/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!
*
* @file     MC33937_routines.h
*
* @author   B15651
* 
* @version  1.0.2.0
* 
* @date     Jun-16-2011
* 
* @brief    MC33937 MOSFET pre-driver Init function header file, with routines
*           for setup and diagnostic.
*
*******************************************************************************
*
* Detailed Description of the file.
*
******************************************************************************/
#ifndef _MC33937_PARAM_H
#define _MC33937_PARAM_H

#include "MPC5643L_LLD_qs.h"

/******************************************************************************
| Defines and macros            (scope: module-local)
-----------------------------------------------------------------------------*/

//#define PICTUS
#define LEOPARD
// deadtime value in [ns]
#define DEADTIME                    800
// define commands for MC33937 predriver

// MASK command
    /*
    MASK 0
    -------------------------------------------------------------------------------
    | 7 | 6 | 5 | 4 |     bit3     |       bit2       |     bit1     |    bit0    |
    -------------------------------------------------------------------------------
    | 0 | 0 | 1 | 0 | Over current | VLS undervoltage | Desaturation | Over Temp. |
    -------------------------------------------------------------------------------
    */
#define MASK0_CMD                   0x20

/*
    MASK 1
    ---------------------------------------------------------------------------
    | 7 | 6 | 5 | 4 |     bit3    |     bit2    |     bit1      |    bit0     |
    ---------------------------------------------------------------------------
    | 0 | 0 | 1 | 1 | Reset Event | Write Error | Framing Error | Phase Error |
    ---------------------------------------------------------------------------
    */
#define MASK1_CMD                   0x30

// CLINT command
// Clears portion of the fault latch corresponding to MASK0
#define CLINT0_CMD                  0x6F
// Clears portion of the fault latch corresponding to MASK1
#define CLINT1_CMD                  0x7F

/*
    MODE command
    ---------------------------------------------------------
    | 7 | 6 | 5 | 4 |     bit3    | 2 |  bit1   |    bit0   |
    ---------------------------------------------------------
    | 0 | 1 | 0 | 0 | Desat Fault | 0 | FULLON  | Mode Lock |
    |   |   |   |   |    mode     |   |  mode   |           |
    ---------------------------------------------------------
    */
#define MODE_CMD                    0x49

// DEADTIME command
#define DEADTIME_CMD                0x81

// STATUS register 0
#define STATUS0_CMD                 0x00
// STATUS register 0
#define STATUS1_CMD                 0x01
// STATUS register 0
#define STATUS2_CMD                 0x02
// STATUS register 0
#define STATUS3_CMD                 0x03

// define PIT CLK in MHz
//#define PIT_CLK                     80

#define PIT_DELAY_2MS               (PIT_CLK * 2000)
#define PIT_DELAY_10US              (PIT_CLK * 10)

// MC33937 deadtime calibration clock
#define MC33937_CALIB_CLK           (16)
// timeout for stabilize power on MC33937 device = 2ms; 2e-3*120e6*1000/PIT_CLK   (PIT_CLK = 120)
//#define MC33937_POWER_UP_TIME       2000000

// timeout for stabilize power on MC33937 device = 5ms; 5e-3*120e6*1000/PIT_CLK   (PIT_CLK = 120)
#define MC33937_POWER_UP_TIME       5000000

#ifdef LEOPARD
/*! Macro containing motor CS values for MPC5643L Dual Motor Controller board */
#define MOTOR1_CS                   0
#define MOTOR2_CS                   1

/*! Macro containing number of the PCR register of the CS for motor 1 and 2 */
#define MOTOR1_CSPCR                36
#define MOTOR2_CSPCR                79

/*! Macro containing number of the PCR register of the Enable for motor 1 */
#define M1_ENBLPCR                  11
#define M2_ENBLPCR                  9

/*! Macro containing number of the PCR register of the Reset for motor 1 */
#define RSTPCR                      10

#endif

#ifdef PICTUS
/*! Macro containing motor CS values for MPC5604P Dual Motor Controller board */
#define MOTOR1_CS                   0

/*! Macro containing number of the PCR register of the CS for motor 1 and 2 */
#define MOTOR1_CSPCR                83

#endif

/*! Macro containing default value for setup MPC5643L dual motor controller board.*/
#define MPC5643L_BGA257_CB_M1_DEFAULT      {MOTOR1_CS,MOTOR1_CSPCR,(ASSERT_CS0 | ASSERT_CTAR0),DSPI0_BASE,0,0,0,0,0,DEADTIME,MODE_CMD,MASK0_CMD,MASK1_CMD,PIT_CHNL0_BASE,RSTPCR,M1_ENBLPCR,2}
//#define MPC5643L_BGA257_CB_M1_DEFAULT      {0,0,0,0,0,DEADTIME,MODE_CMD,MASK0_CMD,MASK1_CMD,3,MOTOR1_CS,0,MOTOR1_CSPCR,10,11,2}
//#define MPC5643L_BGA257_CB_M2_DEFAULT      {0,0,0,0,0,DEADTIME,MODE_CMD,MASK0_CMD,MASK1_CMD,3,MOTOR2_CS,0,MOTOR2_CSPCR,10,11,2}
#define MPC5643L_BGA257_CB_M2_DEFAULT      {MOTOR2_CS,MOTOR2_CSPCR,(ASSERT_CS1 | ASSERT_CTAR0),DSPI0_BASE,0,0,0,0,0,DEADTIME,MODE_CMD,MASK0_CMD,MASK1_CMD,PIT_CHNL0_BASE,RSTPCR,M2_ENBLPCR,2}

/*! Macro containing default values for setup MPC5604P controller board.*/
#define MPC5604P_TQFP144_CB_DEFAULT        {0,0,0,0,0,DEADTIME,MODE_CMD,MASK0_CMD,MASK1_CMD,3,MOTOR1_CS,3,MOTOR1_CSPCR,42,96,1}



/******************************************************************************
| Typedefs and structures       (scope: module-local)
-----------------------------------------------------------------------------*/
/*------------------------------------------------------------------------*//*!
@struct SR0_T "\MC33937_routines.h"

@brief  Structure containing status register 0 image of the MC33937 device
*//*-------------------------------------------------------------------------*/
typedef union {
    tU8 R;
    struct {
        tU8    reset_event  :1;    /*!< reset event flag, is set upon exiting /RST */
        tU8    write_err    :1;    /*!< Write Error Afther the Lock flag */
        tU8    framing_err  :1;    /*!< Framing error flag */
        tU8    phase_err    :1;    /*!< Phase error flag */
        tU8    overcurrent  :1;    /*!< Over-current event flag */
        tU8    lowvls       :1;    /*!< Low VLS voltage flag */
        tU8    desat        :1;    /*!< DESAT flag detected on any channel */
        tU8    tlim         :1;    /*!< TLIM flag detected on any channel */
    } B;
}SR0_T;

/*------------------------------------------------------------------------*//*!
@struct SR1_T "\MC33937_routines.h"

@brief  Structure containing status register 1 image of the MC33937 device
*//*-------------------------------------------------------------------------*/
typedef union {
    tU8 R;
    struct {
        tU8    :1;                  /*!< reserve */
        tU8    desat_mode   :1;     /*!< current state of the Desaturation/Phase Error turn-off mode */
        tU8    zds          :1;     /*!< Zero deadtime is commanded */
        tU8    calib_overfl :1;     /*!< flag for a Deadtime Calibration Overflow */
        tU8    deadtime_cal :1;     /*!< Deadtime calibration occurred */
        tU8    :1;                  /*!< reserve */
        tU8    fullon       :1;     /*!< present status of FULLON MODE */
        tU8    lockbit      :1;     /*!< LockBit indicates the IC regs are locked */
    } B;
}SR1_T;

/*------------------------------------------------------------------------*//*!
@struct SR2_T "\MC33937_routines.h"

@brief  Structure containing status register 2 image of the MC33937 device
*//*-------------------------------------------------------------------------*/
typedef union {
    tU8 R;
    struct {
        tU8    mask1_3      :1;     /*!< status of the MASK1.3 bit */
        tU8    mask1_2      :1;     /*!< status of the MASK1.2 bit */
        tU8    mask1_1      :1;     /*!< status of the MASK1.1 bit */
        tU8    mask1_0      :1;     /*!< status of the MASK1.0 bit */
        tU8    mask0_3      :1;     /*!< status of the MASK0.3 bit */
        tU8    mask0_2      :1;     /*!< status of the MASK0.2 bit */
        tU8    mask0_1      :1;     /*!< status of the MASK0.1 bit */
        tU8    mask0_0      :1;     /*!< status of the MASK0.0 bit */
    } B;
}SR2_T;

/*------------------------------------------------------------------------*//*!
@struct MC33937_SR_T "\MC33937_routines.h"

@brief  Structure containing status registers image of the MC33937 device
*//*-------------------------------------------------------------------------*/
typedef struct
{
    SR0_T       sr0;    /*!< status register 0 */
    SR1_T       sr1;    /*!< status register 1 */
    SR2_T       sr2;    /*!< status register 2 */
    tU8     sr3;    /*!< status register 3 */
}MC33937_SR_T;

/*------------------------------------------------------------------------*//*!
@struct MC33937_SET_T "\MC33937_routines.h"

@brief  Structure containing configuration setup for the MC33937 device
*//*-------------------------------------------------------------------------*/
typedef struct
{
    DSPI_SET_T      dspiSet;        /*!< DSPI settings */
    MC33937_SR_T    status;         /*!< image of the Status registers */
    tU16        setDeadtime;    /*!< real dead time of HS and LS transistors */
    tU16        deadtime;       /*!< define dead time of HS and LS transistors */
    tU8         mode;           /*!< define value of the MODE register */
    tU8         mask0;          /*!< define value of the MASK0 register */
    tU8         mask1;          /*!< define value of the MASK1 register */
    tU32        pitChnlBaseAdr; /*!< define number of the PIT channel used for generation delays */
    tU8         rstPcrNb;       /*!< define number of the PCR register used for /RESET signal on the CB */
    tU8         enPcrNb;        /*!< define number of the PCR register used for ENABLE signal on the CB */
    tU8         typeCb;         /*!< define type of the used CB */
}MC33937_SET_T;


extern tBool   bFcnStatusMC33937;

// ****************************************************************************
/*! 
* @ingroup MC33937_GROUP 
*/ 
extern  void        mc33937ClearFault(MC33937_SET_T *ptr);
extern  void        mc33937Enable(MC33937_SET_T *ptr);
extern  void        mc33937Disable(MC33937_SET_T *ptr);
extern  void        mc33937Reset(MC33937_SET_T *ptr);
extern  tBool       mc33937ReadSr(MC33937_SET_T *ptr);
extern  tBool       mc33937DeadtimeSetup(MC33937_SET_T *ptr);
extern  void        mc33937DoubleReset(MC33937_SET_T *ptr);
extern  tBool       mc33937Config(MC33937_SET_T *ptr);

#endif  /* _MC33937_PARAM_H */
// ****************************************************************************
