/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!
*
* @file     POSPE_FLT.c
*
* @author   r63172
*
* @version  1.0.3.0
*
* @date     Aug-21-2012
*
* @brief    Board Support Package for MPC563L - Position/Speed
*           calculation module
*
*******************************************************************************
*
* This file includes all functions and settings specific for MPC5643L_CB
*
******************************************************************************/

/******************************************************************************
| Includes
-----------------------------------------------------------------------------*/
/*#include "MPC5643L_qs.h"
#include "MPC5643L_LLD_qs.h"

#include "MPC5643L_DMCB_BSP.h"
#include "amclib.h"*/

#include "POSPE_FLT.h"

/******************************************************************************
| External declarations
-----------------------------------------------------------------------------*/

/******************************************************************************
| Defines and macros            (scope: module-local)
-----------------------------------------------------------------------------*/

/******************************************************************************
| Typedefs and structures       (scope: module-local)
-----------------------------------------------------------------------------*/

/******************************************************************************
| Global variable definitions   (scope: module-exported)
-----------------------------------------------------------------------------*/

/******************************************************************************
| Global variable definitions   (scope: module-local)
-----------------------------------------------------------------------------*/

/******************************************************************************
| Function prototypes           (scope: module-local)
-----------------------------------------------------------------------------*/

/******************************************************************************
| Function implementations      (scope: module-local)
-----------------------------------------------------------------------------*/

/******************************************************************************
| Function implementations      (scope: module-exported)
-----------------------------------------------------------------------------*/

/**************************************************************************//*!
@brief      Position/Speed (POSPE) module initialization routine

@param[in,out]  *ptr    Pointer to structure of POSPE module variables and
                        parameters

@return     # true - POSPE initialization successful
            # false - POSPE initialization error

@details    This function performs software POSPE module initialization.

@note

@warning
******************************************************************************/
tBool POSPE_ModuleClearEnc(pmsmDrive_t *ptr)
{

    AMCLIB_TrackObsrvInit_FLT(&ptr->pospeEnc.observer.ATO);
    GDFLIB_FilterMAInit_FLT(&ptr->pospeEnc.observer.filterMA);

    ptr->pospeEnc.fltThetaEl                         = 0.0F;
    ptr->pospeEnc.fltThetaElRes                      = 0.0F;
    ptr->pospeEnc.fltThetaMe                         = 0.0F;
    ptr->pospeEnc.fltThErr                           = 0.0F;

    ptr->pospeEnc.fltResOffset                       = 0.0F;
    ptr->pospeEnc.fltResSin                          = 0.0F;
    ptr->pospeEnc.fltResCos                          = 0.0F;

    return (1);
}
/**************************************************************************//*!
@brief      Position/Speed (POSPE) module initialization routine

@param[in,out]  *ptr    Pointer to structure of POSPE module variables and
                        parameters

@return     # true - POSPE initialization successful
            # false - POSPE initialization error

@details    This function performs software POSPE module initialization.

@note

@warning
******************************************************************************/
tBool POSPE_ModuleClearRes(pmsmDrive_t *ptr)
{
    AMCLIB_TrackObsrvInit_FLT(&ptr->pospeRes.observer.ATO);
    GDFLIB_FilterMAInit_FLT(&ptr->pospeRes.observer.filterMA);

    ptr->pospeRes.fltThetaEl                         = 0.0F;
    ptr->pospeRes.fltThetaElRes                      = 0.0F;
    ptr->pospeRes.fltThetaMe                         = 0.0F;
    ptr->pospeRes.fltThErr	                         = 0.0F;

    ptr->pospeRes.fltResOffset                       = 0.0F;
    ptr->pospeRes.fltResSin                          = 0.0F;
    ptr->pospeRes.fltResCos                          = 0.0F;

    return (1);
}

/**************************************************************************//*!
@brief      Function for reading rotor mechanical position using encoder
            and rescaling it to electrical angle.

@param[in,out]  *ptr    Pointer to structure of POSPE module variables and
                        parameters

@return     Electrical rotor position \f$ \left< -\pi;\pi \right> \f$

@details

@note

@warning
******************************************************************************/
tBool POSPE_GetPositionElEnc(pmsmDrive_t *ptr)
{
    static tFrac32 f32ThRotMe, f32ThRotEl, f32ThRotMe_eTimer;
    static tFrac16 f16TimerValue, f16CMPLD2Value;

    f16TimerValue                = ioctl(ptr->pospeCfg.encCfg.eTimerAddr,ETIMER_READ_VALUE_REG_CNTR, NULL);
    f16CMPLD2Value               = MLIB_Neg(ioctl(ptr->pospeCfg.encCfg.eTimerAddr,ETIMER_READ_VALUE_REG_CMPLD2, NULL));

    // Mechanical rotor position acquired from eTimer - in fix point <-1,1)
    f32ThRotMe_eTimer			 = MLIB_ConvertPU_F32FLT(MLIB_Div((tFloat)f16TimerValue,(tFloat)f16CMPLD2Value));

    AMCLIB_TrackObsrv_FLT( ptr->pospeEnc.fltThErr, & ptr->pospeEnc.fltThetaMe, &ptr->pospeEnc.fltOmegaMe.raw, &ptr->pospeEnc.observer.ATO);
    ptr->pospeEnc.fltOmegaEl.raw = MLIB_Mul(ptr->pospeEnc.fltOmegaMe.raw,ptr->pospeEnc.fltMotorPP);

    // Estimated Mechanical rotor position - wrapping into the range <-pi,pi> - float
      if (ptr->pospeEnc.fltThetaMe>FLOAT_PI)
      	{
      		ptr->pospeEnc.observer.ATO.pParamInteg.fltState = MLIB_Sub(ptr->pospeEnc.observer.ATO.pParamInteg.fltState,FLOAT_2_PI);
      		ptr->pospeEnc.fltThetaMe = ptr->pospeEnc.observer.ATO.pParamInteg.fltState;
      	}

      if (ptr->pospeEnc.fltThetaMe<-FLOAT_PI)
      	{
        	ptr->pospeEnc.observer.ATO.pParamInteg.fltState = MLIB_Add(ptr->pospeEnc.observer.ATO.pParamInteg.fltState,FLOAT_2_PI);
        	ptr->pospeEnc.fltThetaMe = ptr->pospeEnc.observer.ATO.pParamInteg.fltState;
      	}

  	// Mechanical rotor position - transformation in to the range <-1,1> - fix point
    f32ThRotMe 				 	= MLIB_ConvertPU_F32FLT(MLIB_Div(ptr->pospeEnc.fltThetaMe,FLOAT_PI));
    // Rotor position - transformation from mechanical to electrical  - fix point
    f32ThRotEl				 	= MLIB_ShL_F32(MLIB_MulSat_F32(f32ThRotMe,ptr->pospeEnc.s32MotorPpScale),ptr->pospeEnc.s16MotorPpScaleShift);

    // Electrical rotor position - <-pi, pi> range - floating point
    ptr->pospeEnc.fltThetaEl   	= MLIB_Mul(MLIB_ConvertPU_FLTF32(f32ThRotEl),FLOAT_PI);

    // Theta error = (Theta_eTimer - Theta_est), calculated in fix point due to the precision
    ptr->pospeEnc.fltThErr  	= MLIB_Mul(MLIB_ConvertPU_FLTF32(MLIB_Sub_F32(f32ThRotMe_eTimer,f32ThRotMe)),FLOAT_PI);

    return(1);
}
/**************************************************************************//*!
@brief      Function enables to set the POSPE module to arbitrary initial
            rotor position.

@param[in,out]  *ptr    Pointer to structure of POSPE module variables and
                        parameters

@return     Electrical rotor position \f$ \left< -\pi;\pi \right> \f$

@details

@note

@warning
******************************************************************************/
tBool POSPE_SetPositionElEnc(pmsmDrive_t *ptr)
{
    ioctl(ptr->pospeCfg.encCfg.eTimerAddr,ETIMER_WRITE_VALUE_REG_CNTR, 0);
    ptr->pospeEnc.observer.ATO.pParamInteg.fltState = 0;

    return(1);
}

/**************************************************************************//*!
@brief      Function for reading electrical rotor angular velocity.

@param[in,out]  *ptr    Pointer to structure of POSPE module variables and
                        parameters

@return     Function #POSPE_GetSpeedElEnc returns angular velocity of the rotor
            calculated by the position tracking observer and filtered using
            a moving average filter.

@details

@note

@warning
******************************************************************************/
tBool POSPE_GetSpeedElEnc(pmsmDrive_t *ptr)
{
	ptr->pospeEnc.fltOmegaEl.filt = GDFLIB_FilterMA(ptr->pospeEnc.fltOmegaEl.raw,&(ptr->pospeEnc.observer.filterMA));

    return(1);
}

/**************************************************************************//*!
@brief      Function for reading rotor mechanical position using resolver
            and rescaling it to electrical angle.

@param[in,out]  *ptr    Pointer to structure of POSPE module variables and
                        parameters

@return     Electrical rotor position \f$ \left< -\pi;\pi \right> \f$

@details

@note

@warning
******************************************************************************/
tBool POSPE_GetPositionElRes(pmsmDrive_t *ptr)
{
	static tFloat  fltCosEst;
	static tFloat  fltSinEst;
	static tFrac32 F32ThetaElRes;
	static tFrac32 F32ThetaMeRes;
	static tFrac32 F32ResOffsetEl;

	// Resolver feedback signal measurement - float
    ptr->pospeRes.fltResSin      = MLIB_Mul(MLIB_Sub(MLIB_Div((tFloat)(ioctl(ptr->pospeCfg.resCfg.SinBaseAddr,ADC_READ_VALUE,ptr->pospeCfg.resCfg.SinChnlOffset)),(tFloat)0x0FFF),0.5F), 2.0F);
    ptr->pospeRes.fltResCos      = MLIB_Mul(MLIB_Sub(MLIB_Div((tFloat)(ioctl(ptr->pospeCfg.resCfg.CosBaseAddr,ADC_READ_VALUE,ptr->pospeCfg.resCfg.CosChnlOffset)),(tFloat)0x0FFF),0.5F), 2.0F);

    /*// Mechanical and electrical angular speed calculation - float*/

    AMCLIB_TrackObsrv_FLT(ptr->pospeRes.fltThErr, & ptr->pospeRes.fltThetaMe, &ptr->pospeRes.fltOmegaMe.raw, &ptr->pospeRes.observer.ATO);
    ptr->pospeRes.fltOmegaEl.raw = MLIB_Mul(ptr->pospeRes.fltOmegaMe.raw, ptr->pospeRes.fltMotorPP);

    // Mechanical rotor position - transformation in to the range <-pi,pi> - float
    if (ptr->pospeRes.fltThetaMe>3.1415926F)
    	{
    		ptr->pospeRes.observer.ATO.pParamInteg.fltState = MLIB_Sub(ptr->pospeRes.observer.ATO.pParamInteg.fltState,MLIB_Mul(2.0F,3.1415926F));
    		ptr->pospeRes.fltThetaMe = ptr->pospeRes.observer.ATO.pParamInteg.fltState;
    	}

    if (ptr->pospeRes.fltThetaMe<-3.1415926F)
    	{
    		ptr->pospeRes.observer.ATO.pParamInteg.fltState = MLIB_Add(ptr->pospeRes.observer.ATO.pParamInteg.fltState,MLIB_Mul(2.0F,3.1415926F));
    		ptr->pospeRes.fltThetaMe = ptr->pospeRes.observer.ATO.pParamInteg.fltState;
    	}

	// Electrical rotor position - transformation in to the range <-pi,pi> - fix point
    F32ThetaMeRes 				 = (tFrac32)(MLIB_Mul(MLIB_Div(ptr->pospeRes.fltThetaMe,3.1415926F),(tFloat)0x80000000));
    F32ThetaElRes				 = MLIB_ShL_F32(MLIB_MulSat_F32(F32ThetaMeRes,ptr->pospeRes.s32MotorPpScale),ptr->pospeRes.s16MotorPpScaleShift);
    // Resolver offset converted to FRAC format due to overflow
    F32ResOffsetEl				 = (tFrac32)(MLIB_Mul(MLIB_Div(ptr->pospeRes.fltResOffset,3.1415926F),(tFloat)0x80000000));
	// Electrical rotor position - floating point
    ptr->pospeRes.fltThetaEl  	 = MLIB_Mul(MLIB_Div((tFloat)(MLIB_Sub_F32(F32ThetaElRes,F32ResOffsetEl)),(tFloat)0x80000000), 3.1415926F);

    fltSinEst                    = GFLIB_Sin(ptr->pospeRes.fltThetaMe);
    fltCosEst                    = GFLIB_Cos(ptr->pospeRes.fltThetaMe);

    ptr->pospeRes.fltThErr  	 = MLIB_Sub(MLIB_Mul(ptr->pospeRes.fltResSin,fltCosEst), MLIB_Mul(ptr->pospeRes.fltResCos,fltSinEst));

    return(1);

}
/**************************************************************************//*!
@brief      Function for reading electrical rotor angular velocity from resolver.

@param[in,out]  *ptr    Pointer to structure of POSPE module variables and
                        parameters

@return     Function #POSPE_GetSpeedElRes returns angular velocity of the rotor
            calculated by the position tracking observer and filtered using
            a moving average filter.

@details

@note

@warning
******************************************************************************/
tBool POSPE_GetSpeedElRes(pmsmDrive_t *ptr)
{
    ptr->pospeRes.fltOmegaEl.filt = GDFLIB_FilterMA(ptr->pospeRes.fltOmegaEl.raw,&(ptr->pospeRes.observer.filterMA));

    return(1);
}

/* End of file */
