/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!
*
* @file     POSPE_FLT.h
*
* @author   r63172
*
* @version  1.0.3.0
*
* @date     Aug-21-2012
*
* @brief    Header file for MPC5643L Board Support Package
*           Position/Speed calculation module
*
*******************************************************************************
*
* This file includes MACRO and user type definitions of Board Support Package
* for MPC5643L
*
******************************************************************************/
#ifndef _POSPE_FLT_H_
#define _POSPE_FLT_H_

#include "ADC_MEAS_FLT.h"

#include "MPC5643L_qs.h"
#include "MPC5643L_LLD_qs.h"
#include "MPC5643L_DMCB_BSP.h"
#include "amclib.h"

/******************************************************************************
| Defines and macros            (scope: module-local)
-----------------------------------------------------------------------------*/
//povodne
/*
#define POSPE_OBSERVER_DEFAULT  {GFLIB_CONTROLLER_PIAW_R_DEFAULT,\
                                GFLIB_INTEGRATOR_TR_DEFAULT,\
                                GDFLIB_FILTER_MA_DEFAULT}
*/

#define POSPE_OBSERVER_DEFAULT  {AMCLIB_TRACK_OBSRV_DEFAULT_FLT,\
                                GDFLIB_FILTER_MA_DEFAULT}

#define POSPE_FILT_DEFAULT      {0,0}

#define POSPE_MODULE_DEFAULT    {0,0,0,0,0,0,0,0,0,0,0,\
                                POSPE_FILT_DEFAULT,\
                                POSPE_FILT_DEFAULT,\
                                POSPE_FILT_DEFAULT,\
                                POSPE_OBSERVER_DEFAULT}

/* Encoder 0 & Resolver 0 settings*/
#define POSPE_M1_CFG_DEFAULT     ADC0_BASE,ADC_CDR0_OFFSET,\
								 ADC1_BASE,ADC_CDR0_OFFSET,\
								 ETIMER0_CH0_BASE\

/* Encoder 1 & Resolver 1 settings*/
#define POSPE_M2_CFG_DEFAULT     ADC0_BASE,ADC_CDR6_OFFSET,\
								 ADC1_BASE,ADC_CDR6_OFFSET,\
								 ETIMER1_CH0_BASE\

/* Structure ElectricDrive_t - default settings */
#define CFOC_DEFAULT          	0,0,\
                                1,\
                                {0,0},{0,0},{0,0},{0,0},{0,0},{0,0},{0,0},{0,0},{0,0},\
                                {0,0,0},{0,0,0},{0,0,0,0},\
                                GMCLIB_ELIMDCBUSRIP_DEFAULT,\
                                GFLIB_CONTROLLER_PIAW_R_DEFAULT,\
                                GFLIB_CONTROLLER_PIAW_R_DEFAULT,\
                                GFLIB_CONTROLLER_PIAW_P_DEFAULT,\
                                GFLIB_RAMP_DEFAULT,\
                                GDFLIB_FILTER_IIR1_DEFAULT,\
                                GDFLIB_FILTER_IIR1_DEFAULT,\
                                GDFLIB_FILTER_IIR1_DEFAULT,\
                                ADC_MODULE_DEFAULT,\
                                POSPE_MODULE_DEFAULT,\
                                POSPE_MODULE_DEFAULT,\
                                {0,0,0,0,0,0}\

/******************************************************************************
| Typedefs and structures       (scope: module-local)
-----------------------------------------------------------------------------*/


/******************************************************************************
| Exported Variables
-----------------------------------------------------------------------------*/

/******************************************************************************
| Exported function prototypes
-----------------------------------------------------------------------------*/
extern tBool POSPE_ModuleClearEnc(pmsmDrive_t *ptr);
extern tBool POSPE_ModuleClearRes(pmsmDrive_t *ptr);

// Encoder signal processing
extern tBool POSPE_SetPositionElEnc(pmsmDrive_t *ptr);
extern tBool POSPE_GetPositionElEnc(pmsmDrive_t *ptr);
extern tBool POSPE_GetSpeedElEnc(pmsmDrive_t *ptr);

// Resolver signal processing
extern tBool POSPE_GetPositionElRes(pmsmDrive_t *ptr);
extern tBool POSPE_GetSpeedElRes(pmsmDrive_t *ptr);

/*------------------------------------------------------------------------*//*!

@brief        Multiply two 16-bit fractional values and accumulate with
              a 32-bit fractional value.

@return       All bits of the multiply-and-accumulate operation.

@note         Overflow is not detected.
-----------------------------------------------------------------------------*/
static inline tFrac32
F32MacF16F16(register tFrac32 a, register tFrac16 x, register tFrac16 y)
{
	return INT32TOF32((F32TOINT32(a) + (tS32) ((F32TOINT16(x)*F32TOINT16(y))<<1)));
}

#endif /* _POSPE_FLT_H_ */
