/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!*
* @file     MPC5643L_DSPI_LLD.c
*
* @author   b15651
*
* @version  1.0.1.0
*
* @date     Jul-13-2012
*
* @brief    DSPI low level driver module for MPC5643L
*
*******************************************************************************
*
* This file includes initial setting functions of MPC5643L DSPI module.
*
******************************************************************************/
#include "MPC5643L_qs.h"
#include "MPC5643L_DSPI_LLD.h"

/******************************************************************************
* DSPI functions
*****************************************************************************/

/**************************************************************************//*!
@brief          DSPI byte transmision

@param[in,out]  void
@param[in]      void

@return         void

@details        The function transmit 8bits from SPI module and get

                \image latex foc.pdf "My application" width=10cm

@note           This function transmit 8bits from DSPI1 unit

@warning
******************************************************************************/
tBool dspiSendByte(DSPI_SET_T *ptr, tU8 u8DataOut, volatile tU8 *ptDataIn)
{
    static  tU32 data_out;

    // data preparation - concatenate transfer command and data into 32bit transfer register
    data_out            = (tU32)u8DataOut;
    data_out            |= ptr->txCmd;      //(ASSERT_CS0 | ASSERT_CTAR0);  ptr->DspiBaseAdr

    ioctl(ptr->dspiBaseAdr, DSPI_WRITE_DATA, data_out);
    *ptDataIn           = (tU8)(ioctl(ptr->dspiBaseAdr, DSPI_READ_DATA, NULL));

    return (1);
}


/**************************************************************************//*!
@brief          DSPI transmit word

@param[in,out]  u16DataOut
@param[in]      void

@return         ptDataIn

@details        The function transmit 16bits from SPI module and get 16 bit \
                from external device

                \image latex foc.pdf "My application" width=10cm

@note           This function transmit 8bits from DSPI1 unit

@warning
******************************************************************************/
tBool dspiSendWord(DSPI_SET_T *ptr, tU16 u16DataOut, volatile tU16 *ptDataIn)
{
    static  tU32 data_out;

    // data preparation - concatenate transfer command and data into 32bit transfer register
    data_out            = (tU32)u16DataOut;
    data_out            |= ptr->txCmd;      //(ASSERT_CS0 | ASSERT_CTAR0);

    ioctl(ptr->dspiBaseAdr, DSPI_WRITE_DATA, data_out);
    *ptDataIn           = (tU16)(ioctl(ptr->dspiBaseAdr, DSPI_READ_DATA, NULL));

    return (1);
}
