/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!*
* @file       MPC5643L_ETIMER_LLD.h
*
* @author     b15651
*
* @version    1.0.1.0
*
* @date       Jul-13-2012
*
* @brief      eTIMER low level driver module for MPC5643L.
*
*******************************************************************************
*
* This file includes initial setting and MACRO definitions of MPC5643L eTIMER
* peripheral module.
*
******************************************************************************/

#ifndef _MPC5643L_ETIMER_LLD_H_
#define _MPC5643L_ETIMER_LLD_H_

#ifdef __cplusplus
extern "C" {
#endif

#define ETIMER0_BASE                                    0xFFE18000
#define ETIMER0_CH0_BASE                                0xFFE18000
#define ETIMER0_CH1_BASE                                0xFFE18020
#define ETIMER0_CH2_BASE                                0xFFE18040
#define ETIMER0_CH3_BASE                                0xFFE18060
#define ETIMER0_CH4_BASE                                0xFFE18080
#define ETIMER0_CH5_BASE                                0xFFE180A0
#define ETIMER1_BASE                                    0xFFE1C000
#define ETIMER1_CH0_BASE                                0xFFE1C000
#define ETIMER1_CH1_BASE                                0xFFE1C020
#define ETIMER1_CH2_BASE                                0xFFE1C040
#define ETIMER1_CH3_BASE                                0xFFE1C060
#define ETIMER1_CH4_BASE                                0xFFE1C080
#define ETIMER1_CH5_BASE                                0xFFE1C0A0
#define ETIMER2_BASE                                    0xFFE20000
#define ETIMER2_CH0_BASE                                0xFFE20000
#define ETIMER2_CH1_BASE                                0xFFE20040
#define ETIMER2_CH2_BASE                                0xFFE20040
#define ETIMER2_CH3_BASE                                0xFFE20060
#define ETIMER2_CH4_BASE                                0xFFE20080
#define ETIMER2_CH5_BASE                                0xFFE200A0

/******************************************************************************
* eTIMER ioctl commands definitions
******************************************************************************/
/***************************************************************************//*!
*
* @brief                The function read actual value of the COMP1 register.
*
* @param                NULL
*
* @return               The function return compare register 1 value.
*
* @details              The #ETIMER_GET_COMP1_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_GET_COMP1_VALUE, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_GET_COMP1_VALUE

/***************************************************************************//*!
*
* @brief                The function write parameter value to the COMP1 register.
*
* @param                (value 16bit unsigned)
*
* @return               NULL
*
* @details              The #ETIMER_WRITE_VALUE_REG_COMP1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_WRITE_VALUE_REG_COMP1, (value 16bit unsigned));
* \endcode
*
******************************************************************************/
#define ETIMER_WRITE_VALUE_REG_COMP1

/***************************************************************************//*!
*
* @brief                The function read actual value of the COMP2 register.
*
* @param                NULL
*
* @return               The function return compare register 1 value.
*
* @details              The #ETIMER_GET_COMP2_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_GET_COMP2_VALUE, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_GET_COMP2_VALUE

/***************************************************************************//*!
*
* @brief                The function write parameter value to the COMP2 register.
*
* @param                (value 16bit unsigned)
*
* @return               NULL
*
* @details              The #ETIMER_WRITE_VALUE_REG_COMP2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_WRITE_VALUE_REG_COMP2, (value 16bit unsigned));
* \endcode
*
******************************************************************************/
#define ETIMER_WRITE_VALUE_REG_COMP2

/***************************************************************************//*!
*
* @brief                The function read actual value of the CAPT1 register.
*
* @param                NULL
*
* @return               The function return capture register 1 actual value.
*
* @details              The #ETIMER_GET_CAPT1_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_GET_CAPT1_VALUE, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_GET_CAPT1_VALUE

/***************************************************************************//*!
*
* @brief                The function read actual value of the CAPT2 register.
*
* @param                NULL
*
* @return               The function return capture register 2 actual value.
*
* @details              The #ETIMER_GET_CAPT2_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_GET_CAPT2_VALUE, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_GET_CAPT2_VALUE

/***************************************************************************//*!
*
* @brief                The function write parameter value to the LOAD register.
*
* @param                (value 16bit unsigned)
*
* @return               NULL
*
* @details              The #ETIMER_WRITE_VALUE_REG_LOAD ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_WRITE_VALUE_REG_LOAD, (value 16bit unsigned));
* \endcode
*
******************************************************************************/
#define ETIMER_WRITE_VALUE_REG_LOAD

/***************************************************************************//*!
*
* @brief                The function write parameter value to the HOLD register.
*
* @param                NULL
*
* @return               The function return hold register actual value.
*
* @details              The #ETIMER_READ_VALUE_REG_HOLD ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_VALUE_REG_HOLD, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_VALUE_REG_HOLD

/***************************************************************************//*!
*
* @brief                Read CNTR register value.
*
* @param                NULL
*
* @return               The function return counter register actual value.
*
* @details              The #ETIMER_READ_VALUE_REG_CNTR ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_VALUE_REG_CNTR, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_VALUE_REG_CNTR

/***************************************************************************//*!
*
* @brief                Write CNTR register value.
*
* @param                (value 16bit unsigned)
*
* @return               NULL
*
* @details              The #ETIMER_WRITE_VALUE_REG_CNTR ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_WRITE_VALUE_REG_CNTR, (value 16bit unsigned));
* \endcode
*
******************************************************************************/
#define ETIMER_WRITE_VALUE_REG_CNTR

/***************************************************************************//*!
*
* @brief                The function read content of the CTRL1 register. 
*
* @param                NULL
*
* @return               The function return content of the CTRL1 register.
*
* @details              The #ETIMER_READ_VALUE_REG_CTRL1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_VALUE_REG_CTRL1, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_VALUE_REG_CTRL1

/***************************************************************************//*!
*
* @brief                The function select secondary count source.
*
* @param                ETIMER_CNT_0_INPUT
* @param                ETIMER_CNT_1_INPUT
* @param                ETIMER_CNT_2_INPUT
* @param                ETIMER_CNT_3_INPUT
* @param                ETIMER_CNT_4_INPUT
* @param                ETIMER_CNT_5_INPUT
* @param                ETIMER_AUXIN_0
* @param                ETIMER_AUXIN_1
* @param                ETIMER_AUXIN_2
* @param                ETIMER_CNT_0_OUTPUT
* @param                ETIMER_CNT_1_OUTPUT
* @param                ETIMER_CNT_2_OUTPUT
* @param                ETIMER_CNT_3_OUTPUT
* @param                ETIMER_CNT_4_OUTPUT
* @param                ETIMER_CNT_5_OUTPUT
*
* @return               NULL
*
* @details              The #ETIMER_SET_SEC_COUNT_SOURCE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_SEC_COUNT_SOURCE, ETIMER_CNT_0_INPUT);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_SEC_COUNT_SOURCE

/***************************************************************************//*!
*
* @brief                The function set count direction.
*
* @param                ETIMER_UP
* @param                ETIMER_DOWN
*
* @return               NULL
*
* @details              The #ETIMER_SET_COUNT_DIRECTION ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_COUNT_DIRECTION, ETIMER_UP);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_COUNT_DIRECTION

/***************************************************************************//*!
*
* @brief                The function determines whether the counter counts to the compare value or continue couting to roll over.
*
* @param                ETIMER_ROLL_OVER
* @param                ETIMER_UNTIL_COMPARE
*
* @return               NULL
*
* @details              The #ETIMER_SET_COUNT_LENGTH ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_COUNT_LENGTH, ETIMER_ROLL_OVER);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_COUNT_LENGTH

/***************************************************************************//*!
*
* @brief                The function select continuous or one shot counting mode.
*
* @param                ETIMER_COUNT_REPEATEDLY
* @param                ETIMER_COUNT_ONCE
*
* @return               NULL
*
* @details              The #ETIMER_SET_ONCE_COUNT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_ONCE_COUNT, ETIMER_COUNT_REPEATEDLY);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_ONCE_COUNT

/***************************************************************************//*!
*
* @brief                The function select primary count source.
*
* @param                ETIMER_CNT_0_INPUT
* @param                ETIMER_CNT_1_INPUT
* @param                ETIMER_CNT_2_INPUT
* @param                ETIMER_CNT_3_INPUT
* @param                ETIMER_CNT_4_INPUT
* @param                ETIMER_CNT_5_INPUT
* @param                ETIMER_AUXIN_0
* @param                ETIMER_AUXIN_1
* @param                ETIMER_AUXIN_2
* @param                ETIMER_CNT_0_OUTPUT
* @param                ETIMER_CNT_1_OUTPUT
* @param                ETIMER_CNT_2_OUTPUT
* @param                ETIMER_CNT_3_OUTPUT
* @param                ETIMER_CNT_4_OUTPUT
* @param                ETIMER_CNT_5_OUTPUT
* @param                ETIMER_IPBUS_DIV_1
* @param                ETIMER_IPBUS_DIV_2
* @param                ETIMER_IPBUS_DIV_4
* @param                ETIMER_IPBUS_DIV_8
* @param                ETIMER_IPBUS_DIV_16
* @param                ETIMER_IPBUS_DIV_32
* @param                ETIMER_IPBUS_DIV_64
* @param                ETIMER_IPBUS_DIV_128
*
* @return               NULL
*
* @details              The #ETIMER_SET_PRIM_COUNT_SOURCE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_PRIM_COUNT_SOURCE, ETIMER_CNT_0_INPUT);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_PRIM_COUNT_SOURCE

/***************************************************************************//*!
*
* @brief                Set eTIMER counting mode. 
*
* @param                ETIMER_NO_OPERATION
* @param                ETIMER_RIS_EDGE_OF_PRIMARY_SOURCE
* @param                ETIMER_RIS_FALLING_EDGE_OF_PRI_SRC
* @param                ETIMER_RIS_EDGE_OF_PRI_SRC_WHILE_SEC_HIGH_ACT
* @param                ETIMER_QUADRATURE_MODE
* @param                ETIMER_RIS_EDGE_OF_PRI_SRC_SEC_DIRECTION
* @param                ETIMER_SEC_SOURCE_TRIG_PRIM_COUNT
* @param                ETIMER_CASCADED_CNT_MODE
*
* @return               NULL
*
* @details              The #ETIMER_SELECT_COUNT_MODE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SELECT_COUNT_MODE, ETIMER_NO_OPERATION);
* \endcode
*
******************************************************************************/
#define ETIMER_SELECT_COUNT_MODE

/***************************************************************************//*!
*
* @brief                Read CTRL2 register value. 
*
* @param                NULL
*
* @return               The function return content of the CTRL2 register.
*
* @details              The #ETIMER_READ_VALUE_REG_CTRL2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_VALUE_REG_CTRL2, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_VALUE_REG_CTRL2

/***************************************************************************//*!
*
* @brief                Select counter output mode for the OFLAG output signal.
*
* @param                ETIMER_SW_CONTROLLED
* @param                ETIMER_CLEAR_OUTPUT_ON_COMPARE
* @param                ETIMER_SET_OUTPUT_ON_COMPARE
* @param                ETIMER_TOGGLE_OUTPUT_ON_COMPARE
* @param                ETIMER_TOGGLE_OUTPUT_ON_ALT_COMPARE
* @param                ETIMER_SET_ON_COMP1_CLEAR_ON_SEC_EDGE
* @param                ETIMER_SET_ON_COMP2_CLEAR_ON_SEC_EDGE
* @param                ETIMER_SET_ON_COMPARE_CLR_ON_ROLLOVER
* @param                ETIMER_SET_ON_COMP1_CLEAR_ON_COMP2
* @param                ETIMER_SET_WHEN_ACTIVE_CLEAR_STOPED
* @param                ETIMER_SET_COUNT_UP_CLEAR_COUNT_DOWN
* @param                ETIMER_GATED_CLOCK_WHEN_ACTIVE
*
* @return               NULL
*
* @details              The #ETIMER_SEL_OUTMODE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SEL_OUTMODE, ETIMER_SW_CONTROLLED);
* \endcode
*
******************************************************************************/
#define ETIMER_SEL_OUTMODE

/***************************************************************************//*!
*
* @brief                The function enable boadcasting the compare output's to the other channels. 
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_MASTER_MODE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_MASTER_MODE, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_MASTER_MODE

/***************************************************************************//*!
*
* @brief                Select output flag polarity.
*
* @param                ETIMER_TRUE_POLARITY
* @param                ETIMER_INVERTED_POLARITY
*
* @return               NULL
*
* @details              The #ETIMER_SEL_OUT_POL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SEL_OUT_POL, ETIMER_TRUE_POLARITY);
* \endcode
*
******************************************************************************/
#define ETIMER_SEL_OUT_POL

/***************************************************************************//*!
*
* @brief                Select primary input polarity.
*
* @param                ETIMER_TRUE_POLARITY
* @param                ETIMER_INVERTED_POLARITY
*
* @return               NULL
*
* @details              The #ETIMER_SET_PRIMARY_INP_POLARITY ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_PRIMARY_INP_POLARITY, ETIMER_TRUE_POLARITY);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_PRIMARY_INP_POLARITY

/***************************************************************************//*!
*
* @brief                Select secondary input polarity.
*
* @param                ETIMER_TRUE_POLARITY
* @param                ETIMER_INVERTED_POLARITY
*
* @return               NULL
*
* @details              The #ETIMER_SET_SECONDARY_INP_POLARITY ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_SECONDARY_INP_POLARITY, ETIMER_TRUE_POLARITY);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_SECONDARY_INP_POLARITY

/***************************************************************************//*!
*
* @brief                Enable channel re-initialization.
*
* @param                ETIMER_DISBL
* @param                ETIMER_COINIT_USING_LOAD_REG
* @param                ETIMER_COINIT_USING_CMPLD1
*
* @return               NULL
*
* @details              The #ETIMER_SET_CO_CHANNEL_INIT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_CO_CHANNEL_INIT, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_CO_CHANNEL_INIT

/***************************************************************************//*!
*
* @brief                Enable/disable forcing of the OFLAG signal from another channel.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_CO_CHANNEL_OFLAG_FORCE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_CO_CHANNEL_OFLAG_FORCE, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_CO_CHANNEL_OFLAG_FORCE

/***************************************************************************//*!
*
* @brief                Force the OFLAG output in software controlled output mode.
*
* @param                ETIMER_LOW
* @param                ETIMER_HIGH
*
* @return               NULL
*
* @details              The #ETIMER_FORCE_OFLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_FORCE_OFLAG, ETIMER_LOW);
* \endcode
*
******************************************************************************/
#define ETIMER_FORCE_OFLAG

/***************************************************************************//*!
*
* @brief                The function read external input signal (secondary input)
*
* @param                NULL
*
* @return               the value reflect the current state of the signal selected via SECSRC.
*
* @details              The #ETIMER_READ_SEC_SRC_STATUS ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_SEC_SRC_STATUS, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_SEC_SRC_STATUS

/***************************************************************************//*!
*
* @brief                The function enables/disables redundant chennel checking (channels 0 and 1, 2 and 3, 4 and 5 ).
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_REDUNDANT_CHECKING ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_REDUNDANT_CHECKING, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_REDUNDANT_CHECKING

/***************************************************************************//*!
*
* @brief                The function determines the direction of the external pin.
*
* @param                ETIMER_OUTPUT
* @param                ETIMER_INPUT
*
* @return               NULL
*
* @details              The #ETIMER_SET_DIR_EXTRN_PIN ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_DIR_EXTRN_PIN, ETIMER_OUTPUT);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_DIR_EXTRN_PIN

/***************************************************************************//*!
*
* @brief                Read CTRL3 register value. 
*
* @param                NULL
*
* @return               The function return content of the CTRL3 register.
*
* @details              The #ETIMER_READ_VALUE_REG_CTRL3 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_VALUE_REG_CTRL3, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_VALUE_REG_CTRL3

/***************************************************************************//*!
*
* @brief                Set eTIMER behavior in debug mode. 
*
* @param                ETIMER_CONTINUE_NORMAL_OPERATION
* @param                ETIMER_HALT_COUNTER
* @param                ETIMER_FORCE_OFLAG_TO_ZERO
* @param                ETIMER_HALT_COUNTER_AND_FORCE
*
* @return               NULL
*
* @details              The #ETIMER_SET_DEBUG_OPERAITON ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_DEBUG_OPERAITON, ETIMER_CONTINUE_NORMAL_OPERATION);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_DEBUG_OPERAITON

/***************************************************************************//*!
*
* @brief                Read number of words in CAPT1 FIFO
*
* @param                NULL
*
* @return               number of words in the CAPT1 FIFO
*
* @details              The #ETIMER_READ_CAPT1_FIFO_CNT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_CAPT1_FIFO_CNT, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_CAPT1_FIFO_CNT

/***************************************************************************//*!
*
* @brief                Read number of words in CAPT2 FIFO
*
* @param                NULL
*
* @return               number of words in the CAPT2 FIFO
*
* @details              The #ETIMER_READ_CAPT2_FIFO_CNT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_CAPT2_FIFO_CNT, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_CAPT2_FIFO_CNT

/***************************************************************************//*!
*
* @brief                Set reload mechanism on capture event.
*
* @param                ETIMER_DISBL
* @param                ETIMER_RELOAD_ON_CATP1_EVNT
* @param                ETIMER_RELOAD_ON_CATP2_EVNT
* @param                ETIMER_RELOAD_ON_CATP1_AND_CAPT2_EVNT
*
* @return               NULL
*
* @details              The #ETIMER_SET_RELOAD_ON_CAPT_MODE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_RELOAD_ON_CAPT_MODE, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_RELOAD_ON_CAPT_MODE

/***************************************************************************//*!
*
* @brief                Set eTIMER behavior in STOP mode. 
*
* @param                ETIMER_OE_UNAFFECTED
* @param                ETIMER_OE_DISABLED
*
* @return               NULL
*
* @details              The #ETIMER_SET_STOP_OPERATION ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_STOP_OPERATION, ETIMER_OE_UNAFFECTED);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_STOP_OPERATION

/***************************************************************************//*!
*
* @brief                Read STS register value. 
*
* @param                NULL
*
* @return               STS register value.
*
* @details              The #ETIMER_READ_VALUE_REG_STS ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_VALUE_REG_STS, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_VALUE_REG_STS

/***************************************************************************//*!
*
* @brief                Read timer compare flag. 
*
* @param                NULL
*
* @return               Timer compare flag value.
*
* @details              The #ETIMER_READ_COMPARE_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_COMPARE_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_COMPARE_FLAG

/***************************************************************************//*!
*
* @brief                Clear timer compare flag. 
*
* @param                ETIMER_CLEAR_FLAG
*
* @return               NULL
*
* @details              The #ETIMER_CLEAR_COMPARE_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_CLEAR_COMPARE_FLAG, ETIMER_CLEAR_FLAG);
* \endcode
*
******************************************************************************/
#define ETIMER_CLEAR_COMPARE_FLAG

/***************************************************************************//*!
*
* @brief                Read timer COMP1 flag. 
*
* @param                NULL
*
* @return               Timer compare 1 flag value.
*
* @details              The #ETIMER_READ_COMP1_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_COMP1_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_COMP1_FLAG

/***************************************************************************//*!
*
* @brief                Clear timer COMP1 flag. 
*
* @param                ETIMER_CLEAR_FLAG
*
* @return               NULL
*
* @details              The #ETIMER_CLEAR_COMP1_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_CLEAR_COMP1_FLAG, ETIMER_CLEAR_FLAG);
* \endcode
*
******************************************************************************/
#define ETIMER_CLEAR_COMP1_FLAG

/***************************************************************************//*!
*
* @brief                Clear timer COMP2 flag. 
*
* @param                NULL
*
* @return               Timer compare 2 flag value.
*
* @details              The #ETIMER_READ_COMP2_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_COMP2_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_COMP2_FLAG

/***************************************************************************//*!
*
* @brief                Clear timer COMP2 flag. 
*
* @param                ETIMER_CLEAR_FLAG
*
* @return               NULL
*
* @details              The #ETIMER_CLEAR_COMP2_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_CLEAR_COMP2_FLAG, ETIMER_CLEAR_FLAG);
* \endcode
*
******************************************************************************/
#define ETIMER_CLEAR_COMP2_FLAG

/***************************************************************************//*!
*
* @brief                Read timer overflow flag. 
*
* @param                NULL
*
* @return               Timer overflow flag value.
*
* @details              The #ETIMER_READ_TMR_OVERFLOW_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_TMR_OVERFLOW_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_TMR_OVERFLOW_FLAG

/***************************************************************************//*!
*
* @brief                Clear timer overflow flag. 
*
* @param                ETIMER_CLEAR_FLAG
*
* @return               NULL
*
* @details              The #ETIMER_CLEAR_TMR_OVERFLOW_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_CLEAR_TMR_OVERFLOW_FLAG, ETIMER_CLEAR_FLAG);
* \endcode
*
******************************************************************************/
#define ETIMER_CLEAR_TMR_OVERFLOW_FLAG

/***************************************************************************//*!
*
* @brief                Read timer negative transition flag. 
*
* @param                NULL
*
* @return               input edge low flag value.
*
* @details              The #ETIMER_READ_INPUT_EDGE_LOW_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_INPUT_EDGE_LOW_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_INPUT_EDGE_LOW_FLAG

/***************************************************************************//*!
*
* @brief                Clear timer negative transition flag. 
*
* @param                ETIMER_CLEAR_FLAG
*
* @return               NULL
*
* @details              The #ETIMER_CLEAR_INPUT_EDGE_LOW_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_CLEAR_INPUT_EDGE_LOW_FLAG, ETIMER_CLEAR_FLAG);
* \endcode
*
******************************************************************************/
#define ETIMER_CLEAR_INPUT_EDGE_LOW_FLAG

/***************************************************************************//*!
*
* @brief                Clear timer positive transition flag. 
*
* @param                NULL
*
* @return               Input edge high flag value.
*
* @details              The #ETIMER_READ_INPUT_EDGE_HIGH_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_INPUT_EDGE_HIGH_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_INPUT_EDGE_HIGH_FLAG

/***************************************************************************//*!
*
* @brief                Clear timer positive transition flag. 
*
* @param                ETIMER_CLEAR_FLAG
*
* @return               NULL
*
* @details              The #ETIMER_CLEAR_INPUT_EDGE_HIGH_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_CLEAR_INPUT_EDGE_HIGH_FLAG, ETIMER_CLEAR_FLAG);
* \endcode
*
******************************************************************************/
#define ETIMER_CLEAR_INPUT_EDGE_HIGH_FLAG

/***************************************************************************//*!
*
* @brief                Read timer CAPT1 flag. 
*
* @param                NULL
*
* @return               capture 1 flag value.
*
* @details              The #ETIMER_READ_CAPTURE1_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_CAPTURE1_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_CAPTURE1_FLAG

/***************************************************************************//*!
*
* @brief                Clear timer CAPT1 flag. 
*
* @param                ETIMER_CLEAR_FLAG
*
* @return               NULL
*
* @details              The #ETIMER_CLEAR_CAPTURE1_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_CLEAR_CAPTURE1_FLAG, ETIMER_CLEAR_FLAG);
* \endcode
*
******************************************************************************/
#define ETIMER_CLEAR_CAPTURE1_FLAG

/***************************************************************************//*!
*
* @brief                Read timer CAPT2 flag. 
*
* @param                NULL
*
* @return               capture 2 flag value.
*
* @details              The #ETIMER_READ_CAPTURE2_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_CAPTURE2_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_CAPTURE2_FLAG

/***************************************************************************//*!
*
* @brief                Clear timer CAPT2 flag. 
*
* @param                ETIMER_CLEAR_FLAG
*
* @return               NULL
*
* @details              The #ETIMER_CLEAR_CAPTURE2_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_CLEAR_CAPTURE2_FLAG, ETIMER_CLEAR_FLAG);
* \endcode
*
******************************************************************************/
#define ETIMER_CLEAR_CAPTURE2_FLAG

/***************************************************************************//*!
*
* @brief                Read timer redundant channel flag. 
*
* @param                NULL
*
* @return               redundant channel flag value.
*
* @details              The #ETIMER_READ_RDND_CHNL_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_RDND_CHNL_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_RDND_CHNL_FLAG

/***************************************************************************//*!
*
* @brief                Clear timer redundant channel flag. 
*
* @param                ETIMER_CLEAR_FLAG
*
* @return               NULL
*
* @details              The #ETIMER_CLEAR_RDND_CHNL_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_CLEAR_RDND_CHNL_FLAG, ETIMER_CLEAR_FLAG);
* \endcode
*
******************************************************************************/
#define ETIMER_CLEAR_RDND_CHNL_FLAG

/***************************************************************************//*!
*
* @brief                Read timer watchdog timer-out flag. 
*
* @param                NULL
*
* @return               watchdog timer-out flag value.
*
* @details              The #ETIMER_READ_WATCHDOG_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_WATCHDOG_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_WATCHDOG_FLAG

/***************************************************************************//*!
*
* @brief                Clear timer watchdog timer-out flag. 
*
* @param                ETIMER_CLEAR_FLAG
*
* @return               NULL
*
* @details              The #ETIMER_CLEAR_WATCHDOG_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_CLEAR_WATCHDOG_FLAG, ETIMER_CLEAR_FLAG);
* \endcode
*
******************************************************************************/
#define ETIMER_CLEAR_WATCHDOG_FLAG

/***************************************************************************//*!
*
* @brief                Read INTDMA register value. 
*
* @param                NULL
*
* @return               INTDMA register value.
*
* @details              The #ETIMER_READ_VALUE_REG_INTDMA ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_VALUE_REG_INTDMA, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_VALUE_REG_INTDMA

/***************************************************************************//*!
*
* @brief                Set timer compare interrupt flag.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_COMPARE_INT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_COMPARE_INT_FLAG, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_COMPARE_INT_FLAG

/***************************************************************************//*!
*
* @brief                Set timer compare 1 interrupt flag.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_COMP1_INT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_COMP1_INT_FLAG, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_COMP1_INT_FLAG

/***************************************************************************//*!
*
* @brief                Set timer compare 2 interrupt flag.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_COMP2_INT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_COMP2_INT_FLAG, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_COMP2_INT_FLAG

/***************************************************************************//*!
*
* @brief                Set timer overflow interrupt flag.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_TMR_OVERFLOW_INT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_TMR_OVERFLOW_INT_FLAG, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_TMR_OVERFLOW_INT_FLAG

/***************************************************************************//*!
*
* @brief                Set timer input edge low interrupt flag.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_INP_EDGE_LOW_INT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_INP_EDGE_LOW_INT_FLAG, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_INP_EDGE_LOW_INT_FLAG

/***************************************************************************//*!
*
* @brief                Set timer input edge high interrupt flag.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_INP_EDGE_HIGH_INT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_INP_EDGE_HIGH_INT_FLAG, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_INP_EDGE_HIGH_INT_FLAG

/***************************************************************************//*!
*
* @brief                Set timer capture 1 interrupt flag.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_CAPT1_INT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_CAPT1_INT_FLAG, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_CAPT1_INT_FLAG

/***************************************************************************//*!
*
* @brief                Set timer capture 2 interrupt flag.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_CAPT2_INT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_CAPT2_INT_FLAG, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_CAPT2_INT_FLAG

/***************************************************************************//*!
*
* @brief                Set timer redundant channel interrupt flag.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_RDND_CHNL_INT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_RDND_CHNL_INT_FLAG, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_RDND_CHNL_INT_FLAG

/***************************************************************************//*!
*
* @brief                Set timer watchdog interrupt flag.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_WATCHDOG_INT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_WATCHDOG_INT_FLAG, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_WATCHDOG_INT_FLAG

/***************************************************************************//*!
*
* @brief                Set timer CMPLD1 DMA enable interrupt flag.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_CMPLD1DE_INT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_CMPLD1DE_INT_FLAG, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_CMPLD1DE_INT_FLAG

/***************************************************************************//*!
*
* @brief                Set timer CMPLD2 DMA enable interrupt flag.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_CMPLD2DE_INT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_CMPLD2DE_INT_FLAG, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_CMPLD2DE_INT_FLAG

/***************************************************************************//*!
*
* @brief                Set timer input capture 1 DMA enable interrupt flag.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_ICF1DE_INT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_ICF1DE_INT_FLAG, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_ICF1DE_INT_FLAG

/***************************************************************************//*!
*
* @brief                Set timer input capture 2 DMA enable interrupt flag.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_ICF2DE_INT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_ICF2DE_INT_FLAG, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_ICF2DE_INT_FLAG

/***************************************************************************//*!
*
* @brief                Read CMPLD1 register value. 
*
* @param                NULL
*
* @return               CMPLD1 register value.
*
* @details              The #ETIMER_READ_VALUE_REG_CMPLD1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_VALUE_REG_CMPLD1, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_VALUE_REG_CMPLD1

/***************************************************************************//*!
*
* @brief                Write value to CMPLD1 register.
*
* @param                (value 16bit unsigned)
*
* @return               NULL
*
* @details              The #ETIMER_WRITE_VALUE_REG_CMPLD1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_WRITE_VALUE_REG_CMPLD1, (value 16bit unsigned));
* \endcode
*
******************************************************************************/
#define ETIMER_WRITE_VALUE_REG_CMPLD1

/***************************************************************************//*!
*
* @brief                Read CMPLD2 register value. 
*
* @param                NULL
*
* @return               CMPLD2 register value.
*
* @details              The #ETIMER_READ_VALUE_REG_CMPLD2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_VALUE_REG_CMPLD2, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_VALUE_REG_CMPLD2

/***************************************************************************//*!
*
* @brief                Write value to CMPLD2 register.
*
* @param                (value 16bit unsigned)
*
* @return               NULL
*
* @details              The #ETIMER_WRITE_VALUE_REG_CMPLD2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_WRITE_VALUE_REG_CMPLD2, (value 16bit unsigned));
* \endcode
*
******************************************************************************/
#define ETIMER_WRITE_VALUE_REG_CMPLD2

/***************************************************************************//*!
*
* @brief                Read CCCTRL register value. 
*
* @param                NULL
*
* @return               CCCTRL register value.
*
* @details              The #ETIMER_READ_VALUE_REG_CCCTRL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_CH0_BASE,ETIMER_READ_VALUE_REG_CCCTRL, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_VALUE_REG_CCCTRL

/***************************************************************************//*!
*
* @brief                Enables/Disables input capture operation.
*
* @param                ETIMER_DISBL
* @param                ETIMER_ENBL
*
* @return               NULL
*
* @details              The #ETIMER_SET_CAPTURE_OPER ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_CAPTURE_OPER, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_CAPTURE_OPER

/***************************************************************************//*!
*
* @brief                Enables/Disables input capture operation mode.
*
* @param                ETIMER_FREERUNNING
* @param                ETIMER_ONESHOT
*
* @return               NULL
*
* @details              The #ETIMER_SET_CAPTURE_OPER_MODE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_CAPTURE_OPER_MODE, ETIMER_FREERUNNING);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_CAPTURE_OPER_MODE

/***************************************************************************//*!
*
* @brief                Define which input edge cause a capture 1 event.
*
* @param                ETIMER_DISBL
* @param                ETIMER_CAPT_FALLING_EDGE
* @param                ETIMER_CAPT_RISING_EDGE
* @param                ETIMER_CAPT_ANY_EDGE
*
* @return               NULL
*
* @details              The #ETIMER_SET_CAPT1_MODE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_CAPT1_MODE, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_CAPT1_MODE

/***************************************************************************//*!
*
* @brief                Define which input edge cause a capture 2 event.
*
* @param                ETIMER_DISBL
* @param                ETIMER_CAPT_FALLING_EDGE
* @param                ETIMER_CAPT_RISING_EDGE
* @param                ETIMER_CAPT_ANY_EDGE
*
* @return               NULL
*
* @details              The #ETIMER_SET_CAPT2_MODE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_CAPT2_MODE, ETIMER_DISBL);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_CAPT2_MODE

/***************************************************************************//*!
*
* @brief                Define using of the COMP1 and COMP2 registers in regards to the counting direction.
*
* @param                ETIMER_COMP1_UP_COMP2_UP
* @param                ETIMER_COMP1_DOWM_COMP2_UP
* @param                ETIMER_COMP1_UP_COMP2_DOWN
* @param                ETIMER_COMP1_DOWM_COMP2_DOWM
*
* @return               NULL
*
* @details              The #ETIMER_SET_COMPARE_MODE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_COMPARE_MODE, ETIMER_COMP1_UP_COMP2_UP);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_COMPARE_MODE

/***************************************************************************//*!
*
* @brief                Set compare load control 1 mode.
*
* @param                ETIMER_NEVER_PRELOAD
* @param                ETIMER_CMPLD1_TO_COMP1_ON_COMP1
* @param                ETIMER_CMPLD1_TO_COMP1_ON_COMP2
* @param                ETIMER_CMPLD2_TO_COMP1_ON_COMP1
* @param                ETIMER_CMPLD2_TO_COMP1_ON_COMP2
* @param                ETIMER_CMPLD1_TO_CNTR_ON_COMP1
* @param                ETIMER_CMPLD1_TO_CNTR_ON_COMP2
*
* @return               NULL
*
* @details              The #ETIMER_SET_COMPARE_LOAD_CTRL1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_COMPARE_LOAD_CTRL1, ETIMER_NEVER_PRELOAD);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_COMPARE_LOAD_CTRL1

/***************************************************************************//*!
*
* @brief                Set compare load control 2 mode.
*
* @param                ETIMER_NEVER_PRELOAD
* @param                ETIMER_CMPLD1_TO_COMP2_ON_COMP1
* @param                ETIMER_CMPLD1_TO_COMP2_ON_COMP2
* @param                ETIMER_CMPLD2_TO_COMP2_ON_COMP1
* @param                ETIMER_CMPLD2_TO_COMP2_ON_COMP2
* @param                ETIMER_CMPLD2_TO_CNTR_ON_COMP1
* @param                ETIMER_CMPLD2_TO_CNTR_ON_COMP2
*
* @return               NULL
*
* @details              The #ETIMER_SET_COMPARE_LOAD_CTRL2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_CH0_BASE,ETIMER_SET_COMPARE_LOAD_CTRL2, ETIMER_NEVER_PRELOAD);
* \endcode
*
******************************************************************************/
#define ETIMER_SET_COMPARE_LOAD_CTRL2

/***************************************************************************//*!
*
* @brief                Read FILT register value. 
*
* @param                NULL
*
* @return               FILT register value.
*
* @details              The #ETIMER_READ_VALUE_REG_FILT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_BASE,ETIMER_READ_VALUE_REG_FILT, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_VALUE_REG_FILT

/***************************************************************************//*!
*
* @brief                Set filter sample period.
*
* @param                (value 8bit unsigned)
*
* @return               NULL
*
* @details              The #ETIMER_SET_FLT_SAMPL_PERIOD ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_BASE,ETIMER_SET_FLT_SAMPL_PERIOD, (value 8bit unsigned));
* \endcode
*
******************************************************************************/
#define ETIMER_SET_FLT_SAMPL_PERIOD

/***************************************************************************//*!
*
* @brief                Set filter sample count.
*
* @param                (value 3bit unsigned)
*
* @return               NULL
*
* @details              The #ETIMER_SET_FLT_SAMPL_COUNT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_BASE,ETIMER_SET_FLT_SAMPL_COUNT, (value 3bit unsigned));
* \endcode
*
******************************************************************************/
#define ETIMER_SET_FLT_SAMPL_COUNT

/***************************************************************************//*!
*
* @brief                Read WDTOL register value. 
*
* @param                NULL
*
* @return               WDTOL register value.
*
* @details              The #ETIMER_READ_VALUE_REG_WDTOL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_BASE,ETIMER_READ_VALUE_REG_WDTOL, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_VALUE_REG_WDTOL

/***************************************************************************//*!
*
* @brief                Set watchdog time-out low value.
*
* @param                (value 16bit unsigned)
*
* @return               NULL
*
* @details              The #ETIMER_SET_WATCHDOG_TIMEOUT_LOW ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_BASE,ETIMER_SET_WATCHDOG_TIMEOUT_LOW, (value 16bit unsigned));
* \endcode
*
******************************************************************************/
#define ETIMER_SET_WATCHDOG_TIMEOUT_LOW

/***************************************************************************//*!
*
* @brief                Read WDTOH register value. 
*
* @param                NULL
*
* @return               WDTOH register value.
*
* @details              The #ETIMER_READ_VALUE_REG_WDTOH ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_BASE,ETIMER_READ_VALUE_REG_WDTOH, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_VALUE_REG_WDTOH

/***************************************************************************//*!
*
* @brief                Set watchdog time-out high value.
*
* @param                (value 16bit unsigned)
*
* @return               NULL
*
* @details              The #ETIMER_SET_WATCHDOG_TIMEOUT_HIGH ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_BASE,ETIMER_SET_WATCHDOG_TIMEOUT_HIGH, (value 16bit unsigned));
* \endcode
*
******************************************************************************/
#define ETIMER_SET_WATCHDOG_TIMEOUT_HIGH

/***************************************************************************//*!
*
* @brief                Read ENBL register value. 
*
* @param                NULL
*
* @return               WDTOH register value.
*
* @details              The #ETIMER_READ_VALUE_REG_ENBL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(ETIMER0_BASE,ETIMER_READ_VALUE_REG_ENBL, NULL);
* \endcode
*
******************************************************************************/
#define ETIMER_READ_VALUE_REG_ENBL

/***************************************************************************//*!
*
* @brief                Enable timer channel.
*
* @param                ETIMER_CHANNEL1
* @param                ETIMER_CHANNEL2
* @param                ETIMER_CHANNEL3
* @param                ETIMER_CHANNEL4
* @param                ETIMER_CHANNEL5
* @param                ETIMER_CHANNEL6
*
* @return               NULL
*
* @details              The #ETIMER_ENBL_CHNL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_BASE,ETIMER_ENBL_CHNL, ETIMER_CHANNEL1);
* \endcode
*
******************************************************************************/
#define ETIMER_ENBL_CHNL

/***************************************************************************//*!
*
* @brief                Select the source of the eTimer DMA request 0.
*
* @param                ETIMER_CHNL0_CAPT1_DMA_READ
* @param                ETIMER_CHNL0_CAPT2_DMA_READ
* @param                ETIMER_CHNL0_CMPLD1_DMA_WRITE
* @param                ETIMER_CHNL0_CMPLD2_DMA_WRITE
* @param                ETIMER_CHNL1_CAPT1_DMA_READ
* @param                ETIMER_CHNL1_CAPT2_DMA_READ
* @param                ETIMER_CHNL1_CMPLD1_DMA_WRITE
* @param                ETIMER_CHNL1_CMPLD2_DMA_WRITE
* @param                ETIMER_CHNL2_CAPT1_DMA_READ
* @param                ETIMER_CHNL2_CAPT2_DMA_READ
* @param                ETIMER_CHNL2_CMPLD1_DMA_WRITE
* @param                ETIMER_CHNL2_CMPLD2_DMA_WRITE
* @param                ETIMER_CHNL3_CAPT1_DMA_READ
* @param                ETIMER_CHNL3_CAPT2_DMA_READ
* @param                ETIMER_CHNL3_CMPLD1_DMA_WRITE
* @param                ETIMER_CHNL3_CMPLD2_DMA_WRITE
* @param                ETIMER_CHNL4_CAPT1_DMA_READ
* @param                ETIMER_CHNL4_CAPT2_DMA_READ
* @param                ETIMER_CHNL4_CMPLD1_DMA_WRITE
* @param                ETIMER_CHNL4_CMPLD2_DMA_WRITE
* @param                ETIMER_CHNL5_CAPT1_DMA_READ
* @param                ETIMER_CHNL5_CAPT2_DMA_READ
* @param                ETIMER_CHNL5_CMPLD1_DMA_WRITE
* @param                ETIMER_CHNL5_CMPLD2_DMA_WRITE
*
* @return               NULL
*
* @details              The #ETIMER_SEL_DMA_REQUEST_0 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_BASE,ETIMER_SEL_DMA_REQUEST_0, ETIMER_CHNL0_CAPT1_DMA_READ);
* \endcode
*
******************************************************************************/
#define ETIMER_SEL_DMA_REQUEST_0

/***************************************************************************//*!
*
* @brief                Select the source of the eTimer DMA request 1.
*
* @param                ETIMER_CHNL0_CAPT1_DMA_READ
* @param                ETIMER_CHNL0_CAPT2_DMA_READ
* @param                ETIMER_CHNL0_CMPLD1_DMA_WRITE
* @param                ETIMER_CHNL0_CMPLD2_DMA_WRITE
* @param                ETIMER_CHNL1_CAPT1_DMA_READ
* @param                ETIMER_CHNL1_CAPT2_DMA_READ
* @param                ETIMER_CHNL1_CMPLD1_DMA_WRITE
* @param                ETIMER_CHNL1_CMPLD2_DMA_WRITE
* @param                ETIMER_CHNL2_CAPT1_DMA_READ
* @param                ETIMER_CHNL2_CAPT2_DMA_READ
* @param                ETIMER_CHNL2_CMPLD1_DMA_WRITE
* @param                ETIMER_CHNL2_CMPLD2_DMA_WRITE
* @param                ETIMER_CHNL3_CAPT1_DMA_READ
* @param                ETIMER_CHNL3_CAPT2_DMA_READ
* @param                ETIMER_CHNL3_CMPLD1_DMA_WRITE
* @param                ETIMER_CHNL3_CMPLD2_DMA_WRITE
* @param                ETIMER_CHNL4_CAPT1_DMA_READ
* @param                ETIMER_CHNL4_CAPT2_DMA_READ
* @param                ETIMER_CHNL4_CMPLD1_DMA_WRITE
* @param                ETIMER_CHNL4_CMPLD2_DMA_WRITE
* @param                ETIMER_CHNL5_CAPT1_DMA_READ
* @param                ETIMER_CHNL5_CAPT2_DMA_READ
* @param                ETIMER_CHNL5_CMPLD1_DMA_WRITE
* @param                ETIMER_CHNL5_CMPLD2_DMA_WRITE
*
* @return               NULL
*
* @details              The #ETIMER_SEL_DMA_REQUEST_1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(ETIMER0_BASE,ETIMER_SEL_DMA_REQUEST_1, ETIMER_CHNL0_CAPT1_DMA_READ);
* \endcode
*
******************************************************************************/
#define ETIMER_SEL_DMA_REQUEST_1


/******************************************************************************
* eTIMER bitfield masks definition
******************************************************************************/


/******************************************************************************
* eTIMER register offset definition
******************************************************************************/

#define ETIMER_COMP1_OFFSET                             0x0
#define ETIMER_COMP2_OFFSET                             0x2
#define ETIMER_CAPT1_OFFSET                             0x4
#define ETIMER_CAPT2_OFFSET                             0x6
#define ETIMER_LOAD_OFFSET                              0x8
#define ETIMER_HOLD_OFFSET                              0xA
#define ETIMER_CNTR_OFFSET                              0xC
#define ETIMER_CTRL1_OFFSET                             0xE
#define ETIMER_CTRL2_OFFSET                             0x10
#define ETIMER_CTRL3_OFFSET                             0x12
#define ETIMER_CNTR3_OFFSET                             0x12
#define ETIMER_STS_OFFSET                               0x14
#define ETIMER_INTDMA_OFFSET                            0x16
#define ETIMER_CMPLD1_OFFSET                            0x18
#define ETIMER_CMPLD2_OFFSET                            0x1A
#define ETIMER_CCCTRL_OFFSET                            0x1C
#define ETIMER_FILT_OFFSET                              0x1E
#define ETIMER_WDTOL_OFFSET                             0x100
#define ETIMER_WDTOH_OFFSET                             0x102
#define ETIMER_ENBL_OFFSET                              0x10C
#define ETIMER_DREQ0_OFFSET                             0x110
#define ETIMER_DREQ1_OFFSET                             0x112

/******************************************************************************
* eTIMER MACRO and ioctl parameters definition
******************************************************************************/

#define ETIMER_CNT_0_INPUT                              0x0
#define ETIMER_CNT_1_INPUT                              0x1
#define ETIMER_CNT_2_INPUT                              0x2
#define ETIMER_CNT_3_INPUT                              0x3
#define ETIMER_CNT_4_INPUT                              0x4
#define ETIMER_CNT_5_INPUT                              0x5
#define ETIMER_AUXIN_0                                  0x8
#define ETIMER_AUXIN_1                                  0x9
#define ETIMER_AUXIN_2                                  0xA
#define ETIMER_CNT_0_OUTPUT                             0x10
#define ETIMER_CNT_1_OUTPUT                             0x11
#define ETIMER_CNT_2_OUTPUT                             0x12
#define ETIMER_CNT_3_OUTPUT                             0x13
#define ETIMER_CNT_4_OUTPUT                             0x14
#define ETIMER_CNT_5_OUTPUT                             0x15
#define ETIMER_UP                                       0x0
#define ETIMER_DOWN                                     0x1
#define ETIMER_ROLL_OVER                                0x0
#define ETIMER_UNTIL_COMPARE                            0x1
#define ETIMER_COUNT_REPEATEDLY                         0x0
#define ETIMER_COUNT_ONCE                               0x1
#define ETIMER_IPBUS_DIV_1                              0x18
#define ETIMER_IPBUS_DIV_2                              0x19
#define ETIMER_IPBUS_DIV_4                              0x1A
#define ETIMER_IPBUS_DIV_8                              0x1B
#define ETIMER_IPBUS_DIV_16                             0x1C
#define ETIMER_IPBUS_DIV_32                             0x1D
#define ETIMER_IPBUS_DIV_64                             0x1E
#define ETIMER_IPBUS_DIV_128                            0x1F
#define ETIMER_NO_OPERATION                             0x0
#define ETIMER_RIS_EDGE_OF_PRIMARY_SOURCE               0x1
#define ETIMER_RIS_FALLING_EDGE_OF_PRI_SRC              0x2
#define ETIMER_RIS_EDGE_OF_PRI_SRC_WHILE_SEC_HIGH_ACT   0x3
#define ETIMER_QUADRATURE_MODE                          0x4
#define ETIMER_RIS_EDGE_OF_PRI_SRC_SEC_DIRECTION        0x5
#define ETIMER_SEC_SOURCE_TRIG_PRIM_COUNT               0x6
#define ETIMER_CASCADED_CNT_MODE                        0x7
#define ETIMER_SW_CONTROLLED                            0x0
#define ETIMER_CLEAR_OUTPUT_ON_COMPARE                  0x1
#define ETIMER_SET_OUTPUT_ON_COMPARE                    0x2
#define ETIMER_TOGGLE_OUTPUT_ON_COMPARE                 0x3
#define ETIMER_TOGGLE_OUTPUT_ON_ALT_COMPARE             0x4
#define ETIMER_SET_ON_COMP1_CLEAR_ON_SEC_EDGE           0x5
#define ETIMER_SET_ON_COMP2_CLEAR_ON_SEC_EDGE           0x6
#define ETIMER_SET_ON_COMPARE_CLR_ON_ROLLOVER           0x7
#define ETIMER_SET_ON_COMP1_CLEAR_ON_COMP2              0x8
#define ETIMER_SET_WHEN_ACTIVE_CLEAR_STOPED             0x9
#define ETIMER_SET_COUNT_UP_CLEAR_COUNT_DOWN            0xA
#define ETIMER_GATED_CLOCK_WHEN_ACTIVE                  0xF
#define ETIMER_DISBL                                    0x0
#define ETIMER_ENBL                                     0x1
#define ETIMER_TRUE_POLARITY                            0x0
#define ETIMER_INVERTED_POLARITY                        0x1
#define ETIMER_COINIT_USING_LOAD_REG                    0x1
#define ETIMER_COINIT_USING_CMPLD1                      0x2
#define ETIMER_LOW                                      0x1
#define ETIMER_HIGH                                     0x3
#define ETIMER_OUTPUT                                   0x1
#define ETIMER_INPUT                                    0x0
#define ETIMER_CONTINUE_NORMAL_OPERATION                0x0
#define ETIMER_HALT_COUNTER                             0x1
#define ETIMER_FORCE_OFLAG_TO_ZERO                      0x2
#define ETIMER_HALT_COUNTER_AND_FORCE                   0x3
#define ETIMER_RELOAD_ON_CATP1_EVNT                     0x1
#define ETIMER_RELOAD_ON_CATP2_EVNT                     0x2
#define ETIMER_RELOAD_ON_CATP1_AND_CAPT2_EVNT           0x3
#define ETIMER_OE_UNAFFECTED                            0x0
#define ETIMER_OE_DISABLED                              0x1
#define ETIMER_CLEAR_FLAG                               0x1
#define ETIMER_FREERUNNING                              0x0
#define ETIMER_ONESHOT                                  0x1
#define ETIMER_CAPT_FALLING_EDGE                        0x1
#define ETIMER_CAPT_RISING_EDGE                         0x2
#define ETIMER_CAPT_ANY_EDGE                            0x3
#define ETIMER_COMP1_UP_COMP2_UP                        0x0
#define ETIMER_COMP1_DOWM_COMP2_UP                      0x1
#define ETIMER_COMP1_UP_COMP2_DOWN                      0x2
#define ETIMER_COMP1_DOWM_COMP2_DOWM                    0x3
#define ETIMER_NEVER_PRELOAD                            0x0
#define ETIMER_CMPLD1_TO_COMP1_ON_COMP1                 0x2
#define ETIMER_CMPLD1_TO_COMP1_ON_COMP2                 0x3
#define ETIMER_CMPLD2_TO_COMP1_ON_COMP1                 0x4
#define ETIMER_CMPLD2_TO_COMP1_ON_COMP2                 0x5
#define ETIMER_CMPLD1_TO_CNTR_ON_COMP1                  0x6
#define ETIMER_CMPLD1_TO_CNTR_ON_COMP2                  0x7
#define ETIMER_CMPLD1_TO_COMP2_ON_COMP1                 0x2
#define ETIMER_CMPLD1_TO_COMP2_ON_COMP2                 0x3
#define ETIMER_CMPLD2_TO_COMP2_ON_COMP1                 0x4
#define ETIMER_CMPLD2_TO_COMP2_ON_COMP2                 0x5
#define ETIMER_CMPLD2_TO_CNTR_ON_COMP1                  0x6
#define ETIMER_CMPLD2_TO_CNTR_ON_COMP2                  0x7
#define ETIMER_CHANNEL1                                 0x1
#define ETIMER_CHANNEL2                                 0x2
#define ETIMER_CHANNEL3                                 0x4
#define ETIMER_CHANNEL4                                 0x8
#define ETIMER_CHANNEL5                                 0x10
#define ETIMER_CHANNEL6                                 0x20
#define ETIMER_CHNL0_CAPT1_DMA_READ                     0x0
#define ETIMER_CHNL0_CAPT2_DMA_READ                     0x1
#define ETIMER_CHNL0_CMPLD1_DMA_WRITE                   0x2
#define ETIMER_CHNL0_CMPLD2_DMA_WRITE                   0x3
#define ETIMER_CHNL1_CAPT1_DMA_READ                     0x4
#define ETIMER_CHNL1_CAPT2_DMA_READ                     0x5
#define ETIMER_CHNL1_CMPLD1_DMA_WRITE                   0x6
#define ETIMER_CHNL1_CMPLD2_DMA_WRITE                   0x7
#define ETIMER_CHNL2_CAPT1_DMA_READ                     0x8
#define ETIMER_CHNL2_CAPT2_DMA_READ                     0x9
#define ETIMER_CHNL2_CMPLD1_DMA_WRITE                   0xA
#define ETIMER_CHNL2_CMPLD2_DMA_WRITE                   0xB
#define ETIMER_CHNL3_CAPT1_DMA_READ                     0xC
#define ETIMER_CHNL3_CAPT2_DMA_READ                     0xD
#define ETIMER_CHNL3_CMPLD1_DMA_WRITE                   0xE
#define ETIMER_CHNL3_CMPLD2_DMA_WRITE                   0xF
#define ETIMER_CHNL4_CAPT1_DMA_READ                     0x10
#define ETIMER_CHNL4_CAPT2_DMA_READ                     0x11
#define ETIMER_CHNL4_CMPLD1_DMA_WRITE                   0x12
#define ETIMER_CHNL4_CMPLD2_DMA_WRITE                   0x13
#define ETIMER_CHNL5_CAPT1_DMA_READ                     0x14
#define ETIMER_CHNL5_CAPT2_DMA_READ                     0x15
#define ETIMER_CHNL5_CMPLD1_DMA_WRITE                   0x16
#define ETIMER_CHNL5_CMPLD2_DMA_WRITE                   0x17

/******************************************************************************
* eTIMER ioctl commands implementation
******************************************************************************/

#define ioctlETIMER_GET_COMP1_VALUE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_COMP1_OFFSET))

#define ioctlETIMER_WRITE_VALUE_REG_COMP1(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_COMP1_OFFSET)) = (param)

#define ioctlETIMER_GET_COMP2_VALUE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_COMP2_OFFSET))

#define ioctlETIMER_WRITE_VALUE_REG_COMP2(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_COMP2_OFFSET)) = (param)

#define ioctlETIMER_GET_CAPT1_VALUE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CAPT1_OFFSET))

#define ioctlETIMER_GET_CAPT2_VALUE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CAPT2_OFFSET))

#define ioctlETIMER_WRITE_VALUE_REG_LOAD(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_LOAD_OFFSET)) = (param)

#define ioctlETIMER_READ_VALUE_REG_HOLD(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_HOLD_OFFSET))

#define ioctlETIMER_READ_VALUE_REG_CNTR(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CNTR_OFFSET))

#define ioctlETIMER_WRITE_VALUE_REG_CNTR(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CNTR_OFFSET)) = (param)

#define ioctlETIMER_READ_VALUE_REG_CTRL1(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL1_OFFSET))

#define ioctlETIMER_SET_SEC_COUNT_SOURCE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL1_OFFSET)) = (param)

#define ioctlETIMER_SET_COUNT_DIRECTION(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL1_OFFSET)) = (param<<5)

#define ioctlETIMER_SET_COUNT_LENGTH(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL1_OFFSET)) = (param<<6)

#define ioctlETIMER_SET_ONCE_COUNT(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL1_OFFSET)) = (param<<7)

#define ioctlETIMER_SET_PRIM_COUNT_SOURCE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL1_OFFSET)) = (param<<8)

#define ioctlETIMER_SELECT_COUNT_MODE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL1_OFFSET)) = (param<<13)

#define ioctlETIMER_READ_VALUE_REG_CTRL2(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL2_OFFSET))

#define ioctlETIMER_SEL_OUTMODE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL2_OFFSET)) = (param)

#define ioctlETIMER_MASTER_MODE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL2_OFFSET)) = (param<<4)

#define ioctlETIMER_SEL_OUT_POL(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL2_OFFSET)) = (param<<5)

#define ioctlETIMER_SET_PRIMARY_INP_POLARITY(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL2_OFFSET)) = (param<<6)

#define ioctlETIMER_SET_SECONDARY_INP_POLARITY(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL2_OFFSET)) = (param<<7)

#define ioctlETIMER_SET_CO_CHANNEL_INIT(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL2_OFFSET)) = (param<<8)

#define ioctlETIMER_CO_CHANNEL_OFLAG_FORCE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL2_OFFSET)) = (param<<10)

#define ioctlETIMER_FORCE_OFLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL2_OFFSET)) = (param<<11)

#define ioctlETIMER_READ_SEC_SRC_STATUS(etimerAddr,param) \
        (*((volatile tU16 *)(etimerAddr + ETIMER_CTRL2_OFFSET))) >>13

#define ioctlETIMER_SET_REDUNDANT_CHECKING(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL2_OFFSET)) = (param<<14)

#define ioctlETIMER_SET_DIR_EXTRN_PIN(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL2_OFFSET)) = (param<<15)

#define ioctlETIMER_READ_VALUE_REG_CTRL3(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL3_OFFSET))

#define ioctlETIMER_SET_DEBUG_OPERAITON(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CNTR3_OFFSET)) = (param)

#define ioctlETIMER_READ_CAPT1_FIFO_CNT(etimerAddr,param) \
        (*((volatile tU16 *)(etimerAddr + ETIMER_CTRL3_OFFSET))) >>2

#define ioctlETIMER_READ_CAPT2_FIFO_CNT(etimerAddr,param) \
        (*((volatile tU16 *)(etimerAddr + ETIMER_CTRL3_OFFSET))) >>5

#define ioctlETIMER_SET_RELOAD_ON_CAPT_MODE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL3_OFFSET)) = (param<<13)

#define ioctlETIMER_SET_STOP_OPERATION(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CTRL3_OFFSET)) = (param<<15)

#define ioctlETIMER_READ_VALUE_REG_STS(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET))

#define ioctlETIMER_READ_COMPARE_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET))

#define ioctlETIMER_CLEAR_COMPARE_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET)) = (param)

#define ioctlETIMER_READ_COMP1_FLAG(etimerAddr,param) \
        (*((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET))) >>1

#define ioctlETIMER_CLEAR_COMP1_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET)) = (param<<1)

#define ioctlETIMER_READ_COMP2_FLAG(etimerAddr,param) \
        (*((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET))) >>2

#define ioctlETIMER_CLEAR_COMP2_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET)) = (param<<2)

#define ioctlETIMER_READ_TMR_OVERFLOW_FLAG(etimerAddr,param) \
        (*((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET))) >>3

#define ioctlETIMER_CLEAR_TMR_OVERFLOW_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET)) = (param<<3)

#define ioctlETIMER_READ_INPUT_EDGE_LOW_FLAG(etimerAddr,param) \
        (*((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET))) >>4

#define ioctlETIMER_CLEAR_INPUT_EDGE_LOW_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET)) = (param<<4)

#define ioctlETIMER_READ_INPUT_EDGE_HIGH_FLAG(etimerAddr,param) \
        (*((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET))) >>5

#define ioctlETIMER_CLEAR_INPUT_EDGE_HIGH_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET)) = (param<<5)

#define ioctlETIMER_READ_CAPTURE1_FLAG(etimerAddr,param) \
        (*((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET))) >>6

#define ioctlETIMER_CLEAR_CAPTURE1_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET)) = (param<<6)

#define ioctlETIMER_READ_CAPTURE2_FLAG(etimerAddr,param) \
        (*((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET))) >>7

#define ioctlETIMER_CLEAR_CAPTURE2_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET)) = (param<<7)

#define ioctlETIMER_READ_RDND_CHNL_FLAG(etimerAddr,param) \
        (*((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET))) >>8

#define ioctlETIMER_CLEAR_RDND_CHNL_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET)) = (param<<8)

#define ioctlETIMER_READ_WATCHDOG_FLAG(etimerAddr,param) \
        (*((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET))) >>9

#define ioctlETIMER_CLEAR_WATCHDOG_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_STS_OFFSET)) = (param<<9)

#define ioctlETIMER_READ_VALUE_REG_INTDMA(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET))

#define ioctlETIMER_SET_COMPARE_INT_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET)) = (param)

#define ioctlETIMER_SET_COMP1_INT_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET)) = (param<<1)

#define ioctlETIMER_SET_COMP2_INT_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET)) = (param<<2)

#define ioctlETIMER_SET_TMR_OVERFLOW_INT_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET)) = (param<<3)

#define ioctlETIMER_SET_INP_EDGE_LOW_INT_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET)) = (param<<4)

#define ioctlETIMER_SET_INP_EDGE_HIGH_INT_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET)) = (param<<5)

#define ioctlETIMER_SET_CAPT1_INT_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET)) = (param<<6)

#define ioctlETIMER_SET_CAPT2_INT_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET)) = (param<<7)

#define ioctlETIMER_SET_RDND_CHNL_INT_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET)) = (param<<8)

#define ioctlETIMER_SET_WATCHDOG_INT_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET)) = (param<<9)

#define ioctlETIMER_SET_CMPLD1DE_INT_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET)) = (param<<12)

#define ioctlETIMER_SET_CMPLD2DE_INT_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET)) = (param<<13)

#define ioctlETIMER_SET_ICF1DE_INT_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET)) = (param<<14)

#define ioctlETIMER_SET_ICF2DE_INT_FLAG(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_INTDMA_OFFSET)) = (param<<15)

#define ioctlETIMER_READ_VALUE_REG_CMPLD1(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CMPLD1_OFFSET))

#define ioctlETIMER_WRITE_VALUE_REG_CMPLD1(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CMPLD1_OFFSET)) = (param)

#define ioctlETIMER_READ_VALUE_REG_CMPLD2(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CMPLD2_OFFSET))

#define ioctlETIMER_WRITE_VALUE_REG_CMPLD2(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CMPLD2_OFFSET)) = (param)

#define ioctlETIMER_READ_VALUE_REG_CCCTRL(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CCCTRL_OFFSET))

#define ioctlETIMER_SET_CAPTURE_OPER(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CCCTRL_OFFSET)) = (param)

#define ioctlETIMER_SET_CAPTURE_OPER_MODE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CCCTRL_OFFSET)) = (param<<1)

#define ioctlETIMER_SET_CAPT1_MODE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CCCTRL_OFFSET)) = (param<<4)

#define ioctlETIMER_SET_CAPT2_MODE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CCCTRL_OFFSET)) = (param<<6)

#define ioctlETIMER_SET_COMPARE_MODE(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CCCTRL_OFFSET)) = (param<<8)

#define ioctlETIMER_SET_COMPARE_LOAD_CTRL1(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CCCTRL_OFFSET)) = (param<<10)

#define ioctlETIMER_SET_COMPARE_LOAD_CTRL2(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_CCCTRL_OFFSET)) = (param<<13)

#define ioctlETIMER_READ_VALUE_REG_FILT(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_FILT_OFFSET))

#define ioctlETIMER_SET_FLT_SAMPL_PERIOD(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_FILT_OFFSET)) = (param)

#define ioctlETIMER_SET_FLT_SAMPL_COUNT(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_FILT_OFFSET)) = (param<<8)

#define ioctlETIMER_READ_VALUE_REG_WDTOL(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_WDTOL_OFFSET))

#define ioctlETIMER_SET_WATCHDOG_TIMEOUT_LOW(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_WDTOL_OFFSET)) = (param)

#define ioctlETIMER_READ_VALUE_REG_WDTOH(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_WDTOH_OFFSET))

#define ioctlETIMER_SET_WATCHDOG_TIMEOUT_HIGH(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_WDTOH_OFFSET)) = (param)

#define ioctlETIMER_READ_VALUE_REG_ENBL(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_ENBL_OFFSET))

#define ioctlETIMER_ENBL_CHNL(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_ENBL_OFFSET)) = (param)

#define ioctlETIMER_SEL_DMA_REQUEST_0(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_DREQ0_OFFSET)) = (param)

#define ioctlETIMER_SEL_DMA_REQUEST_1(etimerAddr,param) \
        *((volatile tU16 *)(etimerAddr + ETIMER_DREQ1_OFFSET)) = (param)

#ifdef __cplusplus
}
#endif

#endif /* _MPC5643L_ETIMER_LLD_H_ */
