/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!*
* @file       MPC5643L_FlexPWM_LLD.h
*
* @author     r63172
*
* @version    1.0.1.0
*
* @date       Jul-13-2012
*
* @brief      FlexPWM low level driver module for MPC5643L.
*
*******************************************************************************
*
* This file includes initial setting and MACRO definitions of MPC5643L FlexPWM
* peripheral module.
*
******************************************************************************/

#ifndef _MPC5643L_FLEXPWM_LLD_H_
#define _MPC5643L_FLEXPWM_LLD_H_

#ifdef __cplusplus
extern "C" {
#endif

#define FLEXPWM0_BASE                                   0xFFE24000
#define FLEXPWM0_SUB0_BASE                              0xFFE24000
#define FLEXPWM0_SUB1_BASE                              0xFFE24050
#define FLEXPWM0_SUB2_BASE                              0xFFE240A0
#define FLEXPWM0_SUB3_BASE                              0xFFE240F0
#define FLEXPWM1_BASE                                   0xFFE28000
#define FLEXPWM1_SUB0_BASE                              0xFFE28000
#define FLEXPWM1_SUB1_BASE                              0xFFE28050
#define FLEXPWM1_SUB2_BASE                              0xFFE280A0
#define FLEXPWM1_SUB3_BASE                              0xFFE280F0

/******************************************************************************
* FlexPWM ioctl commands definitions
******************************************************************************/
/***************************************************************************//*!
*
* @brief                Get actual value of FlexPWM submodule counter.
*
* @param                NULL
*
* @return               State of the signed 16-bit submodule counter.
*
* @details              The #FLEXPWM_GET_COUNTER_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_COUNTER_VALUE, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_COUNTER_VALUE

/***************************************************************************//*!
*
* @brief                Set FlexPWM submodule counter initial value.
*
* @param                (value signed 16bit)
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_COUNTER_INIT_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_COUNTER_INIT_VALUE, (value signed 16bit));
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_COUNTER_INIT_VALUE

/***************************************************************************//*!
*
* @brief                Get FlexPWM submodule counter initial value.
*
* @param                NULL
*
* @return               Submodule counter initial value.
*
* @details              The #FLEXPWM_GET_COUNTER_INIT_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_COUNTER_INIT_VALUE, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_COUNTER_INIT_VALUE

/***************************************************************************//*!
*
* @brief                Debug Enable
*
* @param                FLEXPWM_STOP
* @param                FLEXPWM_RUN
*
* @return               NULL
*
* @details              The #FLEXPWM_DEBUG_OPERATION ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_DEBUG_OPERATION, FLEXPWM_STOP);
* \endcode
*
******************************************************************************/
#define FLEXPWM_DEBUG_OPERATION

/***************************************************************************//*!
*
* @brief                WAIT Enable
*
* @param                FLEXPWM_STOP
* @param                FLEXPWM_RUN
*
* @return               NULL
*
* @details              The #FLEXPWM_WAIT_OPERATION ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_WAIT_OPERATION, FLEXPWM_STOP);
* \endcode
*
******************************************************************************/
#define FLEXPWM_WAIT_OPERATION

/***************************************************************************//*!
*
* @brief                Independent or Complementary Pair Operation
*
* @param                FLEXPWM_COMPLEMENTARY
* @param                FLEXPWM_INDEPENDENT
*
* @return               NULL
*
* @details              The #FLEXPWM_CHANNEL_OPERATION ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_CHANNEL_OPERATION, FLEXPWM_COMPLEMENTARY);
* \endcode
*
******************************************************************************/
#define FLEXPWM_CHANNEL_OPERATION

/***************************************************************************//*!
*
* @brief                Set PWM A (PWM 23) initial state
*
* @param                FLEXPWM_LOW
* @param                FLEXPWM_HIGH
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_PWMA_INIT_STATE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_PWMA_INIT_STATE, FLEXPWM_LOW);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMA_INIT_STATE

/***************************************************************************//*!
*
* @brief                Set PWM B (PWM 45) initial state
*
* @param                FLEXPWM_LOW
* @param                FLEXPWM_HIGH
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_PWMB_INIT_STATE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_PWMB_INIT_STATE, FLEXPWM_LOW);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMB_INIT_STATE

/***************************************************************************//*!
*
* @brief                Set PWM X initial state
*
* @param                FLEXPWM_LOW
* @param                FLEXPWM_HIGH
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_PWMX_INIT_STATE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_PWMX_INIT_STATE, FLEXPWM_LOW);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMX_INIT_STATE

/***************************************************************************//*!
*
* @brief                Submodule counter initialization source configuration
*
* @param                FLEXPWM_INIT_ON_LOCAL_SOURCE
* @param                FLEXPWM_INIT_ON_MASTER_RELOAD
* @param                FLEXPWM_INIT_ON_MASTER_SYNC
* @param                FLEXPWM_INIT_ON_EXT_SYNC
*
* @return               NULL
*
* @details              The #FLEXPWM_COUNTER_INITIALIZATION ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_COUNTER_INITIALIZATION, FLEXPWM_INIT_ON_LOCAL_SOURCE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_COUNTER_INITIALIZATION

/***************************************************************************//*!
*
* @brief                Enable/disable counter initialization on FORCE_OUT signal
*
* @param                FLEXPWM_DISABLE
* @param                FLEXPWM_ENABLE
*
* @return               NULL
*
* @details              The #FLEXPWM_FORCEOUT_COUNTER_INITIALIZATION ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_FORCEOUT_COUNTER_INITIALIZATION, FLEXPWM_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_FORCEOUT_COUNTER_INITIALIZATION

/***************************************************************************//*!
*
* @brief                Select source of the FORCE_OUT signal
*
* @param                FLEXPWM_FORCEOUT_ON_LOCAL_FORCE
* @param                FLEXPWM_FORCEOUT_ON_MASTER_FORCE
* @param                FLEXPWM_FORCEOUT_ON_LOCAL_RELOAD
* @param                FLEXPWM_FORCEOUT_ON_MASTER_RELOAD
* @param                FLEXPWM_FORCEOUT_ON_LOCAL_SYNC
* @param                FLEXPWM_FORCEOUT_ON_MASTER_SYNC
* @param                FLEXPWM_FORCEOUT_ON_EXT_FORCE
*
* @return               NULL
*
* @details              The #FLEXPWM_FORCEOUT_SOURCE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_FORCEOUT_SOURCE, FLEXPWM_FORCEOUT_ON_LOCAL_FORCE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_FORCEOUT_SOURCE

/***************************************************************************//*!
*
* @brief                Select source of the RELOAD signal for the submodule
*
* @param                FLEXPWM_RELOAD_ON_LOCAL_RELOAD
* @param                FLEXPWM_RELOAD_ON_MASTER_RELOAD
*
* @return               NULL
*
* @details              The #FLEXPWM_RELOAD_SOURCE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_RELOAD_SOURCE, FLEXPWM_RELOAD_ON_LOCAL_RELOAD);
* \endcode
*
******************************************************************************/
#define FLEXPWM_RELOAD_SOURCE

/***************************************************************************//*!
*
* @brief                Select source of the CLOCK signal for the submodule
*
* @param                FLEXPWM_IPBUS
* @param                FLEXPWM_EXT_CLK
* @param                FLEXPWM_SUB0_CLK
*
* @return               NULL
*
* @details              The #FLEXPWM_CLOCK_SOURCE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_CLOCK_SOURCE, FLEXPWM_IPBUS);
* \endcode
*
******************************************************************************/
#define FLEXPWM_CLOCK_SOURCE

/***************************************************************************//*!
*
* @brief                Module reload frequency
*
* @param                FLEXPWM_RELOAD_EVERY_OPPORTUNITY
* @param                FLEXPWM_RELOAD_EVERY_2_OPPORTUNITIES
* @param                FLEXPWM_RELOAD_EVERY_3_OPPORTUNITIES
* @param                FLEXPWM_RELOAD_EVERY_4_OPPORTUNITIES
* @param                FLEXPWM_RELOAD_EVERY_5_OPPORTUNITIES
* @param                FLEXPWM_RELOAD_EVERY_6_OPPORTUNITIES
* @param                FLEXPWM_RELOAD_EVERY_7_OPPORTUNITIES
* @param                FLEXPWM_RELOAD_EVERY_8_OPPORTUNITIES
* @param                FLEXPWM_RELOAD_EVERY_9_OPPORTUNITIES
* @param                FLEXPWM_RELOAD_EVERY_10_OPPORTUNITIES
* @param                FLEXPWM_RELOAD_EVERY_11_OPPORTUNITIES
* @param                FLEXPWM_RELOAD_EVERY_12_OPPORTUNITIES
* @param                FLEXPWM_RELOAD_EVERY_13_OPPORTUNITIES
* @param                FLEXPWM_RELOAD_EVERY_14_OPPORTUNITIES
* @param                FLEXPWM_RELOAD_EVERY_15_OPPORTUNITIES
* @param                FLEXPWM_RELOAD_EVERY_16_OPPORTUNITIES
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_RELOAD_FREQUENCY ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_RELOAD_FREQUENCY, FLEXPWM_RELOAD_EVERY_OPPORTUNITY);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_RELOAD_FREQUENCY

/***************************************************************************//*!
*
* @brief                Enable/disable half cycle reload
*
* @param                FLEXPWM_DISABLE
* @param                FLEXPWM_ENABLE
*
* @return               NULL
*
* @details              The #FLEXPWM_HALF_RELOAD ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_HALF_RELOAD, FLEXPWM_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_HALF_RELOAD

/***************************************************************************//*!
*
* @brief                Enable/disable full cycle reload
*
* @param                FLEXPWM_DISABLE
* @param                FLEXPWM_ENABLE
*
* @return               NULL
*
* @details              The #FLEXPWM_FULL_RELOAD ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_FULL_RELOAD, FLEXPWM_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_FULL_RELOAD

/***************************************************************************//*!
*
* @brief                Clock prescaler configuration
*
* @param                FLEXPWM_PRESCALER_DIV_BY_1
* @param                FLEXPWM_PRESCALER_DIV_BY_2
* @param                FLEXPWM_PRESCALER_DIV_BY_4
* @param                FLEXPWM_PRESCALER_DIV_BY_8
* @param                FLEXPWM_PRESCALER_DIV_BY_16
* @param                FLEXPWM_PRESCALER_DIV_BY_32
* @param                FLEXPWM_PRESCALER_DIV_BY_64
* @param                FLEXPWM_PRESCALER_DIV_BY_128
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_CLOCK_PRESCALER ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_CLOCK_PRESCALER, FLEXPWM_PRESCALER_DIV_BY_1);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_CLOCK_PRESCALER

/***************************************************************************//*!
*
* @brief                Enable/disable PWM double switching
*
* @param                FLEXPWM_DISABLE
* @param                FLEXPWM_ENABLE
*
* @return               NULL
*
* @details              The #FLEXPWM_DOUBLE_SWITCHING ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_DOUBLE_SWITCHING, FLEXPWM_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_DOUBLE_SWITCHING

/***************************************************************************//*!
*
* @brief                Get register INIT value
*
* @param                NULL
*
* @return               Submodule INIT register value
*
* @details              The #FLEXPWM_GET_INIT ioctl command TBD
*
* @par Code Example:
*
* \code
* //
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_INIT, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_INIT

/***************************************************************************//*!
*
* @brief                Set value register VAL0
*
* @param                (value signed 16bit)
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_VAL0 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_VAL0, (value signed 16bit));
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_VAL0

/***************************************************************************//*!
*
* @brief                Get register VAL0 value
*
* @param                NULL
*
* @return               Submodule VAL0 register value
*
* @details              The #FLEXPWM_GET_VAL0 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_VAL0, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_VAL0

/***************************************************************************//*!
*
* @brief                Set value register VAL1
*
* @param                (value signed 16bit)
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_VAL1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_VAL1, (value signed 16bit));
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_VAL1

/***************************************************************************//*!
*
* @brief                Get register VAL1 value
*
* @param                NULL
*
* @return               Submodule VAL1 register value
*
* @details              The #FLEXPWM_GET_VAL1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_VAL1, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_VAL1

/***************************************************************************//*!
*
* @brief                Set value register VAL2
*
* @param                (value signed 16bit)
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_VAL2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_VAL2, (value signed 16bit));
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_VAL2

/***************************************************************************//*!
*
* @brief                Get register VAL2 value
*
* @param                NULL
*
* @return               Submodule VAL2 register value
*
* @details              The #FLEXPWM_GET_VAL2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_VAL2, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_VAL2

/***************************************************************************//*!
*
* @brief                Set value register VAL3
*
* @param                (value signed 16bit)
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_VAL3 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_VAL3, (value signed 16bit));
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_VAL3

/***************************************************************************//*!
*
* @brief                Get register VAL3 value
*
* @param                NULL
*
* @return               Submodule VAL3 register value
*
* @details              The #FLEXPWM_GET_VAL3 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_VAL3, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_VAL3

/***************************************************************************//*!
*
* @brief                Set value register VAL4
*
* @param                (value signed 16bit)
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_VAL4 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_VAL4, (value signed 16bit));
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_VAL4

/***************************************************************************//*!
*
* @brief                Get register VAL4 value
*
* @param                NULL
*
* @return               Submodule VAL4 register value
*
* @details              The #FLEXPWM_GET_VAL4 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_VAL4, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_VAL4

/***************************************************************************//*!
*
* @brief                Set value register VAL5
*
* @param                (value signed 16bit)
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_VAL5 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_VAL5, (value signed 16bit));
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_VAL5

/***************************************************************************//*!
*
* @brief                Get register VAL5 value
*
* @param                NULL
*
* @return               Submodule VAL5 register value
*
* @details              The #FLEXPWM_GET_VAL5 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_VAL5, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_VAL5

/***************************************************************************//*!
*
* @brief                PWM A output polarity configuration
*
* @param                FLEXPWM_ACTIVE_HIGH
* @param                FLEXPWM_ACTIVE_LOW
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_PWMA_OUTPUT_POLARITY ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_PWMA_OUTPUT_POLARITY, FLEXPWM_ACTIVE_HIGH);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMA_OUTPUT_POLARITY

/***************************************************************************//*!
*
* @brief                PWM B output polarity configuration
*
* @param                FLEXPWM_ACTIVE_HIGH
* @param                FLEXPWM_ACTIVE_LOW
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_PWMB_OUTPUT_POLARITY ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_PWMB_OUTPUT_POLARITY, FLEXPWM_ACTIVE_HIGH);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMB_OUTPUT_POLARITY

/***************************************************************************//*!
*
* @brief                PWM X output polarity configuration
*
* @param                FLEXPWM_ACTIVE_HIGH
* @param                FLEXPWM_ACTIVE_LOW
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_PWMX_OUTPUT_POLARITY ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_PWMX_OUTPUT_POLARITY, FLEXPWM_ACTIVE_HIGH);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMX_OUTPUT_POLARITY

/***************************************************************************//*!
*
* @brief                PWMA output state during fault conditions and STOP mode.
*
* @param                FLEXPWM_LOW
* @param                FLEXPWM_HIGH
* @param                FLEXPWM_TRISTATED
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_PWMA_FAULT_STATE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_PWMA_FAULT_STATE, FLEXPWM_LOW);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMA_FAULT_STATE

/***************************************************************************//*!
*
* @brief                PWMB output state during fault conditions and STOP mode.
*
* @param                FLEXPWM_LOW
* @param                FLEXPWM_HIGH
* @param                FLEXPWM_TRISTATED
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_PWMB_FAULT_STATE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_PWMB_FAULT_STATE, FLEXPWM_LOW);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMB_FAULT_STATE

/***************************************************************************//*!
*
* @brief                PWMX output state during fault conditions and STOP mode.
*
* @param                FLEXPWM_LOW
* @param                FLEXPWM_HIGH
* @param                FLEXPWM_TRISTATED
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_PWMX_FAULT_STATE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_PWMX_FAULT_STATE, FLEXPWM_LOW);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMX_FAULT_STATE

/***************************************************************************//*!
*
* @brief                Get register update flag
*
* @param                NULL
*
* @return               Returns logic 1 if least one of the double buffered registers has been updated since the last reload.
*
* @details              The #FLEXPWM_GET_REGISTER_UPDATE_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_REGISTER_UPDATE_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_REGISTER_UPDATE_FLAG

/***************************************************************************//*!
*
* @brief                Get reload error flag
*
* @param                NULL
*
* @return               Returns logic 1 if a reload cycle occurs while LDOK is 0 and the double buffered registers
are in a non-coherent state (RUF = 1).
*
* @details              The #FLEXPWM_GET_RELOAD_ERROR_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_RELOAD_ERROR_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_RELOAD_ERROR_FLAG


/***************************************************************************//*!
*
* @brief                Get reload flag
*
* @param                NULL
*
* @return               Returns logic 1 if new reload occurred since last reload clearing.
*
* @details              The #FLEXPWM_GET_RELOAD_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_RELOAD_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_RELOAD_FLAG

/***************************************************************************//*!
*
* @brief                Clear reload flag
*
* @param                NULL
*
* @return               NULL
*
* @details              The #FLEXPWM_CLEAR_RELOAD_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_CLEAR_RELOAD_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_CLEAR_RELOAD_FLAG

/***************************************************************************//*!
*
* @brief                Get capture flag X1
*
* @param                NULL
*
* @return               Returns logic 1 if the word count of the Capture X1 FIFO exceeds the capture watermark value (CFXWM).
*
* @details              The #FLEXPWM_GET_CAPTX1_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_CAPTX1_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_CAPTX1_FLAG

/***************************************************************************//*!
*
* @brief                Get capture flag X0
*
* @param                NULL
*
* @return               Returns logic 1 if the word count of the Capture X0 FIFO exceeds the capture watermark value (CFXWM).
*
* @details              The #FLEXPWM_GET_CAPTX0_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_CAPTX0_FLAG, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_CAPTX0_FLAG

/***************************************************************************//*!
*
* @brief                Get filtered fault
*
* @param               	FLEXPWM_FAULT_0
* @param                FLEXPWM_FAULT_1
* @param                FLEXPWM_FAULT_2
* @param                FLEXPWM_FAULT_3
*
* @return               Returns logic 1 if a fault condition appears on the filtered FAULTx pin.
*
* @details              The #FLEXPWM_GET_FAULT ioctl command TBD
*
* @par Code Example:
*
* \code
* //
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_BASE,FLEXPWM_GET_FAULT, param);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_FAULT

/***************************************************************************//*!
*
* @brief                Get fault flag
*
* @param               	FLEXPWM_FAULT_0
* @param                FLEXPWM_FAULT_1
* @param                FLEXPWM_FAULT_2
* @param                FLEXPWM_FAULT_3
*
* @return               Returns logic 1 if a fault condition appears on the fault flag FFLAGx pin.
*
* @details              The #FLEXPWM_GET_FAULT_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* //
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_BASE,FLEXPWM_GET_FAULT_FLAG, param);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_FAULT_FLAG

/***************************************************************************//*!
*
* @brief                Clear all fault flag bits
*
* @param               	NULL
*
* @return               NULL
*
* @details              The #FLEXPWM_CLEAR_ALL_FAULT_FLAGS ioctl command TBD
*
* @par Code Example:
*
* \code
* //
*
* ioctl(FLEXPWM0_BASE,FLEXPWM_CLEAR_ALL_FAULT_FLAGS, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_CLEAR_ALL_FAULT_FLAGS

/***************************************************************************//*!
*
* @brief                Get VALx compare flag
*
* @param                FLEXPWM_VAL0
* @param                FLEXPWM_VAL1
* @param                FLEXPWM_VAL2
* @param                FLEXPWM_VAL3
* @param                FLEXPWM_VAL4
* @param                FLEXPWM_VAL5
*
* @return               Returns logic 1 if the submodule counter value matches the value of the selected VAL register
*
* @details              The #FLEXPWM_GET_VAL_COMPARE_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_VAL_COMPARE_FLAG, FLEXPWM_VAL0);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_VAL_COMPARE_FLAG

/***************************************************************************//*!
*
* @brief                Clear VALx compare flag
*
* @param                FLEXPWM_VAL0
* @param                FLEXPWM_VAL1
* @param                FLEXPWM_VAL2
* @param                FLEXPWM_VAL3
* @param                FLEXPWM_VAL4
* @param                FLEXPWM_VAL5
*
* @return               NULL
*
* @details              The #FLEXPWM_CLEAR_VAL_COMPARE_FLAG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_CLEAR_VAL_COMPARE_FLAG, FLEXPWM_VAL0);
* \endcode
*
******************************************************************************/
#define FLEXPWM_CLEAR_VAL_COMPARE_FLAG

/***************************************************************************//*!
*
* @brief                Enable/disable reload error interrupt
*
* @param                FLEXPWM_DISABLE
* @param                FLEXPWM_ENABLE
*
* @return               NULL
*
* @details              The #FLEXPWM_RELOAD_ERROR_INT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_RELOAD_ERROR_INT, FLEXPWM_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_RELOAD_ERROR_INT

/***************************************************************************//*!
*
* @brief                Enable/disable reload interrupt
*
* @param                FLEXPWM_DISABLE
* @param                FLEXPWM_ENABLE
*
* @return               NULL
*
* @details              The #FLEXPWM_RELOAD_INT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_RELOAD_INT, FLEXPWM_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_RELOAD_INT

/***************************************************************************//*!
*
* @brief                Enable/disable capture X1 interrupt
*
* @param                FLEXPWM_DISABLE
* @param                FLEXPWM_ENABLE
*
* @return               NULL
*
* @details              The #FLEXPWM_CAPTURE_X1_INT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_CAPTURE_X1_INT, FLEXPWM_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_CAPTURE_X1_INT

/***************************************************************************//*!
*
* @brief                Enable/disable capture X0 interrupt
*
* @param                FLEXPWM_DISABLE
* @param                FLEXPWM_ENABLE
*
* @return               NULL
*
* @details              The #FLEXPWM_CAPTURE_X0_INT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_CAPTURE_X0_INT, FLEXPWM_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_CAPTURE_X0_INT

/***************************************************************************//*!
*
* @brief                Disable VAL compare interrupt
*
* @param                FLEXPWM_VAL0
* @param                FLEXPWM_VAL1
* @param                FLEXPWM_VAL2
* @param                FLEXPWM_VAL3
* @param                FLEXPWM_VAL4
* @param                FLEXPWM_VAL5
*
* @return               NULL
*
* @details              The #FLEXPWM_DISABLE_VAL_COMPARE_INT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_DISABLE_VAL_COMPARE_INT, FLEXPWM_VAL0);
* \endcode
*
******************************************************************************/
#define FLEXPWM_DISABLE_VAL_COMPARE_INT

/***************************************************************************//*!
*
* @brief                Enable VAL compare interrupt
*
* @param                FLEXPWM_VAL0
* @param                FLEXPWM_VAL1
* @param                FLEXPWM_VAL2
* @param                FLEXPWM_VAL3
* @param                FLEXPWM_VAL4
* @param                FLEXPWM_VAL5
*
* @return               NULL
*
* @details              The #FLEXPWM_ENABLE_VAL_COMPARE_INT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_ENABLE_VAL_COMPARE_INT, FLEXPWM_VAL0);
* \endcode
*
******************************************************************************/
#define FLEXPWM_ENABLE_VAL_COMPARE_INT

/***************************************************************************//*!
*
* @brief                Enable/disable DMA write request for VALx registers when RF is set.
*
* @param                FLEXPWM_DISABLE
* @param                FLEXPWM_ENABLE
*
* @return               NULL
*
* @details              The #FLEXPWM_DMA_VAL_WRITE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_DMA_VAL_WRITE, FLEXPWM_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_DMA_VAL_WRITE

/***************************************************************************//*!
*
* @brief                Capture FIFO watermark control
*
* @param                FLEXPWM_WM_OR
* @param                FLEXPWM_WM_AND
*
* @return               NULL
*
* @details              The #FLEXPWM_FIFO_WM_CONTROL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_FIFO_WM_CONTROL, FLEXPWM_WM_OR);
* \endcode
*
******************************************************************************/
#define FLEXPWM_FIFO_WM_CONTROL

/***************************************************************************//*!
*
* @brief                Select source of enabling DMA read request for the capture FIFOs.
*
* @param                FLEXPWM_DISABLE
* @param                FLEXPWM_DMA_READ_ON_FIFO_WM
* @param                FLEXPWM_DMA_READ_ON_LOCAL_SYNC
* @param                FLEXPWM_DMA_READ_ON_LOCAL_RELOAD
*
* @return               NULL
*
* @details              The #FLEXPWM_DMA_FIFO_READ ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_DMA_FIFO_READ, FLEXPWM_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_DMA_FIFO_READ

/***************************************************************************//*!
*
* @brief                Capture X1 FIFO DMA Enable/Disable
*
* @param                FLEXPWM_DISABLE
* @param                FLEXPWM_ENABLE
*
* @return               NULL
*
* @details              The #FLEXPWM_CAPTURE_X1_DMA ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_CAPTURE_X1_DMA, FLEXPWM_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_CAPTURE_X1_DMA

/***************************************************************************//*!
*
* @brief                Capture X0 FIFO DMA Enable/Disable
*
* @param                FLEXPWM_DISABLE
* @param                FLEXPWM_ENABLE
*
* @return               NULL
*
* @details              The #FLEXPWM_CAPTURE_X0_DMA ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_CAPTURE_X0_DMA, FLEXPWM_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_CAPTURE_X0_DMA

/***************************************************************************//*!
*
* @brief                Enable generation of output trigger on VAL compare
*
* @param                FLEXPWM_VAL0
* @param                FLEXPWM_VAL1
* @param                FLEXPWM_VAL2
* @param                FLEXPWM_VAL3
* @param                FLEXPWM_VAL4
* @param                FLEXPWM_VAL5
*
* @return               NULL
*
* @details              The #FLEXPWM_ENABLE_VAL_COMPARE_OUTTRG ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_ENABLE_VAL_COMPARE_OUTTRG, FLEXPWM_VAL0);
* \endcode
*
******************************************************************************/
#define FLEXPWM_ENABLE_VAL_COMPARE_OUTTRG

/***************************************************************************//*!
*
* @brief                PWMX Fault Disable Mask
*
* @param                FLEXPWM_FAULTS_DISABLED
* @param                FLEXPWM_FAULT_0
* @param                FLEXPWM_FAULT_1
* @param                FLEXPWM_FAULT_2
* @param                FLEXPWM_FAULT_3
*
* @return               NULL
*
* @details              The #FLEXPWM_FAULT_MASK_PWMX ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_FAULT_MASK_PWMX, FLEXPWM_FAULTS_DISABLED);
* \endcode
*
******************************************************************************/
#define FLEXPWM_FAULT_MASK_PWMX

/***************************************************************************//*!
*
* @brief                PWMB Fault Disable Mask
*
* @param                FLEXPWM_FAULTS_DISABLED
* @param                FLEXPWM_FAULT_0
* @param                FLEXPWM_FAULT_1
* @param                FLEXPWM_FAULT_2
* @param                FLEXPWM_FAULT_3
*
* @return               NULL
*
* @details              The #FLEXPWM_FAULT_MASK_PWMB ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_FAULT_MASK_PWMB, FLEXPWM_FAULTS_DISABLED);
* \endcode
*
******************************************************************************/
#define FLEXPWM_FAULT_MASK_PWMB

/***************************************************************************//*!
*
* @brief                PWMA Fault Disable Mask
*
* @param                FLEXPWM_FAULTS_DISABLED
* @param                FLEXPWM_FAULT_0
* @param                FLEXPWM_FAULT_1
* @param                FLEXPWM_FAULT_2
* @param                FLEXPWM_FAULT_3
*
* @return               NULL
*
* @details              The #FLEXPWM_FAULT_MASK_PWMA ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_FAULT_MASK_PWMA, FLEXPWM_FAULTS_DISABLED);
* \endcode
*
******************************************************************************/
#define FLEXPWM_FAULT_MASK_PWMA

/***************************************************************************//*!
*
* @brief                Set PWM A Deadtime
*
* @param                (value signed 16bit)
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_DEADTIME_PWMA ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_DEADTIME_PWMA, (value signed 16bit));
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_DEADTIME_PWMA

/***************************************************************************//*!
*
* @brief                Set PWM B Deadtime
*
* @param                (value signed 16bit)
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_DEADTIME_PWMB ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_DEADTIME_PWMB, (value signed 16bit));
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_DEADTIME_PWMB

/***************************************************************************//*!
*
* @brief                Get capture X1 FIFO word count
*
* @param                NULL
*
* @return               Returns the number of words in the CVAL1 FIFO
*
* @details              The #FLEXPWM_GET_CAPTUREX1_FIFO_COUNT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_CAPTUREX1_FIFO_COUNT, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_CAPTUREX1_FIFO_COUNT

/***************************************************************************//*!
*
* @brief                Get capture X0 FIFO word count
*
* @param                NULL
*
* @return               Returns the number of words in the CVAL0 FIFO
*
* @details              The #FLEXPWM_GET_CAPTUREX0_FIFO_COUNT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_GET_CAPTUREX0_FIFO_COUNT, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_GET_CAPTUREX0_FIFO_COUNT

/***************************************************************************//*!
*
* @brief                Set capture X0 and X1 FIFOs watermark
*
* @param                FLEXPWM_WM_0
* @param                FLEXPWM_WM_1
* @param                FLEXPWM_WM_2
* @param                FLEXPWM_WM_3
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_CAPTURE_FIFO_WATERMARK ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_SET_CAPTURE_FIFO_WATERMARK, FLEXPWM_WM_0);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_CAPTURE_FIFO_WATERMARK

/***************************************************************************//*!
*
* @brief                Edge Counter X Enable
*
* @param                FLEXPWM_DISABLE
* @param                FLEXPWM_ENABLE
*
* @return               NULL
*
* @details              The #FLEXPWM_PWMX_EDGE_COUNTER ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_PWMX_EDGE_COUNTER, FLEXPWM_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_PWMX_EDGE_COUNTER

/***************************************************************************//*!
*
* @brief                Select source of the capture circuit
*
* @param                FLEXPWM_RAW_PWMX
* @param                FLEXPWM_PWMX_EDGE_COUNTER_OUTPUT
*
* @return               NULL
*
* @details              The #FLEXPWM_CAPTURE_SOURCE_SIGNAL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_CAPTURE_SOURCE_SIGNAL, FLEXPWM_RAW_PWMX);
* \endcode
*
******************************************************************************/
#define FLEXPWM_CAPTURE_SOURCE_SIGNAL

/***************************************************************************//*!
*
* @brief                Configure input capture 1 circuit
*
* @param                FLEXPWM_CAPTURE_DISABLED
* @param                FLEXPWM_CAPTURE_FALLING_EDGES
* @param                FLEXPWM_CAPTURE_RISING_EDGES
* @param                FLEXPWM_CAPTURE_ANY_EDGE
*
* @return               NULL
*
* @details              The #FLEXPWM_CAPTURE_X1_EVENT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_CAPTURE_X1_EVENT, FLEXPWM_CAPTURE_DISABLED);
* \endcode
*
******************************************************************************/
#define FLEXPWM_CAPTURE_X1_EVENT

/***************************************************************************//*!
*
* @brief                Configure input capture 0  circuit
*
* @param                FLEXPWM_CAPTURE_DISABLED
* @param                FLEXPWM_CAPTURE_FALLING_EDGES
* @param                FLEXPWM_CAPTURE_RISING_EDGES
* @param                FLEXPWM_CAPTURE_ANY_EDGE
*
* @return               NULL
*
* @details              The #FLEXPWM_CAPTURE_X0_EVENT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_CAPTURE_X0_EVENT, FLEXPWM_CAPTURE_DISABLED);
* \endcode
*
******************************************************************************/
#define FLEXPWM_CAPTURE_X0_EVENT

/***************************************************************************//*!
*
* @brief                Capture mode
*
* @param                FLEXPWM_FREE_RUNNING
* @param                FLEXPWM_ONE_SHOT
*
* @return               NULL
*
* @details              The #FLEXPWM_CAPTURE_MODE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_CAPTURE_MODE, FLEXPWM_FREE_RUNNING);
* \endcode
*
******************************************************************************/
#define FLEXPWM_CAPTURE_MODE

/***************************************************************************//*!
*
* @brief                Start/stop capture
*
* @param                FLEXPWM_DISABLE
* @param                FLEXPWM_ENABLE
*
* @return               NULL
*
* @details              The #FLEXPWM_CAPTURE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_SUB0_BASE,FLEXPWM_CAPTURE, FLEXPWM_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_CAPTURE

/***************************************************************************//*!
*
* @brief                Enable/disable all PWM outputs immediately
*
* @param                FLEXPWM_OUT_DISABLE_ALL
* @param                FLEXPWM_OUT_ENABLE_ALL
*
* @return               NULL
*
* @details              The #FLEXPWM_OUTPUT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_BASE,FLEXPWM_OUTPUT, FLEXPWM_OUT_DISABLE_ALL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_OUTPUT

/***************************************************************************//*!
*
* @brief                Mask all PWM outputs on FORCE_OUT signal, force out to logic 0.
*
* @param                FLEXPWM_MASK_DISABLE_ALL
* @param                FLEXPWM_MASK_ENABLE_ALL
*
* @return               NULL
*
* @details              The #FLEXPWM_MASK ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_BASE,FLEXPWM_MASK, FLEXPWM_MASK_DISABLE_ALL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_MASK

/***************************************************************************//*!
*
* @brief                Select source signal for deadtime logic in complementary mode PWM
*
* @param                FLEXPWM_SUB0_PWMA
* @param                FLEXPWM_SUB0_PWMB
* @param                FLEXPWM_SUB1_PWMA
* @param                FLEXPWM_SUB1_PWMB
* @param                FLEXPWM_SUB2_PWMA
* @param                FLEXPWM_SUB2_PWMB
* @param                FLEXPWM_SUB3_PWMA
* @param                FLEXPWM_SUB3_PWMB
* @param                FLEXPWM_SUB0123_PWMA
* @param                FLEXPWM_SUB0123_PWMB
*
* @return               NULL
*
* @details              The #FLEXPWM_COMPLEMENTARY_PWM_SOURCE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_BASE,FLEXPWM_COMPLEMENTARY_PWM_SOURCE, FLEXPWM_SUB0_PWMA);
* \endcode
*
******************************************************************************/
#define FLEXPWM_COMPLEMENTARY_PWM_SOURCE

/***************************************************************************//*!
*
* @brief                Enable/Disable clock to PWM generator
*
* @param                FLEXPWM_SUB0_DISABLE
* @param                FLEXPWM_SUB0_ENABLE
* @param                FLEXPWM_SUB1_DISABLE
* @param                FLEXPWM_SUB1_ENABLE
* @param                FLEXPWM_SUB2_DISABLE
* @param                FLEXPWM_SUB2_ENABLE
* @param                FLEXPWM_SUB3_DISABLE
* @param                FLEXPWM_SUB3_ENABLE
* @param                FLEXPWM_SUB0123_DISABLE
* @param                FLEXPWM_SUB0123_ENABLE
*
* @return               NULL
*
* @details              The #FLEXPWM_PWM_GENERATOR_CLOCK ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_BASE,FLEXPWM_PWM_GENERATOR_CLOCK, FLEXPWM_SUB0_DISABLE);
* \endcode
*
******************************************************************************/
#define FLEXPWM_PWM_GENERATOR_CLOCK

/***************************************************************************//*!
*
* @brief                Confirm loading of double buffered registers is finished
*
* @param                FLEXPWM_SUB0_LDOK
* @param                FLEXPWM_SUB1_LDOK
* @param                FLEXPWM_SUB2_LDOK
* @param                FLEXPWM_SUB3_LDOK
*
* @return               NULL
*
* @details              The #FLEXPWM_SET_LDOK ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_BASE,FLEXPWM_SET_LDOK, FLEXPWM_SUB0_LDOK);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_LDOK

/***************************************************************************//*!
*
* @brief                Configure deadtime source signal for all submodules at once, by accessing whole DTSRCSEL register.
*
* @param                FLEXPWM_SUB0_PWMA_PWM
* @param                FLEXPWM_SUB0_PWMA_INV
* @param                FLEXPWM_SUB0_PWMA_SW
* @param                FLEXPWM_SUB0_PWMA_EXT
* @param                FLEXPWM_SUB0_PWMB_PWM
* @param                FLEXPWM_SUB0_PWMB_INV
* @param                FLEXPWM_SUB0_PWMB_SW
* @param                FLEXPWM_SUB0_PWMB_EXT
* @param                FLEXPWM_SUB1_PWMA_PWM
* @param                FLEXPWM_SUB1_PWMA_INV
* @param                FLEXPWM_SUB1_PWMA_SW
* @param                FLEXPWM_SUB1_PWMA_EXT
* @param                FLEXPWM_SUB1_PWMB_PWM
* @param                FLEXPWM_SUB1_PWMB_INV
* @param                FLEXPWM_SUB1_PWMB_SW
* @param                FLEXPWM_SUB1_PWMB_EXT
* @param                FLEXPWM_SUB2_PWMA_PWM
* @param                FLEXPWM_SUB2_PWMA_INV
* @param                FLEXPWM_SUB2_PWMA_SW
* @param                FLEXPWM_SUB2_PWMA_EXT
* @param                FLEXPWM_SUB2_PWMB_PWM
* @param                FLEXPWM_SUB2_PWMB_INV
* @param                FLEXPWM_SUB2_PWMB_SW
* @param                FLEXPWM_SUB2_PWMB_EXT
* @param                FLEXPWM_SUB3_PWMA_PWM
* @param                FLEXPWM_SUB3_PWMA_INV
* @param                FLEXPWM_SUB3_PWMA_SW
* @param                FLEXPWM_SUB3_PWMA_EXT
* @param                FLEXPWM_SUB3_PWMB_PWM
* @param                FLEXPWM_SUB3_PWMB_INV
* @param                FLEXPWM_SUB3_PWMB_SW
* @param                FLEXPWM_SUB3_PWMB_EXT
*
* @return               NULL
*
* @details              The #FLEXPWM_SELECT_DT_SOURCE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_BASE,FLEXPWM_SELECT_DT_SOURCE, FLEXPWM_SUB0_PWMA_PWM);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SELECT_DT_SOURCE

/***************************************************************************//*!
*
* @brief                Configure deadtime source signal for SUB_0 PWM_A signal
*
* @param                FLEXPWM_PWM
* @param                FLEXPWM_PWM_INV
* @param                FLEXPWM_SW
* @param                FLEXPWM_EXT
*
* @return               NULL
*
* @details              The #FLEXPWM_SELECT_DT_SOURCE_SUB0_PWMA ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_BASE,FLEXPWM_SELECT_DT_SOURCE_SUB0_PWMA, FLEXPWM_PWM);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SELECT_DT_SOURCE_SUB0_PWMA

/***************************************************************************//*!
*
* @brief                Configure deadtime source signal for SUB_0 PWM_B signal
*
* @param                FLEXPWM_PWM
* @param                FLEXPWM_PWM_INV
* @param                FLEXPWM_SW
* @param                FLEXPWM_EXT
*
* @return               NULL
*
* @details              The #FLEXPWM_SELECT_DT_SOURCE_SUB0_PWMB ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_BASE,FLEXPWM_SELECT_DT_SOURCE_SUB0_PWMB, FLEXPWM_PWM);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SELECT_DT_SOURCE_SUB0_PWMB

/***************************************************************************//*!
*
* @brief                Configure deadtime source signal for SUB_1 PWM_A signal
*
* @param                FLEXPWM_PWM
* @param                FLEXPWM_PWM_INV
* @param                FLEXPWM_SW
* @param                FLEXPWM_EXT
*
* @return               NULL
*
* @details              The #FLEXPWM_SELECT_DT_SOURCE_SUB1_PWMA ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_BASE,FLEXPWM_SELECT_DT_SOURCE_SUB1_PWMA, FLEXPWM_PWM);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SELECT_DT_SOURCE_SUB1_PWMA

/***************************************************************************//*!
*
* @brief                Configure deadtime source signal for SUB_1 PWM_B signal
*
* @param                FLEXPWM_PWM
* @param                FLEXPWM_PWM_INV
* @param                FLEXPWM_SW
* @param                FLEXPWM_EXT
*
* @return               NULL
*
* @details              The #FLEXPWM_SELECT_DT_SOURCE_SUB1_PWMB ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_BASE,FLEXPWM_SELECT_DT_SOURCE_SUB1_PWMB, FLEXPWM_PWM);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SELECT_DT_SOURCE_SUB1_PWMB

/***************************************************************************//*!
*
* @brief                Configure deadtime source signal for SUB_2 PWM_A signal
*
* @param                FLEXPWM_PWM
* @param                FLEXPWM_PWM_INV
* @param                FLEXPWM_SW
* @param                FLEXPWM_EXT
*
* @return               NULL
*
* @details              The #FLEXPWM_SELECT_DT_SOURCE_SUB2_PWMA ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_BASE,FLEXPWM_SELECT_DT_SOURCE_SUB2_PWMA, FLEXPWM_PWM);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SELECT_DT_SOURCE_SUB2_PWMA

/***************************************************************************//*!
*
* @brief                Configure deadtime source signal for SUB_2 PWM_B signal
*
* @param                FLEXPWM_PWM
* @param                FLEXPWM_PWM_INV
* @param                FLEXPWM_SW
* @param                FLEXPWM_EXT
*
* @return               NULL
*
* @details              The #FLEXPWM_SELECT_DT_SOURCE_SUB2_PWMB ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_BASE,FLEXPWM_SELECT_DT_SOURCE_SUB2_PWMB, FLEXPWM_PWM);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SELECT_DT_SOURCE_SUB2_PWMB

/***************************************************************************//*!
*
* @brief                Configure deadtime source signal for SUB_3 PWM_A signal
*
* @param                FLEXPWM_PWM
* @param                FLEXPWM_PWM_INV
* @param                FLEXPWM_SW
* @param                FLEXPWM_EXT
*
* @return               NULL
*
* @details              The #FLEXPWM_SELECT_DT_SOURCE_SUB3_PWMA ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_BASE,FLEXPWM_SELECT_DT_SOURCE_SUB3_PWMA, FLEXPWM_PWM);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SELECT_DT_SOURCE_SUB3_PWMA

/***************************************************************************//*!
*
* @brief                Configure deadtime source signal for SUB_3 PWM_B signal
*
* @param                FLEXPWM_PWM
* @param                FLEXPWM_PWM_INV
* @param                FLEXPWM_SW
* @param                FLEXPWM_EXT
*
* @return               NULL
*
* @details              The #FLEXPWM_SELECT_DT_SOURCE_SUB3_PWMB ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(FLEXPWM0_BASE,FLEXPWM_SELECT_DT_SOURCE_SUB3_PWMB, FLEXPWM_PWM);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SELECT_DT_SOURCE_SUB3_PWMB

/***************************************************************************//*!
*
* @brief                Read configuration of deadtime source select register
*
* @param                NULL
*
* @return               Returns configuration of deadtime source.
*
* @details              The #FLEXPWM_READ_DT_SOURCE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(FLEXPWM0_BASE,FLEXPWM_READ_DT_SOURCE, NULL);
* \endcode
*
******************************************************************************/
#define FLEXPWM_READ_DT_SOURCE

/***************************************************************************//*!
*
* @brief                Set single phase center aligned dutycyle for PWM A generator
*
* @param                
*
* @return               
*
* @details              The #FLEXPWM_SET_PWMA_DUTY_1PH_CENTERALIGN ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* FLEXPWM_VAL_COMPL myDuty;
*
* myDuty.s16sub0 = 500;     // center aligned dutycyle
*
* //Set dutycyle for FlexPWM0 sub[0] module and use VAL[2]=-duty and VAL[3]=duty for PWM generation
* ioctl(FLEXPWM0_SUB0_BASE, FLEXPWM_SET_PWMA_DUTY_1PH_CENTERALIGN, myDuty.s16sub0);
* ioctl(FLEXPWM0_BASE, FLEXPWM_SET_LDOK, FLEXPWM_SUB0_LDOK);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMA_DUTY_1PH_CENTERALIGN

/***************************************************************************//*!
*
* @brief                Set single phase center aligned dutycyle for PWM B generator
*
* @param                
*
* @return               
*
* @details              The #FLEXPWM_SET_PWMB_DUTY_1PH_CENTERALIGN ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* FLEXPWM_VAL_COMPL myDuty;
*
* myDuty.s16sub0 = 500;     // center aligned dutycyle
*
* //Set dutycyle for FlexPWM0 sub[0] module and use VAL[4]=-duty and VAL[5]=duty for PWM generation
* ioctl(FLEXPWM0_SUB0_BASE, FLEXPWM_SET_PWMB_DUTY_1PH_CENTERALIGN, myDuty.s16sub0);
* ioctl(FLEXPWM0_BASE, FLEXPWM_SET_LDOK, FLEXPWM_SUB0_LDOK);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMB_DUTY_1PH_CENTERALIGN

/***************************************************************************//*!
*
* @brief                Set single phase edge aligned dutycyle for PWM A generator
*
* @param                
*
* @return               
*
* @details              The #FLEXPWM_SET_PWMA_DUTY_1PH_EDGEALIGN ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* FLEXPWM_VAL_COMPL myDuty;
*
* myDuty.s16sub0 = 500;     // center aligned dutycyle
*
* //Set dutycyle for FlexPWM0 sub[0] module and use VAL[2]=INIT and VAL[3]=duty for PWM generation
* ioctl(FLEXPWM0_SUB0_BASE, FLEXPWM_SET_PWMA_DUTY_1PH_EDGEALIGN, myDuty.s16sub0);
* ioctl(FLEXPWM0_BASE, FLEXPWM_SET_LDOK, FLEXPWM_SUB0_LDOK);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMA_DUTY_1PH_EDGEALIGN

/***************************************************************************//*!
*
* @brief                Set single phase edge aligned dutycyle for PWM B generator
*
* @param                
*
* @return               
*
* @details              The #FLEXPWM_SET_PWMB_DUTY_1PH_EDGEALIGN ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* FLEXPWM_VAL_COMPL myDuty;
*
* myDuty.s16sub0 = 500;     // center aligned dutycyle
*
* //Set dutycyle for FlexPWM0 sub[0] module and use VAL[4]=INIT and VAL[5]=duty for PWM generation
* ioctl(FLEXPWM0_SUB0_BASE, FLEXPWM_SET_PWMB_DUTY_1PH_EDGEALIGN, myDuty.s16sub0);
* ioctl(FLEXPWM0_BASE, FLEXPWM_SET_LDOK, FLEXPWM_SUB0_LDOK);
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMB_DUTY_1PH_EDGEALIGN

/***************************************************************************//*!
*
* @brief                Set three phase center aligned dutycyle for PWM A generator
*
* @param                Structure of #FLEXPWM_VAL_COMPL type encompasing values
*                       of three phase dutycyles
*
* @return               
*
* @details              The #FLEXPWM_SET_PWMA_DUTY_3PH_CENTERALIGN ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* FLEXPWM_VAL_COMPL myDuty;
*
* myDuty.s16sub0 = 500;     // center aligned dutycyle for submodule 0
* myDuty.s16sub1 = 1000;    // center aligned dutycyle for submodule 1
* myDuty.s16sub2 = 2000;    // center aligned dutycyle for submodule 2
*
* //Set dutycyle for FlexPWM0 sub[0], sub[1], sub[2] modules and use VAL[2]=-duty and VAL[3]=duty for PWM generation
* ioctl(FLEXPWM0_BASE, FLEXPWM_SET_PWMA_DUTY_3PH_CENTERALIGN, myDuty);
* ioctl(FLEXPWM0_BASE, FLEXPWM_SET_LDOK, FLEXPWM_SUB0_LDOK | FLEXPWM_SUB1_LDOK | FLEXPWM_SUB2_LDOK);
*
* //Set dutycyle for FlexPWM0 sub[0], sub[1], sub[2] modules and use VAL[2]=-duty and VAL[3]=duty for PWM generation
* ioctl(FLEXPWM1_BASE, FLEXPWM_SET_PWMA_DUTY_3PH_CENTERALIGN, myDuty);
* ioctl(FLEXPWM1_BASE, FLEXPWM_SET_LDOK, FLEXPWM_SUB0_LDOK | FLEXPWM_SUB1_LDOK | FLEXPWM_SUB2_LDOK);
*
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMA_DUTY_3PH_CENTERALIGN

/***************************************************************************//*!
*
* @brief                Set three phase edge aligned dutycyle for PWM A generator
*
* @param                Structure of #FLEXPWM_VAL_COMPL type encompasing values
*                       of three phase dutycyles
*
* @return               
*
* @details              The #FLEXPWM_SET_PWMA_DUTY_3PH_EDGEALIGN ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* FLEXPWM_VAL_COMPL myDuty;
*
* myDuty.s16sub0 = 500;     // edge aligned dutycyle for submodule 0
* myDuty.s16sub1 = 1000;    // edge aligned dutycyle for submodule 1
* myDuty.s16sub2 = 2000;    // edge aligned dutycyle for submodule 2
*
* //Set dutycyle for FlexPWM0 sub[0], sub[1], sub[2] modules and use VAL[2]=INIT and VAL[3]=duty for PWM generation
* ioctl(FLEXPWM0_BASE, FLEXPWM_SET_PWMA_DUTY_3PH_EDGEALIGN, myDuty);
* ioctl(FLEXPWM0_BASE, FLEXPWM_SET_LDOK, FLEXPWM_SUB0_LDOK | FLEXPWM_SUB1_LDOK | FLEXPWM_SUB2_LDOK);
*
* //Set dutycyle for FlexPWM0 sub[0], sub[1], sub[2] modules and use VAL[2]=INIT and VAL[3]=duty for PWM generation
* ioctl(FLEXPWM1_BASE, FLEXPWM_SET_PWMA_DUTY_3PH_EDGEALIGN, myDuty);
* ioctl(FLEXPWM1_BASE, FLEXPWM_SET_LDOK, FLEXPWM_SUB0_LDOK | FLEXPWM_SUB1_LDOK | FLEXPWM_SUB2_LDOK);
*
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMA_DUTY_3PH_EDGEALIGN

/***************************************************************************//*!
*
* @brief                Set three phase center aligned dutycyle for PWM B generator
*
* @param                Structure of #FLEXPWM_VAL_COMPL type encompasing values
*                       of three phase dutycyles
*
* @return               
*
* @details              The #FLEXPWM_SET_PWMB_DUTY_3PH_CENTERALIGN ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* FLEXPWM_VAL_COMPL myDuty;
*
* myDuty.s16sub0 = 500;     // center aligned dutycyle for submodule 0
* myDuty.s16sub1 = 1000;    // center aligned dutycyle for submodule 1
* myDuty.s16sub2 = 2000;    // center aligned dutycyle for submodule 2
*
* //Set dutycyle for FlexPWM0 sub[0], sub[1], sub[2] modules and use VAL[4]=-duty and VAL[5]=duty for PWM generation
* ioctl(FLEXPWM0_BASE, FLEXPWM_SET_PWMB_DUTY_3PH_CENTERALIGN, myDuty);
* ioctl(FLEXPWM0_BASE, FLEXPWM_SET_LDOK, FLEXPWM_SUB0_LDOK | FLEXPWM_SUB1_LDOK | FLEXPWM_SUB2_LDOK);
*
* //Set dutycyle for FlexPWM0 sub[0], sub[1], sub[2] modules and use VAL[4]=-duty and VAL[5]=duty for PWM generation
* ioctl(FLEXPWM1_BASE, FLEXPWM_SET_PWMB_DUTY_3PH_CENTERALIGN, myDuty);
* ioctl(FLEXPWM1_BASE, FLEXPWM_SET_LDOK, FLEXPWM_SUB0_LDOK | FLEXPWM_SUB1_LDOK | FLEXPWM_SUB2_LDOK);
*
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMB_DUTY_3PH_CENTERALIGN

/***************************************************************************//*!
*
* @brief                Set three phase edge aligned dutycyle for PWM B generator
*
* @param                Structure of #FLEXPWM_VAL_COMPL type encompasing values
*                       of three phase dutycyles
*
* @return               
*
* @details              The #FLEXPWM_SET_PWMB_DUTY_3PH_EDGEALIGN ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* FLEXPWM_VAL_COMPL myDuty;
*
* myDuty.s16sub0 = 500;     // edge aligned dutycyle for submodule 0
* myDuty.s16sub1 = 1000;    // edge aligned dutycyle for submodule 1
* myDuty.s16sub2 = 2000;    // edge aligned dutycyle for submodule 2
*
* //Set dutycyle for FlexPWM0 sub[0], sub[1], sub[2] modules and use VAL[4]=INIT and VAL[5]=duty for PWM generation
* ioctl(FLEXPWM0_BASE, FLEXPWM_SET_PWMB_DUTY_3PH_EDGEALIGN, myDuty);
* ioctl(FLEXPWM0_BASE, FLEXPWM_SET_LDOK, FLEXPWM_SUB0_LDOK | FLEXPWM_SUB1_LDOK | FLEXPWM_SUB2_LDOK);
*
* //Set dutycyle for FlexPWM0 sub[0], sub[1], sub[2] modules and use VAL[4]=INIT and VAL[5]=duty for PWM generation
* ioctl(FLEXPWM1_BASE, FLEXPWM_SET_PWMB_DUTY_3PH_EDGEALIGN, myDuty);
* ioctl(FLEXPWM1_BASE, FLEXPWM_SET_LDOK, FLEXPWM_SUB0_LDOK | FLEXPWM_SUB1_LDOK | FLEXPWM_SUB2_LDOK);
*
* \endcode
*
******************************************************************************/
#define FLEXPWM_SET_PWMB_DUTY_3PH_EDGEALIGN


/******************************************************************************
* FlexPWM bitfield masks definition
******************************************************************************/

#define FLEXPWM_CNTV_MASK                               0xC000
#define FLEXPWM_DBGEN_MASK                              0x8000
#define FLEXPWM_WAITEN_MASK                             0x4000
#define FLEXPWM_INDEP_MASK                              0x2000
#define FLEXPWM_PWM23_INIT_MASK                         0x1000
#define FLEXPWM_PWM45_INIT_MASK                         0x0800
#define FLEXPWM_PWMX_INIT_MASK                          0x0400
#define FLEXPWM_INIT_SEL_MASK                           0x0300
#define FLEXPWM_FRCEN_MASK                              0x0080
#define FLEXPWM_FORCE_SEL_MASK                          0x0038
#define FLEXPWM_RELOAD_SEL_MASK                         0x0004
#define FLEXPWM_CLK_SEL_MASK                            0x0003
#define FLEXPWM_LDFQ_MASK                               0xF000
#define FLEXPWM_HALF_MASK                               0x0800
#define FLEXPWM_FULL_MASK                               0x0400
#define FLEXPWM_PRSC_MASK                               0x0070
#define FLEXPWM_DBLEN_MASK                              0x0001
#define FLEXPWM_POLA_MASK                               0x0400
#define FLEXPWM_POLB_MASK                               0x0200
#define FLEXPWM_POLX_MASK                               0x0100
#define FLEXPWM_PWMAFS_MASK                             0x0030
#define FLEXPWM_PWMBFS_MASK                             0x000C
#define FLEXPWM_PWMXFS_MASK                             0x0003
#define FLEXPWM_RUF_MASK                                0x2000
#define FLEXPWM_REF_MASK                                0x1000
#define FLEXPWM_RF_MASK                                 0x0800
#define FLEXPWM_CFX1_MASK                               0x0080
#define FLEXPWM_CFX0_MASK                               0x0040
#define FLEXPWM_CMPF_MASK                               0x003F
#define FLEXPWM_REIE_MASK                               0x2000
#define FLEXPWM_RIE_MASK                                0x1000
#define FLEXPWM_CX1IE_MASK                              0x0080
#define FLEXPWM_CX0IE_MASK                              0x0040
#define FLEXPWM_CMPIE_MASK                              0x003F
#define FLEXPWM_VALDE_MASK                              0x0200
#define FLEXPWM_FAND_MASK                               0x0100
#define FLEXPWM_CAPTDE_MASK                             0x00C0
#define FLEXPWM_CX1DE_MASK                              0x0002
#define FLEXPWM_CX0DE_MASK                              0x0001
#define FLEXPWM_OUT_TRIG_EN_MASK                        0x003F
#define FLEXPWM_DISX_MASK                               0x0F00
#define FLEXPWM_DISB_MASK                               0x00F0
#define FLEXPWM_DISA_MASK                               0x000F
#define FLEXPWM_CX1CNT_MASK                             0xE000
#define FLEXPWM_CX0CNT_MASK                             0x1C00
#define FLEXPWM_CFXWM_MASK                              0x0300
#define FLEXPWM_EDGCNTX_EN_MASK                         0x0080
#define FLEXPWM_INP_SELX_MASK                           0x0040
#define FLEXPWM_EDGX1_MASK                              0x0030
#define FLEXPWM_EDGX0_MASK                              0x000C
#define FLEXPWM_ONESHOTX_MASK                           0x0002
#define FLEXPWM_ARMX_MASK                               0x0001
#define FLEXPWM_IPOL_MASK                               0xF000
#define FLEXPWM_RUN_MASK                                0x0F00
#define FLEXPWM_LDOK_MASK                               0x000F
#define FLEXPWM_SUB0_PWMA_MASK                          0x000C
#define FLEXPWM_SUB0_PWMB_MASK                          0x0003
#define FLEXPWM_SUB1_PWMA_MASK                          0x00C0
#define FLEXPWM_SUB1_PWMB_MASK                          0x0030
#define FLEXPWM_SUB2_PWMA_MASK                          0x0C00
#define FLEXPWM_SUB2_PWMB_MASK                          0x0300
#define FLEXPWM_SUB3_PWMA_MASK                          0xC000
#define FLEXPWM_SUB3_PWMB_MASK                          0x3000

/******************************************************************************
* FlexPWM register offset definition
******************************************************************************/

#define FLEXPWM_CNT_OFFSET                              0x0
#define FLEXPWM_INIT_OFFSET                             0x2
#define FLEXPWM_CTRL2_OFFSET                            0x4
#define FLEXPWM_CTLR2_OFFSET                            0x4
#define FLEXPWM_CTRL_OFFSET                             0x6
#define FLEXPWM_VAL_0_OFFSET                            0x8
#define FLEXPWM_VAL_1_OFFSET                            0xa
#define FLEXPWM_VAL_2_OFFSET                            0xc
#define FLEXPWM_VAL_3_OFFSET                            0xe
#define FLEXPWM_VAL_4_OFFSET                            0x10
#define FLEXPWM_VAL_5_OFFSET                            0x12
#define FLEXPWM_OCTRL_OFFSET                            0x18
#define FLEXPWM_STS_OFFSET                              0x1a
#define FLEXPWM_INTEN_OFFSET                            0x1c
#define FLEXPWM_DMAEN_OFFSET                            0x1e
#define FLEXPWM_TCTRL_OFFSET                            0x20
#define FLEXPWM_DISMAP_OFFSET                           0x22
#define FLEXPWM_DTCNT0_OFFSET                           0x24
#define FLEXPWM_DTCNT1_OFFSET                           0x26
#define FLEXPWM_CAPTCTRLX_OFFSET                        0x30
#define FLEXPWM_OUTEN_OFFSET                            0x140
#define FLEXPWM_MASK_OFFSET                             0x142
#define FLEXPWM_MCTRL_OFFSET                            0x148
#define FLEXPWM_DTSRCSEL_OFFSET                         0x146
#define FLEXPWM_FSTS_OFFSET                         	0x14E
#define FLEXPWM_SUB0_OFFSET	                            0x0
#define FLEXPWM_SUB1_OFFSET                             0x50
#define FLEXPWM_SUB2_OFFSET                             0xA0
#define FLEXPWM_SUB3_OFFSET                             0xF0

/******************************************************************************
* FlexPWM MACRO and ioctl parameters definition
******************************************************************************/

#define FLEXPWM_STOP                                    0x0
#define FLEXPWM_RUN                                     0x1
#define FLEXPWM_COMPLEMENTARY                           0x0
#define FLEXPWM_INDEPENDENT                             0x1
#define FLEXPWM_LOW                                     0x0
#define FLEXPWM_HIGH                                    0x1
#define FLEXPWM_INIT_ON_LOCAL_SOURCE                    0x0
#define FLEXPWM_INIT_ON_MASTER_RELOAD                   0x1
#define FLEXPWM_INIT_ON_MASTER_SYNC                     0x2
#define FLEXPWM_INIT_ON_EXT_SYNC                        0x3
#define FLEXPWM_DISABLE                                 0x0
#define FLEXPWM_ENABLE                                  0x1
#define FLEXPWM_FORCEOUT_ON_LOCAL_FORCE                 0x0
#define FLEXPWM_FORCEOUT_ON_MASTER_FORCE                0x1
#define FLEXPWM_FORCEOUT_ON_LOCAL_RELOAD                0x2
#define FLEXPWM_FORCEOUT_ON_MASTER_RELOAD               0x3
#define FLEXPWM_FORCEOUT_ON_LOCAL_SYNC                  0x4
#define FLEXPWM_FORCEOUT_ON_MASTER_SYNC                 0x5
#define FLEXPWM_FORCEOUT_ON_EXT_FORCE                   0x6
#define FLEXPWM_RELOAD_ON_LOCAL_RELOAD                  0x0
#define FLEXPWM_RELOAD_ON_MASTER_RELOAD                 0x1
#define FLEXPWM_IPBUS                                   0x0
#define FLEXPWM_EXT_CLK                                 0x1
#define FLEXPWM_SUB0_CLK                                0x2
#define FLEXPWM_RELOAD_EVERY_OPPORTUNITY                0x0
#define FLEXPWM_RELOAD_EVERY_2_OPPORTUNITIES            0x1
#define FLEXPWM_RELOAD_EVERY_3_OPPORTUNITIES            0x2
#define FLEXPWM_RELOAD_EVERY_4_OPPORTUNITIES            0x3
#define FLEXPWM_RELOAD_EVERY_5_OPPORTUNITIES            0x4
#define FLEXPWM_RELOAD_EVERY_6_OPPORTUNITIES            0x5
#define FLEXPWM_RELOAD_EVERY_7_OPPORTUNITIES            0x6
#define FLEXPWM_RELOAD_EVERY_8_OPPORTUNITIES            0x7
#define FLEXPWM_RELOAD_EVERY_9_OPPORTUNITIES            0x8
#define FLEXPWM_RELOAD_EVERY_10_OPPORTUNITIES           0x9
#define FLEXPWM_RELOAD_EVERY_11_OPPORTUNITIES           0xA
#define FLEXPWM_RELOAD_EVERY_12_OPPORTUNITIES           0xB
#define FLEXPWM_RELOAD_EVERY_13_OPPORTUNITIES           0xC
#define FLEXPWM_RELOAD_EVERY_14_OPPORTUNITIES           0xD
#define FLEXPWM_RELOAD_EVERY_15_OPPORTUNITIES           0xE
#define FLEXPWM_RELOAD_EVERY_16_OPPORTUNITIES           0xF
#define FLEXPWM_PRESCALER_DIV_BY_1                      0x0
#define FLEXPWM_PRESCALER_DIV_BY_2                      0x1
#define FLEXPWM_PRESCALER_DIV_BY_4                      0x2
#define FLEXPWM_PRESCALER_DIV_BY_8                      0x3
#define FLEXPWM_PRESCALER_DIV_BY_16                     0x4
#define FLEXPWM_PRESCALER_DIV_BY_32                     0x5
#define FLEXPWM_PRESCALER_DIV_BY_64                     0x6
#define FLEXPWM_PRESCALER_DIV_BY_128                    0x7
#define FLEXPWM_ACTIVE_HIGH                             0x0
#define FLEXPWM_ACTIVE_LOW                              0x1
#define FLEXPWM_TRISTATED                               0x2
#define FLEXPWM_VAL0                                    0x1
#define FLEXPWM_VAL1                                    0x2
#define FLEXPWM_VAL2                                    0x4
#define FLEXPWM_VAL3                                    0x8
#define FLEXPWM_VAL4                                    0x10
#define FLEXPWM_VAL5                                    0x20
#define FLEXPWM_WM_OR                                   0x0
#define FLEXPWM_WM_AND                                  0x1
#define FLEXPWM_DMA_READ_ON_FIFO_WM                     0x1
#define FLEXPWM_DMA_READ_ON_LOCAL_SYNC                  0x2
#define FLEXPWM_DMA_READ_ON_LOCAL_RELOAD                0x3
#define FLEXPWM_FAULTS_DISABLED                         0x0
#define FLEXPWM_FAULT_0                                 0
#define FLEXPWM_FAULT_1                                 1
#define FLEXPWM_FAULT_2                                 2
#define FLEXPWM_FAULT_3                                 3
#define FLEXPWM_WM_0                                    0x0
#define FLEXPWM_WM_1                                    0x1
#define FLEXPWM_WM_2                                    0x2
#define FLEXPWM_WM_3                                    0x3
#define FLEXPWM_RAW_PWMX                                0x0
#define FLEXPWM_PWMX_EDGE_COUNTER_OUTPUT                0x1
#define FLEXPWM_CAPTURE_DISABLED                        0x0
#define FLEXPWM_CAPTURE_FALLING_EDGES                   0x1
#define FLEXPWM_CAPTURE_RISING_EDGES                    0x2
#define FLEXPWM_CAPTURE_ANY_EDGE                        0x3
#define FLEXPWM_FREE_RUNNING                            0x0
#define FLEXPWM_ONE_SHOT                                0x1
#define FLEXPWM_OUT_DISABLE_ALL                         0x0
#define FLEXPWM_OUT_ENABLE_ALL                          0x0FFF
#define FLEXPWM_MASK_DISABLE_ALL                        0x0
#define FLEXPWM_MASK_ENABLE_ALL                         0x0FFF
#define FLEXPWM_SUB0_PWMA                               0x0
#define FLEXPWM_SUB0_PWMB                               0x1
#define FLEXPWM_SUB1_PWMA                               0x0
#define FLEXPWM_SUB1_PWMB                               0x2
#define FLEXPWM_SUB2_PWMA                               0x0
#define FLEXPWM_SUB2_PWMB                               0x4
#define FLEXPWM_SUB3_PWMA                               0x0
#define FLEXPWM_SUB3_PWMB                               0x8
#define FLEXPWM_SUB0123_PWMA                            0x0
#define FLEXPWM_SUB0123_PWMB                            0xF
#define FLEXPWM_SUB0_DISABLE                            0
#define FLEXPWM_SUB0_ENABLE                             1
#define FLEXPWM_SUB1_DISABLE                            0
#define FLEXPWM_SUB1_ENABLE                             2
#define FLEXPWM_SUB2_DISABLE                            0
#define FLEXPWM_SUB2_ENABLE                             4
#define FLEXPWM_SUB3_DISABLE                            0
#define FLEXPWM_SUB3_ENABLE                             8
#define FLEXPWM_SUB0123_DISABLE                         0
#define FLEXPWM_SUB0123_ENABLE                          15
#define FLEXPWM_SUB0_LDOK                               1
#define FLEXPWM_SUB1_LDOK                               2
#define FLEXPWM_SUB2_LDOK                               4
#define FLEXPWM_SUB3_LDOK                               8
#define FLEXPWM_SUB0_PWMA_PWM                           0x0
#define FLEXPWM_SUB0_PWMA_INV                           0x4
#define FLEXPWM_SUB0_PWMA_SW                            0x8
#define FLEXPWM_SUB0_PWMA_EXT                           0xC
#define FLEXPWM_SUB0_PWMB_PWM                           0x0
#define FLEXPWM_SUB0_PWMB_INV                           0x1
#define FLEXPWM_SUB0_PWMB_SW                            0x2
#define FLEXPWM_SUB0_PWMB_EXT                           0x3
#define FLEXPWM_SUB1_PWMA_PWM                           0x0
#define FLEXPWM_SUB1_PWMA_INV                           0x40
#define FLEXPWM_SUB1_PWMA_SW                            0x80
#define FLEXPWM_SUB1_PWMA_EXT                           0xC0
#define FLEXPWM_SUB1_PWMB_PWM                           0x0
#define FLEXPWM_SUB1_PWMB_INV                           0x10
#define FLEXPWM_SUB1_PWMB_SW                            0x20
#define FLEXPWM_SUB1_PWMB_EXT                           0x30
#define FLEXPWM_SUB2_PWMA_PWM                           0x0
#define FLEXPWM_SUB2_PWMA_INV                           0x400
#define FLEXPWM_SUB2_PWMA_SW                            0x800
#define FLEXPWM_SUB2_PWMA_EXT                           0xC00
#define FLEXPWM_SUB2_PWMB_PWM                           0x0
#define FLEXPWM_SUB2_PWMB_INV                           0x100
#define FLEXPWM_SUB2_PWMB_SW                            0x200
#define FLEXPWM_SUB2_PWMB_EXT                           0x300
#define FLEXPWM_SUB3_PWMA_PWM                           0x0
#define FLEXPWM_SUB3_PWMA_INV                           0x4000
#define FLEXPWM_SUB3_PWMA_SW                            0x8000
#define FLEXPWM_SUB3_PWMA_EXT                           0xC000
#define FLEXPWM_SUB3_PWMB_PWM                           0x0
#define FLEXPWM_SUB3_PWMB_INV                           0x1000
#define FLEXPWM_SUB3_PWMB_SW                            0x2000
#define FLEXPWM_SUB3_PWMB_EXT                           0x3000
#define FLEXPWM_PWM                                     0x0
#define FLEXPWM_PWM_INV                                 0x1
#define FLEXPWM_SW                                      0x2
#define FLEXPWM_EXT                                     0x3

/******************************************************************************
* FlexPWM ioctl commands implementation
******************************************************************************/
#define FLEXPWM_INV(x)                                  (((-(tS32)(x)) == -(tS32) (0x8000)) ? 0x7fff:-x)

#define PWMA                                            2

#define PWMB                                            4

#define ioctlFLEXPWM_GET_COUNTER_VALUE(flexpwmAddr,param) \
        (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CNT_OFFSET)) & (FLEXPWM_CNTV_MASK)) >>14

#define ioctlFLEXPWM_SET_COUNTER_INIT_VALUE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_INIT_OFFSET)) = (param)

#define ioctlFLEXPWM_GET_COUNTER_INIT_VALUE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_INIT_OFFSET))

#define ioctlFLEXPWM_DEBUG_OPERATION(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) & (~FLEXPWM_DBGEN_MASK)) | (param<<15)

#define ioctlFLEXPWM_WAIT_OPERATION(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTLR2_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTLR2_OFFSET)) & (~FLEXPWM_WAITEN_MASK)) | (param<<14)

#define ioctlFLEXPWM_CHANNEL_OPERATION(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) & (~FLEXPWM_INDEP_MASK)) | (param<<13)

#define ioctlFLEXPWM_SET_PWMA_INIT_STATE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) & (~FLEXPWM_PWM23_INIT_MASK)) | (param<<12)

#define ioctlFLEXPWM_SET_PWMB_INIT_STATE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) & (~FLEXPWM_PWM45_INIT_MASK)) | (param<<11)

#define ioctlFLEXPWM_SET_PWMX_INIT_STATE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) & (~FLEXPWM_PWMX_INIT_MASK)) | (param<<10)

#define ioctlFLEXPWM_COUNTER_INITIALIZATION(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) & (~FLEXPWM_INIT_SEL_MASK)) | (param<<8)

#define ioctlFLEXPWM_FORCEOUT_COUNTER_INITIALIZATION(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) & (~FLEXPWM_FRCEN_MASK)) | (param<<7)

#define ioctlFLEXPWM_FORCEOUT_SOURCE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) & (~FLEXPWM_FORCE_SEL_MASK)) | (param<<3)

#define ioctlFLEXPWM_RELOAD_SOURCE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) & (~FLEXPWM_RELOAD_SEL_MASK)) | (param<<2)

#define ioctlFLEXPWM_CLOCK_SOURCE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL2_OFFSET)) & (~FLEXPWM_CLK_SEL_MASK)) | (param)

#define ioctlFLEXPWM_SET_RELOAD_FREQUENCY(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL_OFFSET)) & (~FLEXPWM_LDFQ_MASK)) | (param<<12)

#define ioctlFLEXPWM_HALF_RELOAD(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL_OFFSET)) & (~FLEXPWM_HALF_MASK)) | (param<<11)

#define ioctlFLEXPWM_FULL_RELOAD(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL_OFFSET)) & (~FLEXPWM_FULL_MASK)) | (param<<10)

#define ioctlFLEXPWM_SET_CLOCK_PRESCALER(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL_OFFSET)) & (~FLEXPWM_PRSC_MASK)) | (param<<4)

#define ioctlFLEXPWM_DOUBLE_SWITCHING(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CTRL_OFFSET)) & (~FLEXPWM_DBLEN_MASK)) | (param)

#define ioctlFLEXPWM_GET_INIT(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_INIT_OFFSET))

#define ioctlFLEXPWM_SET_VAL0(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_VAL_0_OFFSET)) = (param)

#define ioctlFLEXPWM_GET_VAL0(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_VAL_0_OFFSET))

#define ioctlFLEXPWM_SET_VAL1(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_VAL_1_OFFSET)) = (param)

#define ioctlFLEXPWM_GET_VAL1(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_VAL_1_OFFSET))

#define ioctlFLEXPWM_SET_VAL2(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_VAL_2_OFFSET)) = (param)

#define ioctlFLEXPWM_GET_VAL2(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_VAL_2_OFFSET))

#define ioctlFLEXPWM_SET_VAL3(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_VAL_3_OFFSET)) = (param)

#define ioctlFLEXPWM_GET_VAL3(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_VAL_3_OFFSET))

#define ioctlFLEXPWM_SET_VAL4(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_VAL_4_OFFSET)) = (param)

#define ioctlFLEXPWM_GET_VAL4(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_VAL_4_OFFSET))

#define ioctlFLEXPWM_SET_VAL5(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_VAL_5_OFFSET)) = (param)

#define ioctlFLEXPWM_GET_VAL5(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_VAL_5_OFFSET))

#define ioctlFLEXPWM_SET_PWMA_OUTPUT_POLARITY(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_OCTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_OCTRL_OFFSET)) & (~FLEXPWM_POLA_MASK)) | (param<<10)

#define ioctlFLEXPWM_SET_PWMB_OUTPUT_POLARITY(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_OCTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_OCTRL_OFFSET)) & (~FLEXPWM_POLB_MASK)) | (param<<9)

#define ioctlFLEXPWM_SET_PWMX_OUTPUT_POLARITY(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_OCTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_OCTRL_OFFSET)) & (~FLEXPWM_POLX_MASK)) | (param<<8)

#define ioctlFLEXPWM_SET_PWMA_FAULT_STATE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_OCTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_OCTRL_OFFSET)) & (~FLEXPWM_PWMAFS_MASK)) | (param<<4)

#define ioctlFLEXPWM_SET_PWMB_FAULT_STATE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_OCTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_OCTRL_OFFSET)) & (~FLEXPWM_PWMBFS_MASK)) | (param<<2)

#define ioctlFLEXPWM_SET_PWMX_FAULT_STATE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_OCTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_OCTRL_OFFSET)) & (~FLEXPWM_PWMXFS_MASK)) | (param)

#define ioctlFLEXPWM_GET_REGISTER_UPDATE_FLAG(flexpwmAddr,param) \
        (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_STS_OFFSET)) & (FLEXPWM_RUF_MASK)) >>13

#define ioctlFLEXPWM_GET_RELOAD_ERROR_FLAG(flexpwmAddr,param) \
        (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_STS_OFFSET)) & (FLEXPWM_REF_MASK)) >>12

#define ioctlFLEXPWM_GET_RELOAD_FLAG(flexpwmAddr,param) \
        (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_STS_OFFSET)) & (FLEXPWM_RF_MASK)) >>11

#define ioctlFLEXPWM_CLEAR_RELOAD_FLAG(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_STS_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_STS_OFFSET)) & (~FLEXPWM_RF_MASK)) | (param<<11)

#define ioctlFLEXPWM_GET_CAPTX1_FLAG(flexpwmAddr,param) \
        (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_STS_OFFSET)) & (FLEXPWM_CFX1_MASK)) >>7

#define ioctlFLEXPWM_GET_CAPTX0_FLAG(flexpwmAddr,param) \
        (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_STS_OFFSET)) & (FLEXPWM_CFX0_MASK)) >>6

#define ioctlFLEXPWM_GET_FAULT(flexpwmAddr,param) \
		(*((volatile tU16 *)(flexpwmAddr + FLEXPWM_FSTS_OFFSET)) & (0x1 << (8 + param))) >>(8 + param)

#define ioctlFLEXPWM_GET_FAULT_FLAG(flexpwmAddr,param) \
        (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_FSTS_OFFSET)) & (0x1 << param)) >>param

#define ioctlFLEXPWM_CLEAR_ALL_FAULT_FLAGS(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_FSTS_OFFSET)) = 0xF

#define ioctlFLEXPWM_GET_VAL_COMPARE_FLAG(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_STS_OFFSET)) & (FLEXPWM_CMPF_MASK) & (param)

#define ioctlFLEXPWM_CLEAR_VAL_COMPARE_FLAG(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_STS_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_STS_OFFSET)) & (~FLEXPWM_CMPF_MASK)) | (param)

#define ioctlFLEXPWM_RELOAD_ERROR_INT(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_INTEN_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_INTEN_OFFSET)) & (~FLEXPWM_REIE_MASK)) | (param<<13)

#define ioctlFLEXPWM_RELOAD_INT(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_INTEN_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_INTEN_OFFSET)) & (~FLEXPWM_RIE_MASK)) | (param<<12)

#define ioctlFLEXPWM_CAPTURE_X1_INT(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_INTEN_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_INTEN_OFFSET)) & (~FLEXPWM_CX1IE_MASK)) | (param<<7)

#define ioctlFLEXPWM_CAPTURE_X0_INT(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_INTEN_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_INTEN_OFFSET)) & (~FLEXPWM_CX0IE_MASK)) | (param<<6)

#define ioctlFLEXPWM_DISABLE_VAL_COMPARE_INT(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_INTEN_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_INTEN_OFFSET)) & (~FLEXPWM_CMPIE_MASK)) | (param)

#define ioctlFLEXPWM_ENABLE_VAL_COMPARE_INT(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_INTEN_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_INTEN_OFFSET)) & (~FLEXPWM_CMPIE_MASK)) | (param)

#define ioctlFLEXPWM_DMA_VAL_WRITE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DMAEN_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DMAEN_OFFSET)) & (~FLEXPWM_VALDE_MASK)) | (param<<9)

#define ioctlFLEXPWM_FIFO_WM_CONTROL(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DMAEN_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DMAEN_OFFSET)) & (~FLEXPWM_FAND_MASK)) | (param<<8)

#define ioctlFLEXPWM_DMA_FIFO_READ(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DMAEN_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DMAEN_OFFSET)) & (~FLEXPWM_CAPTDE_MASK)) | (param<<6)

#define ioctlFLEXPWM_CAPTURE_X1_DMA(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DMAEN_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DMAEN_OFFSET)) & (~FLEXPWM_CX1DE_MASK)) | (param<<1)

#define ioctlFLEXPWM_CAPTURE_X0_DMA(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DMAEN_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DMAEN_OFFSET)) & (~FLEXPWM_CX0DE_MASK)) | (param)

#define ioctlFLEXPWM_ENABLE_VAL_COMPARE_OUTTRG(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_TCTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_TCTRL_OFFSET)) & (~FLEXPWM_OUT_TRIG_EN_MASK)) | (param)

#define ioctlFLEXPWM_FAULT_MASK_PWMX(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DISMAP_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DISMAP_OFFSET)) & (~FLEXPWM_DISX_MASK)) | (param<<8)

#define ioctlFLEXPWM_FAULT_MASK_PWMB(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DISMAP_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DISMAP_OFFSET)) & (~FLEXPWM_DISB_MASK)) | (param<<4)

#define ioctlFLEXPWM_FAULT_MASK_PWMA(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DISMAP_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DISMAP_OFFSET)) & (~FLEXPWM_DISA_MASK)) | (param)

#define ioctlFLEXPWM_SET_DEADTIME_PWMA(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTCNT0_OFFSET)) = (param)

#define ioctlFLEXPWM_SET_DEADTIME_PWMB(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTCNT1_OFFSET)) = (param)

#define ioctlFLEXPWM_GET_CAPTUREX1_FIFO_COUNT(flexpwmAddr,param) \
        (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) & (FLEXPWM_CX1CNT_MASK)) >>13

#define ioctlFLEXPWM_GET_CAPTUREX0_FIFO_COUNT(flexpwmAddr,param) \
        (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) & (FLEXPWM_CX0CNT_MASK)) >>10

#define ioctlFLEXPWM_SET_CAPTURE_FIFO_WATERMARK(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) & (~FLEXPWM_CFXWM_MASK)) | (param<<8)

#define ioctlFLEXPWM_PWMX_EDGE_COUNTER(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) & (~FLEXPWM_EDGCNTX_EN_MASK)) | (param<<7)

#define ioctlFLEXPWM_CAPTURE_SOURCE_SIGNAL(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) & (~FLEXPWM_INP_SELX_MASK)) | (param<<6)

#define ioctlFLEXPWM_CAPTURE_X1_EVENT(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) & (~FLEXPWM_EDGX1_MASK)) | (param<<4)

#define ioctlFLEXPWM_CAPTURE_X0_EVENT(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) & (~FLEXPWM_EDGX0_MASK)) | (param<<2)

#define ioctlFLEXPWM_CAPTURE_MODE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) & (~FLEXPWM_ONESHOTX_MASK)) | (param<<1)

#define ioctlFLEXPWM_CAPTURE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_CAPTCTRLX_OFFSET)) & (~FLEXPWM_ARMX_MASK)) | (param)

#define ioctlFLEXPWM_OUTPUT(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_OUTEN_OFFSET)) = (param)

#define ioctlFLEXPWM_MASK(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_MASK_OFFSET)) = (param)

#define ioctlFLEXPWM_COMPLEMENTARY_PWM_SOURCE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_MCTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_MCTRL_OFFSET)) & (~FLEXPWM_IPOL_MASK)) | (param<<12)

#define ioctlFLEXPWM_PWM_GENERATOR_CLOCK(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_MCTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_MCTRL_OFFSET)) & (~FLEXPWM_RUN_MASK)) | (param<<8)

#define ioctlFLEXPWM_SET_LDOK(flexpwmAddr,param) \
        {\
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_MCTRL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_MCTRL_OFFSET)) & (~FLEXPWM_LDOK_MASK)) | (param);\
        }
        /*
         * while((((*((volatile tU16 *)(flexpwmAddr + FLEXPWM_MCTRL_OFFSET)) & (~FLEXPWM_LDOK_MASK))) & (param)) != 0);\
         */


#define ioctlFLEXPWM_SELECT_DT_SOURCE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) = (param)

#define ioctlFLEXPWM_SELECT_DT_SOURCE_SUB0_PWMA(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) & (~FLEXPWM_SUB0_PWMA_MASK)) | (param<<2)

#define ioctlFLEXPWM_SELECT_DT_SOURCE_SUB0_PWMB(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) & (~FLEXPWM_SUB0_PWMB_MASK)) | (param)

#define ioctlFLEXPWM_SELECT_DT_SOURCE_SUB1_PWMA(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) & (~FLEXPWM_SUB1_PWMA_MASK)) | (param<<6)

#define ioctlFLEXPWM_SELECT_DT_SOURCE_SUB1_PWMB(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) & (~FLEXPWM_SUB1_PWMB_MASK)) | (param<<4)

#define ioctlFLEXPWM_SELECT_DT_SOURCE_SUB2_PWMA(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) & (~FLEXPWM_SUB2_PWMA_MASK)) | (param<<10)

#define ioctlFLEXPWM_SELECT_DT_SOURCE_SUB2_PWMB(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) & (~FLEXPWM_SUB2_PWMB_MASK)) | (param<<8)

#define ioctlFLEXPWM_SELECT_DT_SOURCE_SUB3_PWMA(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) & (~FLEXPWM_SUB3_PWMA_MASK)) | (param<<14)

#define ioctlFLEXPWM_SELECT_DT_SOURCE_SUB3_PWMB(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) = (*((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET)) & (~FLEXPWM_SUB3_PWMB_MASK)) | (param<<12)

#define ioctlFLEXPWM_READ_DT_SOURCE(flexpwmAddr,param) \
        *((volatile tU16 *)(flexpwmAddr + FLEXPWM_DTSRCSEL_OFFSET))

//param &= 0xFFFE;\

#define ioctlFLEXPWM_SET_PWMA_DUTY_1PH_CENTERALIGN(flexpwmAddr,param) \
        {\
        ioctlFLEXPWM_SET_VAL2(flexpwmAddr,FLEXPWM_INV(param));\
        ioctlFLEXPWM_SET_VAL3(flexpwmAddr,param);\
        }

//        param &= 0xFFFE;\

#define ioctlFLEXPWM_SET_PWMB_DUTY_1PH_CENTERALIGN(flexpwmAddr,param) \
        {\
        ioctlFLEXPWM_SET_VAL4(flexpwmAddr,FLEXPWM_INV(param));\
        ioctlFLEXPWM_SET_VAL5(flexpwmAddr,param);\
        }

#define ioctlFLEXPWM_SET_PWMA_DUTY_1PH_EDGEALIGN(flexpwmAddr,param) \
        {\
        ioctlFLEXPWM_SET_VAL2(flexpwmAddr,ioctlFLEXPWM_GET_COUNTER_INIT_VALUE(flexpwmAddr,0));\
        ioctlFLEXPWM_SET_VAL3(flexpwmAddr,param);\
        }

#define ioctlFLEXPWM_SET_PWMB_DUTY_1PH_EDGEALIGN(flexpwmAddr,param) \
        {\
        ioctlFLEXPWM_SET_VAL4(flexpwmAddr,ioctlFLEXPWM_GET_COUNTER_INIT_VALUE(flexpwmAddr,0));\
        ioctlFLEXPWM_SET_VAL5(flexpwmAddr,param);\
        }

#define ioctlFLEXPWM_SET_PWMA_DUTY_3PH_CENTERALIGN(flexpwmModule,param) \
        {\
        ioctlFLEXPWM_SET_PWMA_DUTY_1PH_CENTERALIGN(flexpwmModule + 0x0,param.s16sub0);\
        ioctlFLEXPWM_SET_PWMA_DUTY_1PH_CENTERALIGN(flexpwmModule + 0x50,param.s16sub1);\
        ioctlFLEXPWM_SET_PWMA_DUTY_1PH_CENTERALIGN(flexpwmModule + 0xa0,param.s16sub2);\
        }
        /*
         * ioctlFLEXPWM_SET_LDOK(flexpwmModule, FLEXPWM_SUB0_LDOK | FLEXPWM_SUB1_LDOK | FLEXPWM_SUB2_LDOK | FLEXPWM_SUB3_LDOK);\
         */

#define ioctlFLEXPWM_SET_PWMA_DUTY_3PH_EDGEALIGN(flexpwmModule,param) \
        {\
        ioctlFLEXPWM_SET_PWMA_DUTY_1PH_EDGEALIGN(flexpwmModule + 0x0,param.s16sub0);\
        ioctlFLEXPWM_SET_PWMA_DUTY_1PH_EDGEALIGN(flexpwmModule + 0x50,param.s16sub1);\
        ioctlFLEXPWM_SET_PWMA_DUTY_1PH_EDGEALIGN(flexpwmModule + 0xa0,param.s16sub2);\
        }
        /*
         * ioctlFLEXPWM_SET_LDOK(flexpwmModule, FLEXPWM_SUB0_LDOK | FLEXPWM_SUB1_LDOK | FLEXPWM_SUB2_LDOK | FLEXPWM_SUB3_LDOK);\
         */

#define ioctlFLEXPWM_SET_PWMB_DUTY_3PH_CENTERALIGN(flexpwmModule,param) \
        {\
        ioctlFLEXPWM_SET_PWMB_DUTY_1PH_CENTERALIGN(flexpwmModule + 0x0,param.s16sub0);\
        ioctlFLEXPWM_SET_PWMB_DUTY_1PH_CENTERALIGN(flexpwmModule + 0x50,param.s16sub1);\
        ioctlFLEXPWM_SET_PWMB_DUTY_1PH_CENTERALIGN(flexpwmModule + 0xa0,param.s16sub2);\
        }
        /*
         * ioctlFLEXPWM_SET_LDOK(flexpwmModule, FLEXPWM_SUB0_LDOK | FLEXPWM_SUB1_LDOK | FLEXPWM_SUB2_LDOK | FLEXPWM_SUB3_LDOK);\
         */

#define ioctlFLEXPWM_SET_PWMB_DUTY_3PH_EDGEALIGN(flexpwmModule,param) \
        {\
        ioctlFLEXPWM_SET_PWMB_DUTY_1PH_EDGEALIGN(flexpwmModule + 0x0,param.s16sub0);\
        ioctlFLEXPWM_SET_PWMB_DUTY_1PH_EDGEALIGN(flexpwmModule + 0x50,param.s16sub1);\
        ioctlFLEXPWM_SET_PWMB_DUTY_1PH_EDGEALIGN(flexpwmModule + 0xa0,param.s16sub2);\
        }
        /*
         * ioctlFLEXPWM_SET_LDOK(flexpwmModule, FLEXPWM_SUB0_LDOK | FLEXPWM_SUB1_LDOK | FLEXPWM_SUB2_LDOK | FLEXPWM_SUB3_LDOK);\
         */


typedef struct{
    tU16    s16sub0;
    tU16    s16sub1;
    tU16    s16sub2;
    tU16    s16sub3;
}FLEXPWM_VAL_COMPL;

//extern void flexpwm_set_pwm_duty_centeralign(volatile mcPWM_tag *flexpwmModule, tU16 u16PwmID, FLEXPWM_VAL_COMPL *pPwmVal);
//extern void flexpwm_set_pwm_duty_edgealign(volatile mcPWM_tag *flexpwmModule, tU16 u16PwmID, FLEXPWM_VAL_COMPL *pPwmVal);

#ifdef __cplusplus
}
#endif

#endif /* _MPC5643L_FLEXPWM_LLD_H_ */
