/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!
*
* @file     MPC5643L_PIT_LLD.c
*
* @author   b15651
*
* @version  1.0.1.0
*
* @date     Jul-13-2012
*
* @brief    PIT low level driver module for MPC5643L
*
*******************************************************************************
*
* This file includes initial setting functions of MPC5643L PIT module.
*
******************************************************************************/
#include "MPC5643L_qs.h"
#include "MPC5643L_LLD_qs.h"

/******************************************************************************
* PIT functions
*****************************************************************************/

/**************************************************************************//*!
@ingroup        MC33937_GROUP
@brief          MC33937 pre-driver configuration function.

@param[in,out]  *SetPtr

@return         dt_set_fault

@details        The function provide configuration of MC33937 pre-driver and
                setup deadtime between top and bottom transistor. Function uses
                PIT module and DSPI module.

@note           This function is used to configure MC33937

@warning
******************************************************************************/
void    delayNanoSec(tU32 delay_ns)
{
    // disable timer for setup new period
    ioctl(PIT_BASE,PIT_TIMER, PIT_DISABLE);

    // delay time
    ioctl(PIT_CHNL0_BASE,PIT_SET_TMR_RELOAD_VALUE, ((delay_ns * PIT_CLK)/1000));
    //ioctl(PIT_CHNL0_BASE,PIT_SET_TMR_RELOAD_VALUE, delay_ns);

    // enable timer
    ioctl(PIT_CHNL0_BASE,PIT_TIMER, PIT_ENABLE);

    // wait defined time
    while (!(ioctl(PIT_CHNL0_BASE,PIT_GET_FLAG, NULL)));

    // disable timer
    ioctl(PIT_CHNL0_BASE,PIT_TIMER, PIT_DISABLE);

    // clear interrupt flag
    ioctl(PIT_CHNL0_BASE,PIT_CLEAR_FLAG, PIT_CLEAR_FLAG);

}
