/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!
*
* @file     ctu.c
*
* @author   r63172
*
* @version  1.0.1.0
*
* @date     Jul-13-2012
*
* @brief    CTU - Cross Triggering Unit for MPC5604P
*
*******************************************************************************
*
* This file includes initial setting function of MPC5604P CTU peripheral module.
*
******************************************************************************/
#include "MPC5643L_qs.h"
#include "ctu.h"

/******************************************************************************
* CTU functions
*****************************************************************************/
volatile CTU_tag *pCTU;
/***************************************************************************//*!
@brief          Cross Triggering Unit init function

@param[in,out]  void
@param[in]      void

@return         void

@details        This function initializes basic start-up setting of the CTU.

@note

@warning
******************************************************************************/
void ctu_init(void)
{
    static volatile tU8         i;
    static volatile tU32        readValue32;

    // initialization of peripheral base address
    pCTU=(CTU_tag *)&CTU_0;

    /*-------------------------------------------------------------------------
     * CTU registers reset
    --------------------------------------------------------------------------*/
    pCTU->TGSISR.R          = 0x0;
    pCTU->TGSCR.R           = 0x0;

    for (i = 0; i<=7; i++)
        pCTU->TCR[i].R          = 0x0;

    pCTU->TGSCCR.R          = 0x0;
    pCTU->TGSCRR.R          = 0x0;
    pCTU->CLCR1.R           = 0x0;
    pCTU->CLCR2.R           = 0x0;
    pCTU->THCR1.R           = 0x0;
    pCTU->THCR2.R           = 0x0;

    for (i = 0; i<=23; i++)
    pCTU->CLR[i].R          = 0x0;

    // FDCR (in MPC5643L_RM Rev6)
    pCTU->CR.R              = 0x0;

    pCTU->FCR.R             = 0x0;

    // FTH (in MPC5643L_RM Rev6)
    pCTU->TH1.R             = 0x0;

    for (i = 0; i<=3; i++)
        pCTU->FLA[i].R          = 0x0;

    for (i = 0; i<=3; i++)
        pCTU->FRA[i].R          = 0x0;

    readValue32             = pCTU->CTUEFR.R;
    pCTU->CTUEFR.R          = 0x00;

    pCTU->CTUIFR.R          = 0x0;
    pCTU->CTUIR.R           = 0x0;
    pCTU->COTR.R            = 0x0;
    pCTU->CTUCR.R           = 0x0;
    pCTU->CTUFILTER.R       = 0x0;

    //pCTU->CTUPCR.R          = 0x0;

    pCTU->STATUS.R          = 0x0;

    /*-------------------------------------------------------------------------
     * CTU Control registers
    --------------------------------------------------------------------------*/
    #ifdef CTU_TGSISR                   /* TGSISR register */
        pCTU->TGSISR.R     = CTU_TGSISR;
    #endif

    #ifdef CTU_TGSCR                    /* TGSCR register */
        pCTU->TGSCR.R      = CTU_TGSCR;
    #endif

    #ifdef CTU_T0CR                     /* TCR[0] register */
        pCTU->TCR[0].R     = CTU_T0CR;
    #endif

    #ifdef CTU_T1CR                     /* TCR[1] register */
        pCTU->TCR[1].R     = CTU_T1CR;
    #endif

    #ifdef CTU_T2CR                     /* TCR[2] register */
        pCTU->TCR[2].R     = CTU_T2CR;
    #endif

    #ifdef CTU_T3CR                     /* TCR[3] register */
        pCTU->TCR[3].R     = CTU_T3CR;
    #endif

    #ifdef CTU_T4CR                     /* TCR[4] register */
        pCTU->TCR[4].R     = CTU_T4CR;
    #endif

    #ifdef CTU_T5CR                     /* TCR[5] register */
        pCTU->TCR[5].R     = CTU_T5CR;
    #endif

    #ifdef CTU_T6CR                     /* TCR[6] register */
        pCTU->TCR[6].R     = CTU_T6CR;
    #endif

    #ifdef CTU_T7CR                     /* TCR[7] register */
        pCTU->TCR[7].R     = CTU_T7CR;
    #endif

    #ifdef CTU_TGSCCR                   /* TGSCCR register */
        pCTU->TGSCCR.R     = CTU_TGSCCR;
    #endif

    #ifdef CTU_TGSCRR                   /* TGSCRR register */
        pCTU->TGSCRR.R     = CTU_TGSCRR;
    #endif

    #ifdef CTU_CLCR1                    /* CLCR1 register */
        pCTU->CLCR1.R      = CTU_CLCR1;
    #endif

    #ifdef CTU_CLCR2                    /* CLCR2 register */
        pCTU->CLCR2.R      = CTU_CLCR2;
    #endif

    #ifdef CTU_THCR1                    /* THCR1 register */
        pCTU->THCR1.R      = CTU_THCR1;
    #endif

    #ifdef CTU_THCR2                    /* THCR2 register */
        pCTU->THCR2.R      = CTU_THCR2;
    #endif

    #ifdef CTU_CLR0                     /* CLR[0] register */
       pCTU->CLR[0].R       = CTU_CLR0;
    #endif

    #ifdef CTU_CLR1                     /* CLR[1] register */
       pCTU->CLR[1].R       = CTU_CLR1;
    #endif

    #ifdef CTU_CLR2                     /* CLR[2] register */
       pCTU->CLR[2].R       = CTU_CLR2;
    #endif

    #ifdef CTU_CLR3                     /* CLR[3] register */
       pCTU->CLR[3].R       = CTU_CLR3;
    #endif

    #ifdef CTU_CLR4                     /* CLR[4] register */
       pCTU->CLR[4].R       = CTU_CLR4;
    #endif

    #ifdef CTU_CLR5                     /* CLR[5] register */
       pCTU->CLR[5].R       = CTU_CLR5;
    #endif

    #ifdef CTU_CLR6                     /* CLR[6] register */
       pCTU->CLR[6].R       = CTU_CLR6;
    #endif

    #ifdef CTU_CLR7                     /* CLR[7] register */
       pCTU->CLR[7].R       = CTU_CLR7;
    #endif

    #ifdef CTU_CLR8                     /* CLR[8] register */
       pCTU->CLR[8].R       = CTU_CLR8;
    #endif

    #ifdef CTU_CLR9                     /* CLR[9] register */
       pCTU->CLR[9].R       = CTU_CLR9;
    #endif

    #ifdef CTU_CLR10                    /* CLR[10] register */
       pCTU->CLR[10].R      = CTU_CLR10;
    #endif

    #ifdef CTU_CLR11                    /* CLR[11] register */
       pCTU->CLR[11].R      = CTU_CLR11;
    #endif

    #ifdef CTU_CLR12                    /* CLR[12] register */
       pCTU->CLR[12].R      = CTU_CLR12;
    #endif

    #ifdef CTU_CLR13                    /* CLR[13] register */
       pCTU->CLR[13].R      = CTU_CLR13;
    #endif

    #ifdef CTU_CLR14                    /* CLR[14] register */
       pCTU->CLR[14].R      = CTU_CLR14;
    #endif

    #ifdef CTU_CLR15                    /* CLR[15] register */
       pCTU->CLR[15].R      = CTU_CLR15;
    #endif

    #ifdef CTU_CLR16                    /* CLR[16] register */
       pCTU->CLR[16].R      = CTU_CLR16;
    #endif

    #ifdef CTU_CLR17                    /* CLR[17] register */
       pCTU->CLR[17].R      = CTU_CLR17;
    #endif

    #ifdef CTU_CLR18                    /* CLR[18] register */
       pCTU->CLR[18].R      = CTU_CLR18;
    #endif

    #ifdef CTU_CLR19                    /* CLR[19] register */
       pCTU->CLR[19].R      = CTU_CLR19;
    #endif

    #ifdef CTU_CLR20                    /* CLR[20] register */
       pCTU->CLR[20].R      = CTU_CLR20;
    #endif

    #ifdef CTU_CLR21                    /* CLR[21] register */
       pCTU->CLR[21].R      = CTU_CLR21;
    #endif

    #ifdef CTU_CLR22                    /* CLR[22] register */
       pCTU->CLR[22].R      = CTU_CLR22;
    #endif

    #ifdef CTU_CLR23                    /* CLR[23] register */
       pCTU->CLR[23].R      = CTU_CLR23;
    #endif

    #ifdef CTU_FDCR                       /* CR register */
       pCTU->CR.R           = CTU_FDCR;
    #endif

    #ifdef CTU_FCR                      /* FCR register */
       pCTU->FCR.R          = CTU_FCR;
    #endif

    #ifdef CTU_FTH                      /* TH1 register */
       pCTU->TH1.R          = CTU_FTH;
    #endif

    #ifdef CTU_CTUIR                    /* CTUIR register */
       pCTU->CTUIR.R        = CTU_CTUIR;
    #endif

    #ifdef CTU_COTR                     /* COTR register */
       pCTU->COTR.R         = CTU_COTR;
    #endif

    #ifdef CTU_CTUFILTER                /* CTUFILTER register */
       pCTU->CTUFILTER.R    = CTU_CTUFILTER;
    #endif

    // must be defined last in order to correctly write to double buffered
    // registers using GRE and TGSISR_RE
    #ifdef CTU_CTUCR                    /* CTUCR register */
       pCTU->CTUCR.R        = (CTU_CTUCR & (0xFFFB)); // mask out MRS_SG bit
    #endif
//       pCTU->CTUCR.R               = 0;
       pCTU->CTUCR.B.GRE           = 1;    // CTU General Reload Enable

    #ifdef CTU_CTUCR                    /* CTUCR register */
       pCTU->CTUCR.R        = (CTU_CTUCR & (0x4)); // enable MRS_SG bit
    #endif
}
