/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!
*
* @file     dspi.c
*
* @author   b15651
*
* @version  1.0.1.0
*
* @date     Jul-13-2012
*
* @brief    DSPI - DSPI module on MPC5643L
*
*******************************************************************************
*
* This file includes initial setting functions of MPC5604P DSPI module.
*
******************************************************************************/
#include "MPC5643L_qs.h"
#include "dspi.h"

/******************************************************************************
* DSPI functions
*****************************************************************************/
volatile DSPI_tag *pDSPI0;
volatile DSPI_tag *pDSPI1;
volatile DSPI_tag *pDSPI2;
/***************************************************************************//*!
@brief          DSPi init function

@param[in,out]  void

@return         void

@details        This function initializes basic start-up setting of the DSPI
                modules 0 to 2.

@note

@warning
******************************************************************************/
void dspi_init(void)
{
    pDSPI0  = (DSPI_tag *)&DSPI_A;
    pDSPI1  = (DSPI_tag *)&DSPI_B;
    pDSPI2  = (DSPI_tag *)&DSPI_C;

    /*-------------------------------------------------------------------------
     * DSPI0 Reset
    --------------------------------------------------------------------------*/
    pDSPI0->MCR.R               = 0x1;
    pDSPI0->CTAR[0].R           = 0x38000000;
    pDSPI0->CTAR[1].R           = 0x38000000;
    pDSPI0->CTAR[2].R           = 0x38000000;
    pDSPI0->CTAR[3].R           = 0x38000000;
    pDSPI0->RSER.R              = 0x0;
    /*-------------------------------------------------------------------------
     * DSPI1 Reset
    --------------------------------------------------------------------------*/
    pDSPI1->MCR.R               = 0x1;
    pDSPI1->CTAR[0].R           = 0x38000000;
    pDSPI1->CTAR[1].R           = 0x38000000;
    pDSPI1->CTAR[2].R           = 0x38000000;
    pDSPI1->CTAR[3].R           = 0x38000000;
    pDSPI1->RSER.R              = 0x0;
    /*-------------------------------------------------------------------------
     * DSPI2 Reset
    --------------------------------------------------------------------------*/
    pDSPI2->MCR.R               = 0x1;
    pDSPI2->CTAR[0].R           = 0x38000000;
    pDSPI2->CTAR[1].R           = 0x38000000;
    pDSPI2->CTAR[2].R           = 0x38000000;
    pDSPI2->CTAR[3].R           = 0x38000000;
    pDSPI2->RSER.R              = 0x0;
    /*-------------------------------------------------------------------------
     * DSPI0 Control registers
    --------------------------------------------------------------------------*/
    #ifdef DSPI0_MCR                  /* MCR register */
        pDSPI0->MCR.R           = DSPI0_MCR;
    #endif

    #ifdef DSPI0_TCR                   /* TCR register */
        pDSPI0->TCR.R           = DSPI0_TCR;
    #endif

    #ifdef DSPI0_CTAR0                   /* CTAR[0] register */
        pDSPI0->CTAR[0].R       = DSPI0_CTAR0;
    #endif

    #ifdef DSPI0_CTAR1                   /* CTAR[1] register */
        pDSPI0->CTAR[1].R       = DSPI0_CTAR1;
    #endif

    #ifdef DSPI0_CTAR2                   /* CTAR[2] register */
        pDSPI0->CTAR[2].R       = DSPI0_CTAR2;
    #endif

    #ifdef DSPI0_CTAR3                   /* CTAR[3] register */
        pDSPI0->CTAR[3].R       = DSPI0_CTAR3;
    #endif

    #ifdef DSPI0_RSER                   /* RSER register */
        pDSPI0->RSER.R          = DSPI0_RSER;
    #endif

    /*-------------------------------------------------------------------------
     * DSPI1 Control registers
    --------------------------------------------------------------------------*/
    #ifdef DSPI1_MCR                  /* MCR register */
        pDSPI1->MCR.R           = DSPI1_MCR;
    #endif

    #ifdef DSPI1_TCR                   /* TCR register */
        pDSPI1->TCR.R           = DSPI1_TCR;
    #endif

    #ifdef DSPI1_CTAR0                   /* CTAR[0] register */
        pDSPI1->CTAR[0].R       = DSPI1_CTAR0;
    #endif

    #ifdef DSPI1_CTAR1                   /* CTAR[1] register */
        pDSPI1->CTAR[1].R       = DSPI1_CTAR1;
    #endif

    #ifdef DSPI1_CTAR2                   /* CTAR[2] register */
        pDSPI1->CTAR[2].R       = DSPI1_CTAR2;
    #endif

    #ifdef DSPI1_CTAR3                   /* CTAR[3] register */
        pDSPI1->CTAR[3].R       = DSPI1_CTAR3;
    #endif

    #ifdef DSPI1_RSER                   /* RSER register */
        pDSPI1->RSER.R          = DSPI1_RSER;
    #endif

    /*-------------------------------------------------------------------------
     * DSPI2 Control registers
    --------------------------------------------------------------------------*/
    #ifdef DSPI2_MCR                  /* MCR register */
        pDSPI2->MCR.R           = DSPI2_MCR;
    #endif

    #ifdef DSPI2_TCR                   /* TCR register */
        pDSPI2->TCR.R           = DSPI2_TCR;
    #endif

    #ifdef DSPI2_CTAR0                   /* CTAR[0] register */
        pDSPI2->CTAR[0].R       = DSPI2_CTAR0;
    #endif

    #ifdef DSPI2_CTAR1                   /* CTAR[1] register */
        pDSPI2->CTAR[1].R       = DSPI2_CTAR1;
    #endif

    #ifdef DSPI2_CTAR2                   /* CTAR[2] register */
        pDSPI2->CTAR[2].R       = DSPI2_CTAR2;
    #endif

    #ifdef DSPI2_CTAR3                   /* CTAR[3] register */
        pDSPI2->CTAR[3].R       = DSPI2_CTAR3;
    #endif

    #ifdef DSPI2_RSER                   /* RSER register */
        pDSPI2->RSER.R          = DSPI2_RSER;
    #endif

}
