/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!
*
* @file     eTimer.c
*
* @author   r63172
* 
* @version  1.0.1.0
* 
* @date     Jul-13-2012
* 
* @brief    eTimer - eTimer for MPC5643L
*
*******************************************************************************
*
* This file includes initial setting function of MPC5643L eTimer peripheral
* module.
*
******************************************************************************/
#include "MPC5643L_qs.h"
#include "eTimer.h"

/******************************************************************************
* eTimer functions
*****************************************************************************/
volatile mcTIMER_tag *pETIMER_0;
volatile mcTIMER_tag *pETIMER_1;
volatile mcTIMER_tag *pETIMER_2;
/***************************************************************************//*!
@brief          eTimer0 init function

@param[in,out]  void
@param[in]      void

@return         void

@details        This function initializes basic start-up setting of the eTimer0.

@note           

@warning        
******************************************************************************/
void etimer0_init(void)
{
    int i;

    // initialization of peripheral base address
    pETIMER_0=(mcTIMER_tag *)&mcTIMER0;

    /*-------------------------------------------------------------------------
     * eTimer0 Reset
    --------------------------------------------------------------------------*/
    for (i=0;i<=5;i++)
    {
        pETIMER_0->CHANNEL[0].CAPT1.R   = 0x0;
        pETIMER_0->CHANNEL[0].CAPT2.R   = 0x0;
        pETIMER_0->CHANNEL[0].CCCTRL.R  = 0x0;
        pETIMER_0->CHANNEL[0].CMPLD1.R  = 0x0;
        pETIMER_0->CHANNEL[0].CMPLD2.R  = 0x0;
        pETIMER_0->CHANNEL[0].CNTR.R    = 0x0;
        pETIMER_0->CHANNEL[0].COMP1.R   = 0x0;
        pETIMER_0->CHANNEL[0].COMP2.R   = 0x0;
        pETIMER_0->CHANNEL[0].CTRL.R    = 0x0;
        pETIMER_0->CHANNEL[0].CTRL2.R   = 0x0;
        pETIMER_0->CHANNEL[0].CTRL3.R   = 0x0;
        pETIMER_0->CHANNEL[0].FILT.R    = 0x0;
        pETIMER_0->CHANNEL[0].HOLD.R    = 0x0;
        pETIMER_0->CHANNEL[0].INTDMA.R  = 0x0;
        pETIMER_0->CHANNEL[0].LOAD.R    = 0x0;
        pETIMER_0->CHANNEL[0].STS.R     = 0x0;
    }

    pETIMER_0->DREQ[0].R    = 0x0;
    pETIMER_0->DREQ[1].R    = 0x0;
    pETIMER_0->ENBL.R       = 0x0;
    pETIMER_0->WDTOH.R      = 0x0;
    pETIMER_0->WDTOL.R      = 0x0;
    
    /*-------------------------------------------------------------------------
     * eTimer #0 Control registers
    --------------------------------------------------------------------------*/
    #ifdef eTimer0_WDTOL                    /* WDTOL register */
        pETIMER_0->WDTOL.R              = eTimer0_WDTOL;
    #endif
    
    #ifdef eTimer0_WDTOH                    /* WDTOH register */
        pETIMER_0->WDTOH.R              = eTimer0_WDTOH;
    #endif
    
    #ifdef eTimer0_ENBL                     /* ENBL register */
        pETIMER_0->ENBL.R               = eTimer0_ENBL;
    #endif
    
    #ifdef eTimer0_DREQ0                    /* DREQ[0] register */
        pETIMER_0->DREQ[0].R            = eTimer0_DREQ0;
    #endif
    
    #ifdef eTimer0_DREQ1                    /* DREQ[1] register */
        pETIMER_0->DREQ[1].R            = eTimer0_DREQ1;
    #endif

    /*-------------------------------------------------------------------------
     * eTimer #0 CHANNEL #0 Control registers
    --------------------------------------------------------------------------*/
    #ifdef eTimer0_COMP1_CH0                /* COMP1 register */
        pETIMER_0->CHANNEL[0].COMP1.R   = eTimer0_COMP1_CH0;
    #endif
    
    #ifdef eTimer0_COMP2_CH0                /* COMP2 register */
        pETIMER_0->CHANNEL[0].COMP2.R   = eTimer0_COMP2_CH0;
    #endif
    
    #ifdef eTimer0_LOAD_CH0                 /* LOAD register */
        pETIMER_0->CHANNEL[0].LOAD.R    = eTimer0_LOAD_CH0;
    #endif
    
    #ifdef eTimer0_CTRL_CH0                 /* CTRL register */
        pETIMER_0->CHANNEL[0].CTRL.R    = eTimer0_CTRL_CH0;
    #endif
    
    #ifdef eTimer0_CTRL2_CH0                /* CTRL2 register */
        pETIMER_0->CHANNEL[0].CTRL2.R   = eTimer0_CTRL2_CH0;
    #endif
    
    #ifdef eTimer0_CTRL3_CH0                /* CTRL3 register */
        pETIMER_0->CHANNEL[0].CTRL3.R   = eTimer0_CTRL3_CH0;
    #endif
    
    #ifdef eTimer0_INTDMA_CH0               /* INTDMA register */
        pETIMER_0->CHANNEL[0].INTDMA.R  = eTimer0_INTDMA_CH0;
    #endif
    
    #ifdef eTimer0_CMPLD1_CH0               /* CMPLD1 register */
        pETIMER_0->CHANNEL[0].CMPLD1.R  = eTimer0_CMPLD1_CH0;
    #endif
    
    #ifdef eTimer0_CMPLD2_CH0               /* CMPLD2 register */
        pETIMER_0->CHANNEL[0].CMPLD2.R  = eTimer0_CMPLD2_CH0;
    #endif
    
    #ifdef eTimer0_CCCTRL_CH0               /* CCCTRL register */
        pETIMER_0->CHANNEL[0].CCCTRL.R  = eTimer0_CCCTRL_CH0;
    #endif
    
    #ifdef eTimer0_FILT_CH0                 /* FILT register */
        pETIMER_0->CHANNEL[0].FILT.R    = eTimer0_FILT_CH0;
    #endif

    /*-------------------------------------------------------------------------
     * eTimer #0 CHANNEL #1 Control registers
    --------------------------------------------------------------------------*/
    #ifdef eTimer0_COMP1_CH1                /* COMP1 register */
        pETIMER_0->CHANNEL[1].COMP1.R   = eTimer0_COMP1_CH1;
    #endif
    
    #ifdef eTimer0_COMP2_CH1                /* COMP2 register */
        pETIMER_0->CHANNEL[1].COMP2.R   = eTimer0_COMP2_CH1;
    #endif
    
    #ifdef eTimer0_LOAD_CH1                 /* LOAD register */
        pETIMER_0->CHANNEL[1].LOAD.R    = eTimer0_LOAD_CH1;
    #endif
    
    #ifdef eTimer0_CTRL_CH1                 /* CTRL register */
        pETIMER_0->CHANNEL[1].CTRL.R    = eTimer0_CTRL_CH1;
    #endif
    
    #ifdef eTimer0_CTRL2_CH1                /* CTRL2 register */
        pETIMER_0->CHANNEL[1].CTRL2.R   = eTimer0_CTRL2_CH1;
    #endif
    
    #ifdef eTimer0_CTRL3_CH1                /* CTRL3 register */
        pETIMER_0->CHANNEL[1].CTRL3.R   = eTimer0_CTRL3_CH1;
    #endif
    
    #ifdef eTimer0_INTDMA_CH1               /* INTDMA register */
        pETIMER_0->CHANNEL[1].INTDMA.R  = eTimer0_INTDMA_CH1;
    #endif
    
    #ifdef eTimer0_CMPLD1_CH1               /* CMPLD1 register */
        pETIMER_0->CHANNEL[1].CMPLD1.R  = eTimer0_CMPLD1_CH1;
    #endif
    
    #ifdef eTimer0_CMPLD2_CH1               /* CMPLD2 register */
        pETIMER_0->CHANNEL[1].CMPLD2.R  = eTimer0_CMPLD2_CH1;
    #endif
    
    #ifdef eTimer0_CCCTRL_CH1               /* CCCTRL register */
        pETIMER_0->CHANNEL[1].CCCTRL.R  = eTimer0_CCCTRL_CH1;
    #endif
    
    #ifdef eTimer0_FILT_CH1                 /* FILT register */
        pETIMER_0->CHANNEL[1].FILT.R    = eTimer0_FILT_CH1;
    #endif

    /*-------------------------------------------------------------------------
     * eTimer #0 CHANNEL #2 Control registers
    --------------------------------------------------------------------------*/
    #ifdef eTimer0_COMP1_CH2                /* COMP1 register */
        pETIMER_0->CHANNEL[2].COMP1.R   = eTimer0_COMP1_CH2;
    #endif
    
    #ifdef eTimer0_COMP2_CH2                /* COMP2 register */
        pETIMER_0->CHANNEL[2].COMP2.R   = eTimer0_COMP2_CH2;
    #endif
    
    #ifdef eTimer0_LOAD_CH2                 /* LOAD register */
        pETIMER_0->CHANNEL[2].LOAD.R    = eTimer0_LOAD_CH2;
    #endif
    
    #ifdef eTimer0_CTRL_CH2                 /* CTRL register */
        pETIMER_0->CHANNEL[2].CTRL.R    = eTimer0_CTRL_CH2;
    #endif
    
    #ifdef eTimer0_CTRL2_CH2                /* CTRL2 register */
        pETIMER_0->CHANNEL[2].CTRL2.R   = eTimer0_CTRL2_CH2;
    #endif
    
    #ifdef eTimer0_CTRL3_CH2                /* CTRL3 register */
        pETIMER_0->CHANNEL[2].CTRL3.R   = eTimer0_CTRL3_CH2;
    #endif
    
    #ifdef eTimer0_INTDMA_CH2               /* INTDMA register */
        pETIMER_0->CHANNEL[2].INTDMA.R  = eTimer0_INTDMA_CH2;
    #endif
    
    #ifdef eTimer0_CMPLD1_CH2               /* CMPLD1 register */
        pETIMER_0->CHANNEL[2].CMPLD1.R  = eTimer0_CMPLD1_CH2;
    #endif
    
    #ifdef eTimer0_CMPLD2_CH2               /* CMPLD2 register */
        pETIMER_0->CHANNEL[2].CMPLD2.R  = eTimer0_CMPLD2_CH2;
    #endif
    
    #ifdef eTimer0_CCCTRL_CH2               /* CCCTRL register */
        pETIMER_0->CHANNEL[2].CCCTRL.R  = eTimer0_CCCTRL_CH2;
    #endif
    
    #ifdef eTimer0_FILT_CH2                 /* FILT register */
        pETIMER_0->CHANNEL[2].FILT.R    = eTimer0_FILT_CH2;
    #endif

    /*-------------------------------------------------------------------------
     * eTimer #0 CHANNEL #3 Control registers
    --------------------------------------------------------------------------*/
    #ifdef eTimer0_COMP1_CH3                /* COMP1 register */
        pETIMER_0->CHANNEL[3].COMP1.R   = eTimer0_COMP1_CH3;
    #endif
    
    #ifdef eTimer0_COMP2_CH3                /* COMP2 register */
        pETIMER_0->CHANNEL[3].COMP2.R   = eTimer0_COMP2_CH3;
    #endif
    
    #ifdef eTimer0_LOAD_CH3                 /* LOAD register */
        pETIMER_0->CHANNEL[3].LOAD.R    = eTimer0_LOAD_CH3;
    #endif
    
    #ifdef eTimer0_CTRL_CH3                 /* CTRL register */
        pETIMER_0->CHANNEL[3].CTRL.R    = eTimer0_CTRL_CH3;
    #endif
    
    #ifdef eTimer0_CTRL2_CH3                /* CTRL2 register */
        pETIMER_0->CHANNEL[3].CTRL2.R   = eTimer0_CTRL2_CH3;
    #endif
    
    #ifdef eTimer0_CTRL3_CH3                /* CTRL3 register */
        pETIMER_0->CHANNEL[3].CTRL3.R   = eTimer0_CTRL3_CH3;
    #endif
    
    #ifdef eTimer0_INTDMA_CH3               /* INTDMA register */
        pETIMER_0->CHANNEL[3].INTDMA.R  = eTimer0_INTDMA_CH3;
    #endif
    
    #ifdef eTimer0_CMPLD1_CH3               /* CMPLD1 register */
        pETIMER_0->CHANNEL[3].CMPLD1.R  = eTimer0_CMPLD1_CH3;
    #endif
    
    #ifdef eTimer0_CMPLD2_CH3               /* CMPLD2 register */
        pETIMER_0->CHANNEL[3].CMPLD2.R  = eTimer0_CMPLD2_CH3;
    #endif
    
    #ifdef eTimer0_CCCTRL_CH3               /* CCCTRL register */
        pETIMER_0->CHANNEL[3].CCCTRL.R  = eTimer0_CCCTRL_CH3;
    #endif
    
    #ifdef eTimer0_FILT_CH3                 /* FILT register */
        pETIMER_0->CHANNEL[3].FILT.R    = eTimer0_FILT_CH3;
    #endif

    /*-------------------------------------------------------------------------
     * eTimer #0 CHANNEL #4 Control registers
    --------------------------------------------------------------------------*/
    #ifdef eTimer0_COMP1_CH4                /* COMP1 register */
        pETIMER_0->CHANNEL[4].COMP1.R   = eTimer0_COMP1_CH4;
    #endif
    
    #ifdef eTimer0_COMP2_CH4                /* COMP2 register */
        pETIMER_0->CHANNEL[4].COMP2.R   = eTimer0_COMP2_CH4;
    #endif
    
    #ifdef eTimer0_LOAD_CH4                 /* LOAD register */
        pETIMER_0->CHANNEL[4].LOAD.R    = eTimer0_LOAD_CH4;
    #endif
    
    #ifdef eTimer0_CTRL_CH4                 /* CTRL register */
        pETIMER_0->CHANNEL[4].CTRL.R    = eTimer0_CTRL_CH4;
    #endif
    
    #ifdef eTimer0_CTRL2_CH4                /* CTRL2 register */
        pETIMER_0->CHANNEL[4].CTRL2.R   = eTimer0_CTRL2_CH4;
    #endif
    
    #ifdef eTimer0_CTRL3_CH4                /* CTRL3 register */
        pETIMER_0->CHANNEL[4].CTRL3.R   = eTimer0_CTRL3_CH4;
    #endif
    
    #ifdef eTimer0_INTDMA_CH4               /* INTDMA register */
        pETIMER_0->CHANNEL[4].INTDMA.R  = eTimer0_INTDMA_CH4;
    #endif
    
    #ifdef eTimer0_CMPLD1_CH4               /* CMPLD1 register */
        pETIMER_0->CHANNEL[4].CMPLD1.R  = eTimer0_CMPLD1_CH4;
    #endif
    
    #ifdef eTimer0_CMPLD2_CH4               /* CMPLD2 register */
        pETIMER_0->CHANNEL[4].CMPLD2.R  = eTimer0_CMPLD2_CH4;
    #endif
    
    #ifdef eTimer0_CCCTRL_CH4               /* CCCTRL register */
        pETIMER_0->CHANNEL[4].CCCTRL.R  = eTimer0_CCCTRL_CH4;
    #endif
    
    #ifdef eTimer0_FILT_CH4                 /* FILT register */
        pETIMER_0->CHANNEL[4].FILT.R    = eTimer0_FILT_CH4;
    #endif

    /*-------------------------------------------------------------------------
     * eTimer #0 CHANNEL #5 Control registers
    --------------------------------------------------------------------------*/
    #ifdef eTimer0_COMP1_CH5                /* COMP1 register */
        pETIMER_0->CHANNEL[5].COMP1.R   = eTimer0_COMP1_CH5;
    #endif
    
    #ifdef eTimer0_COMP2_CH5                /* COMP2 register */
        pETIMER_0->CHANNEL[5].COMP2.R   = eTimer0_COMP2_CH5;
    #endif
    
    #ifdef eTimer0_LOAD_CH5                 /* LOAD register */
        pETIMER_0->CHANNEL[5].LOAD.R    = eTimer0_LOAD_CH5;
    #endif
    
    #ifdef eTimer0_CTRL_CH5                 /* CTRL register */
        pETIMER_0->CHANNEL[5].CTRL.R    = eTimer0_CTRL_CH5;
    #endif
    
    #ifdef eTimer0_CTRL2_CH5                /* CTRL2 register */
        pETIMER_0->CHANNEL[5].CTRL2.R   = eTimer0_CTRL2_CH5;
    #endif
    
    #ifdef eTimer0_CTRL3_CH5                /* CTRL3 register */
        pETIMER_0->CHANNEL[5].CTRL3.R   = eTimer0_CTRL3_CH5;
    #endif
    
    #ifdef eTimer0_INTDMA_CH5               /* INTDMA register */
        pETIMER_0->CHANNEL[5].INTDMA.R  = eTimer0_INTDMA_CH5;
    #endif
    
    #ifdef eTimer0_CMPLD1_CH5               /* CMPLD1 register */
        pETIMER_0->CHANNEL[5].CMPLD1.R  = eTimer0_CMPLD1_CH5;
    #endif
    
    #ifdef eTimer0_CMPLD2_CH5               /* CMPLD2 register */
        pETIMER_0->CHANNEL[5].CMPLD2.R  = eTimer0_CMPLD2_CH5;
    #endif
    
    #ifdef eTimer0_CCCTRL_CH5               /* CCCTRL register */
        pETIMER_0->CHANNEL[5].CCCTRL.R  = eTimer0_CCCTRL_CH5;
    #endif
    
    #ifdef eTimer0_FILT_CH5                 /* FILT register */
        pETIMER_0->CHANNEL[5].FILT.R    = eTimer0_FILT_CH5;
    #endif
}

/***************************************************************************//*!
@brief          eTimer1 init function

@param[in,out]  void
@param[in]      void

@return         void

@details        This function initializes basic start-up setting of the eTimer1.

@note           

@warning        
******************************************************************************/
void etimer1_init(void)
{
    int i;
    
    // initialization of peripheral base address
    pETIMER_1=(mcTIMER_tag *)&mcTIMER1;

    /*-------------------------------------------------------------------------
     * eTimer0 Reset
    --------------------------------------------------------------------------*/
    for (i=0;i<=5;i++)
    {
        pETIMER_1->CHANNEL[0].CAPT1.R   = 0x0;
        pETIMER_1->CHANNEL[0].CAPT2.R   = 0x0;
        pETIMER_1->CHANNEL[0].CCCTRL.R  = 0x0;
        pETIMER_1->CHANNEL[0].CMPLD1.R  = 0x0;
        pETIMER_1->CHANNEL[0].CMPLD2.R  = 0x0;
        pETIMER_1->CHANNEL[0].CNTR.R    = 0x0;
        pETIMER_1->CHANNEL[0].COMP1.R   = 0x0;
        pETIMER_1->CHANNEL[0].COMP2.R   = 0x0;
        pETIMER_1->CHANNEL[0].CTRL.R    = 0x0;
        pETIMER_1->CHANNEL[0].CTRL2.R   = 0x0;
        pETIMER_1->CHANNEL[0].CTRL3.R   = 0x0;
        pETIMER_1->CHANNEL[0].FILT.R    = 0x0;
        pETIMER_1->CHANNEL[0].HOLD.R    = 0x0;
        pETIMER_1->CHANNEL[0].INTDMA.R  = 0x0;
        pETIMER_1->CHANNEL[0].LOAD.R    = 0x0;
        pETIMER_1->CHANNEL[0].STS.R     = 0x0;
    }

    pETIMER_1->DREQ[0].R    = 0x0;
    pETIMER_1->DREQ[1].R    = 0x0;
    pETIMER_1->ENBL.R       = 0x0;

    /*-------------------------------------------------------------------------
     * eTimer #0 Control registers
    --------------------------------------------------------------------------*/
    #ifdef eTimer1_ENBL                     /* ENBL register */
        pETIMER_1->ENBL.R               = eTimer1_ENBL;
    #endif
    
    #ifdef eTimer1_DREQ0                    /* DREQ[0] register */
        pETIMER_1->DREQ[0].R            = eTimer1_DREQ0;
    #endif
    
    #ifdef eTimer1_DREQ1                    /* DREQ[1] register */
        pETIMER_1->DREQ[1].R            = eTimer1_DREQ1;
    #endif

    /*-------------------------------------------------------------------------
     * eTimer #0 CHANNEL #0 Control registers
    --------------------------------------------------------------------------*/
    #ifdef eTimer1_COMP1_CH0                /* COMP1 register */
        pETIMER_1->CHANNEL[0].COMP1.R   = eTimer1_COMP1_CH0;
    #endif
    
    #ifdef eTimer1_COMP2_CH0                /* COMP2 register */
        pETIMER_1->CHANNEL[0].COMP2.R   = eTimer1_COMP2_CH0;
    #endif
    
    #ifdef eTimer1_LOAD_CH0                 /* LOAD register */
        pETIMER_1->CHANNEL[0].LOAD.R    = eTimer1_LOAD_CH0;
    #endif
    
    #ifdef eTimer1_CTRL_CH0                 /* CTRL register */
        pETIMER_1->CHANNEL[0].CTRL.R    = eTimer1_CTRL_CH0;
    #endif
    
    #ifdef eTimer1_CTRL2_CH0                /* CTRL2 register */
        pETIMER_1->CHANNEL[0].CTRL2.R   = eTimer1_CTRL2_CH0;
    #endif
    
    #ifdef eTimer1_CTRL3_CH0                /* CTRL3 register */
        pETIMER_1->CHANNEL[0].CTRL3.R   = eTimer1_CTRL3_CH0;
    #endif
    
    #ifdef eTimer1_INTDMA_CH0               /* INTDMA register */
        pETIMER_1->CHANNEL[0].INTDMA.R  = eTimer1_INTDMA_CH0;
    #endif
    
    #ifdef eTimer1_CMPLD1_CH0               /* CMPLD1 register */
        pETIMER_1->CHANNEL[0].CMPLD1.R  = eTimer1_CMPLD1_CH0;
    #endif
    
    #ifdef eTimer1_CMPLD2_CH0               /* CMPLD2 register */
        pETIMER_1->CHANNEL[0].CMPLD2.R  = eTimer1_CMPLD2_CH0;
    #endif
    
    #ifdef eTimer1_CCCTRL_CH0               /* CCCTRL register */
        pETIMER_1->CHANNEL[0].CCCTRL.R  = eTimer1_CCCTRL_CH0;
    #endif
    
    #ifdef eTimer1_FILT_CH0                 /* FILT register */
        pETIMER_1->CHANNEL[0].FILT.R    = eTimer1_FILT_CH0;
    #endif

    /*-------------------------------------------------------------------------
     * eTimer #0 CHANNEL #1 Control registers
    --------------------------------------------------------------------------*/
    #ifdef eTimer1_COMP1_CH1                /* COMP1 register */
        pETIMER_1->CHANNEL[1].COMP1.R   = eTimer1_COMP1_CH1;
    #endif
    
    #ifdef eTimer1_COMP2_CH1                /* COMP2 register */
        pETIMER_1->CHANNEL[1].COMP2.R   = eTimer1_COMP2_CH1;
    #endif
    
    #ifdef eTimer1_LOAD_CH1                 /* LOAD register */
        pETIMER_1->CHANNEL[1].LOAD.R    = eTimer1_LOAD_CH1;
    #endif
    
    #ifdef eTimer1_CTRL_CH1                 /* CTRL register */
        pETIMER_1->CHANNEL[1].CTRL.R    = eTimer1_CTRL_CH1;
    #endif
    
    #ifdef eTimer1_CTRL2_CH1                /* CTRL2 register */
        pETIMER_1->CHANNEL[1].CTRL2.R   = eTimer1_CTRL2_CH1;
    #endif
    
    #ifdef eTimer1_CTRL3_CH1                /* CTRL3 register */
        pETIMER_1->CHANNEL[1].CTRL3.R   = eTimer1_CTRL3_CH1;
    #endif
    
    #ifdef eTimer1_INTDMA_CH1               /* INTDMA register */
        pETIMER_1->CHANNEL[1].INTDMA.R  = eTimer1_INTDMA_CH1;
    #endif
    
    #ifdef eTimer1_CMPLD1_CH1               /* CMPLD1 register */
        pETIMER_1->CHANNEL[1].CMPLD1.R  = eTimer1_CMPLD1_CH1;
    #endif
    
    #ifdef eTimer1_CMPLD2_CH1               /* CMPLD2 register */
        pETIMER_1->CHANNEL[1].CMPLD2.R  = eTimer1_CMPLD2_CH1;
    #endif
    
    #ifdef eTimer1_CCCTRL_CH1               /* CCCTRL register */
        pETIMER_1->CHANNEL[1].CCCTRL.R  = eTimer1_CCCTRL_CH1;
    #endif
    
    #ifdef eTimer1_FILT_CH1                 /* FILT register */
        pETIMER_1->CHANNEL[1].FILT.R    = eTimer1_FILT_CH1;
    #endif

    /*-------------------------------------------------------------------------
     * eTimer #0 CHANNEL #2 Control registers
    --------------------------------------------------------------------------*/
    #ifdef eTimer1_COMP1_CH2                /* COMP1 register */
        pETIMER_1->CHANNEL[2].COMP1.R   = eTimer1_COMP1_CH2;
    #endif
    
    #ifdef eTimer1_COMP2_CH2                /* COMP2 register */
        pETIMER_1->CHANNEL[2].COMP2.R   = eTimer1_COMP2_CH2;
    #endif
    
    #ifdef eTimer1_LOAD_CH2                 /* LOAD register */
        pETIMER_1->CHANNEL[2].LOAD.R    = eTimer1_LOAD_CH2;
    #endif
    
    #ifdef eTimer1_CTRL_CH2                 /* CTRL register */
        pETIMER_1->CHANNEL[2].CTRL.R    = eTimer1_CTRL_CH2;
    #endif
    
    #ifdef eTimer1_CTRL2_CH2                /* CTRL2 register */
        pETIMER_1->CHANNEL[2].CTRL2.R   = eTimer1_CTRL2_CH2;
    #endif
    
    #ifdef eTimer1_CTRL3_CH2                /* CTRL3 register */
        pETIMER_1->CHANNEL[2].CTRL3.R   = eTimer1_CTRL3_CH2;
    #endif
    
    #ifdef eTimer1_INTDMA_CH2               /* INTDMA register */
        pETIMER_1->CHANNEL[2].INTDMA.R  = eTimer1_INTDMA_CH2;
    #endif
    
    #ifdef eTimer1_CMPLD1_CH2               /* CMPLD1 register */
        pETIMER_1->CHANNEL[2].CMPLD1.R  = eTimer1_CMPLD1_CH2;
    #endif
    
    #ifdef eTimer1_CMPLD2_CH2               /* CMPLD2 register */
        pETIMER_1->CHANNEL[2].CMPLD2.R  = eTimer1_CMPLD2_CH2;
    #endif
    
    #ifdef eTimer1_CCCTRL_CH2               /* CCCTRL register */
        pETIMER_1->CHANNEL[2].CCCTRL.R  = eTimer1_CCCTRL_CH2;
    #endif
    
    #ifdef eTimer1_FILT_CH2                 /* FILT register */
        pETIMER_1->CHANNEL[2].FILT.R    = eTimer1_FILT_CH2;
    #endif

    /*-------------------------------------------------------------------------
     * eTimer #0 CHANNEL #3 Control registers
    --------------------------------------------------------------------------*/
    #ifdef eTimer1_COMP1_CH3                /* COMP1 register */
        pETIMER_1->CHANNEL[3].COMP1.R   = eTimer1_COMP1_CH3;
    #endif
    
    #ifdef eTimer1_COMP2_CH3                /* COMP2 register */
        pETIMER_1->CHANNEL[3].COMP2.R   = eTimer1_COMP2_CH3;
    #endif
    
    #ifdef eTimer1_LOAD_CH3                 /* LOAD register */
        pETIMER_1->CHANNEL[3].LOAD.R    = eTimer1_LOAD_CH3;
    #endif
    
    #ifdef eTimer1_CTRL_CH3                 /* CTRL register */
        pETIMER_1->CHANNEL[3].CTRL.R    = eTimer1_CTRL_CH3;
    #endif
    
    #ifdef eTimer1_CTRL2_CH3                /* CTRL2 register */
        pETIMER_1->CHANNEL[3].CTRL2.R   = eTimer1_CTRL2_CH3;
    #endif
    
    #ifdef eTimer1_CTRL3_CH3                /* CTRL3 register */
        pETIMER_1->CHANNEL[3].CTRL3.R   = eTimer1_CTRL3_CH3;
    #endif
    
    #ifdef eTimer1_INTDMA_CH3               /* INTDMA register */
        pETIMER_1->CHANNEL[3].INTDMA.R  = eTimer1_INTDMA_CH3;
    #endif
    
    #ifdef eTimer1_CMPLD1_CH3               /* CMPLD1 register */
        pETIMER_1->CHANNEL[3].CMPLD1.R  = eTimer1_CMPLD1_CH3;
    #endif
    
    #ifdef eTimer1_CMPLD2_CH3               /* CMPLD2 register */
        pETIMER_1->CHANNEL[3].CMPLD2.R  = eTimer1_CMPLD2_CH3;
    #endif
    
    #ifdef eTimer1_CCCTRL_CH3               /* CCCTRL register */
        pETIMER_1->CHANNEL[3].CCCTRL.R  = eTimer1_CCCTRL_CH3;
    #endif
    
    #ifdef eTimer1_FILT_CH3                 /* FILT register */
        pETIMER_1->CHANNEL[3].FILT.R    = eTimer1_FILT_CH3;
    #endif

    /*-------------------------------------------------------------------------
     * eTimer #0 CHANNEL #4 Control registers
    --------------------------------------------------------------------------*/
    #ifdef eTimer1_COMP1_CH4                /* COMP1 register */
        pETIMER_1->CHANNEL[4].COMP1.R   = eTimer1_COMP1_CH4;
    #endif
    
    #ifdef eTimer1_COMP2_CH4                /* COMP2 register */
        pETIMER_1->CHANNEL[4].COMP2.R   = eTimer1_COMP2_CH4;
    #endif
    
    #ifdef eTimer1_LOAD_CH4                 /* LOAD register */
        pETIMER_1->CHANNEL[4].LOAD.R    = eTimer1_LOAD_CH4;
    #endif
    
    #ifdef eTimer1_CTRL_CH4                 /* CTRL register */
        pETIMER_1->CHANNEL[4].CTRL.R    = eTimer1_CTRL_CH4;
    #endif
    
    #ifdef eTimer1_CTRL2_CH4                /* CTRL2 register */
        pETIMER_1->CHANNEL[4].CTRL2.R   = eTimer1_CTRL2_CH4;
    #endif
    
    #ifdef eTimer1_CTRL3_CH4                /* CTRL3 register */
        pETIMER_1->CHANNEL[4].CTRL3.R   = eTimer1_CTRL3_CH4;
    #endif
    
    #ifdef eTimer1_INTDMA_CH4               /* INTDMA register */
        pETIMER_1->CHANNEL[4].INTDMA.R  = eTimer1_INTDMA_CH4;
    #endif
    
    #ifdef eTimer1_CMPLD1_CH4               /* CMPLD1 register */
        pETIMER_1->CHANNEL[4].CMPLD1.R  = eTimer1_CMPLD1_CH4;
    #endif
    
    #ifdef eTimer1_CMPLD2_CH4               /* CMPLD2 register */
        pETIMER_1->CHANNEL[4].CMPLD2.R  = eTimer1_CMPLD2_CH4;
    #endif
    
    #ifdef eTimer1_CCCTRL_CH4               /* CCCTRL register */
        pETIMER_1->CHANNEL[4].CCCTRL.R  = eTimer1_CCCTRL_CH4;
    #endif
    
    #ifdef eTimer1_FILT_CH4                 /* FILT register */
        pETIMER_1->CHANNEL[4].FILT.R    = eTimer1_FILT_CH4;
    #endif

    /*-------------------------------------------------------------------------
     * eTimer #0 CHANNEL #5 Control registers
    --------------------------------------------------------------------------*/
    #ifdef eTimer1_COMP1_CH5                /* COMP1 register */
        pETIMER_1->CHANNEL[5].COMP1.R   = eTimer1_COMP1_CH5;
    #endif
    
    #ifdef eTimer1_COMP2_CH5                /* COMP2 register */
        pETIMER_1->CHANNEL[5].COMP2.R   = eTimer1_COMP2_CH5;
    #endif
    
    #ifdef eTimer1_LOAD_CH5                 /* LOAD register */
        pETIMER_1->CHANNEL[5].LOAD.R    = eTimer1_LOAD_CH5;
    #endif
    
    #ifdef eTimer1_CTRL_CH5                 /* CTRL register */
        pETIMER_1->CHANNEL[5].CTRL.R    = eTimer1_CTRL_CH5;
    #endif
    
    #ifdef eTimer1_CTRL2_CH5                /* CTRL2 register */
        pETIMER_1->CHANNEL[5].CTRL2.R   = eTimer1_CTRL2_CH5;
    #endif
    
    #ifdef eTimer1_CTRL3_CH5                /* CTRL3 register */
        pETIMER_1->CHANNEL[5].CTRL3.R   = eTimer1_CTRL3_CH5;
    #endif
    
    #ifdef eTimer1_INTDMA_CH5               /* INTDMA register */
        pETIMER_1->CHANNEL[5].INTDMA.R  = eTimer1_INTDMA_CH5;
    #endif
    
    #ifdef eTimer1_CMPLD1_CH5               /* CMPLD1 register */
        pETIMER_1->CHANNEL[5].CMPLD1.R  = eTimer1_CMPLD1_CH5;
    #endif
    
    #ifdef eTimer1_CMPLD2_CH5               /* CMPLD2 register */
        pETIMER_1->CHANNEL[5].CMPLD2.R  = eTimer1_CMPLD2_CH5;
    #endif
    
    #ifdef eTimer1_CCCTRL_CH5               /* CCCTRL register */
        pETIMER_1->CHANNEL[5].CCCTRL.R  = eTimer1_CCCTRL_CH5;
    #endif
    
    #ifdef eTimer1_FILT_CH5                 /* FILT register */
        pETIMER_1->CHANNEL[5].FILT.R    = eTimer1_FILT_CH5;
    #endif
}
