/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!
*
* @file     pit.c
*
* @author   b15651
* 
* @version  1.0.1.0
* 
* @date     Jul-13-2012
* 
* @brief    PIT - Periodic Interupt Timer for MPC5604P
*
*******************************************************************************
*
* This file includes initial setting function of MPC5604P PIT peripheral module.
*
******************************************************************************/
#include "MPC5643L_qs.h"
#include "pit.h"

/******************************************************************************
* PIT timer functions
*****************************************************************************/
volatile PIT_RTI_tag *pPIT;
/***************************************************************************//*!
@brief          Periodic Interupt Timer init function

@param[in,out]  void
@param[in]      void

@return         void

@details        This function initializes basic start-up setting of the PIT
                timers.

@note           

@warning        
******************************************************************************/
void pit_init(void)
{
    // initialization of peripheral base address
    pPIT                            = (PIT_RTI_tag *)&PIT_RTI;

    // clock for PIT disabled
    pPIT->PITMCR.B.MDIS = 1;

    /*-------------------------------------------------------------------------
     * PIT channel 0 registers
    --------------------------------------------------------------------------*/
    #ifdef PIT_CH0_LDVAL                  /* LDVAL register */
        pPIT->LDVAL0.R              = PIT_CH0_LDVAL;
    #endif

    #ifdef PIT_CH0_TCTRL                  /* TCTRL register */
        pPIT->TCTRL0.R              = PIT_CH0_TCTRL;
    #endif

    /*-------------------------------------------------------------------------
     * PIT channel 1 registers
    --------------------------------------------------------------------------*/
    #ifdef PIT_CH1_LDVAL                  /* LDVAL register */
        pPIT->LDVAL1.R              = PIT_CH1_LDVAL;
    #endif

    #ifdef PIT_CH1_TCTRL                  /* TCTRL register */
        pPIT->TCTRL1.R              = PIT_CH1_TCTRL;
    #endif

    /*-------------------------------------------------------------------------
     * PIT channel 2 registers
    --------------------------------------------------------------------------*/
    #ifdef PIT_CH2_LDVAL                  /* LDVAL register */
        pPIT->LDVAL2.R              = PIT_CH2_LDVAL;
    #endif

    #ifdef PIT_CH2_TCTRL                  /* TCTRL register */
        pPIT->TCTRL2.R              = PIT_CH2_TCTRL;
    #endif

    /*-------------------------------------------------------------------------
     * PIT channel 3 registers
    --------------------------------------------------------------------------*/
    #ifdef PIT_CH3_LDVAL                  /* LDVAL register */
        pPIT->LDVAL3.R              = PIT_CH3_LDVAL;
    #endif

    #ifdef PIT_CH3_TCTRL                  /* TCTRL register */
        pPIT->TCTRL3.R              = PIT_CH3_TCTRL;
    #endif

    /*-------------------------------------------------------------------------
     * PIT Control registers
    --------------------------------------------------------------------------*/
    #ifdef PIT_PITMCR                  /* MCR register */
        pPIT->PITMCR.R              = PIT_PITMCR;
    #endif
}
