/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!
*
* @file     siul.c
*
* @author   r63172, b15651
* 
* @version  1.0.1.0
* 
* @date     Jul-13-2012
* 
* @brief    SIUL - System Integration Unit for MPC5643L
*
*******************************************************************************
*
* This file includes initial setting function of MPC5643L SIU peripheral module.
* The port settings are valid for TQFP100, TQFP144, MAPBGA257 package.
*
******************************************************************************/
#include "MPC5643L_qs.h"
#include "siul.h"

volatile SIUL_tag *pSIUL;
/******************************************************************************
* SIUL init function
*****************************************************************************/
void siul_init(void)
{
    static tU8  i;
    
    // initialization of peripheral base address
    pSIUL = (SIUL_tag *)&SIUL;

    /*-------------------------------------------------------------------------
     * SIU reset
    --------------------------------------------------------------------------*/
    for (i=0;i<=131;i++)
        pSIUL->PCR[i].R = 0x0;

    for (i=0;i<=42;i++)
        pSIUL->PSMI[i].R = 0x0;

    for (i=0;i<=31;i++)
        pSIUL->IFMC[i].R = 0x0;

    pSIUL->IFCPR.R   = 0x0;
    pSIUL->IFEER.R   = 0x0;
    pSIUL->IFER.R    = 0x0;
    pSIUL->IREER.R   = 0x0;
    pSIUL->IRER.R    = 0x0;
    pSIUL->ISR.R     = 0xFFFFFFFF;   /* clear Interrupt status register */

    for (i=0;i<=131;i++)
    {
        pSIUL->GPDI[i].R    = 0x0;
        pSIUL->GPDO[i].R    = 0x0;
    }

//    pSIUL->MIDR.R    = 0x0;
//    pSIUL->MIDR2.R   = 0x0;
    
    for (i=0;i<=6;i++)
        pSIUL->MPGPDO[i].R  = 0x0;

    for (i=0;i<=15;i++)
    {
        pSIUL->PGPDI[i].R   = 0x0;
        pSIUL->PGPDO[i].R   = 0x0;
    }
    /*-------------------------------------------------------------------------
     * SIU PCR registers
    --------------------------------------------------------------------------*/
    #ifdef SIUL_PCR0              /* SIU 0 */
       pSIUL->PCR[0].R = SIUL_PCR0;
    #endif
    #ifdef SIUL_PCR1              /* SIU 1 */
       pSIUL->PCR[1].R = SIUL_PCR1;
    #endif
    #ifdef SIUL_PCR2              /* SIU 2 */
       pSIUL->PCR[2].R = SIUL_PCR2;
    #endif
    #ifdef SIUL_PCR3              /* SIU 3 */
       pSIUL->PCR[3].R = SIUL_PCR3;
    #endif
    #ifdef SIUL_PCR4              /* SIU 4 */
       pSIUL->PCR[4].R = SIUL_PCR4;
    #endif
    #ifdef SIUL_PCR5              /* SIU 5 */
       pSIUL->PCR[5].R = SIUL_PCR5;
    #endif
    #ifdef SIUL_PCR6              /* SIU 6 */
       pSIUL->PCR[6].R = SIUL_PCR6;
    #endif
    #ifdef SIUL_PCR7              /* SIU 7 */
       pSIUL->PCR[7].R = SIUL_PCR7;
    #endif
    #ifdef SIUL_PCR8              /* SIU 8 */
       pSIUL->PCR[8].R = SIUL_PCR8;
    #endif
    #ifdef SIUL_PCR9              /* SIU 9 */
       pSIUL->PCR[9].R = SIUL_PCR9;
    #endif
    #ifdef SIUL_PCR10             /* SIU 10 */
       pSIUL->PCR[10].R = SIUL_PCR10;
    #endif
    #ifdef SIUL_PCR11             /* SIU 11 */
       pSIUL->PCR[11].R = SIUL_PCR11;
    #endif
    #ifdef SIUL_PCR12             /* SIU 12 */
       pSIUL->PCR[12].R = SIUL_PCR12;
    #endif
    #ifdef SIUL_PCR13             /* SIU 13 */
       pSIUL->PCR[13].R = SIUL_PCR13;
    #endif
    #ifdef SIUL_PCR14             /* SIU 14 */
       pSIUL->PCR[14].R = SIUL_PCR14;
    #endif
    #ifdef SIUL_PCR15             /* SIU 15 */
       pSIUL->PCR[15].R = SIUL_PCR15;
    #endif
    #ifdef SIUL_PCR16             /* SIU 16 */
       pSIUL->PCR[16].R = SIUL_PCR16;
    #endif
    #ifdef SIUL_PCR17             /* SIU 17 */
       pSIUL->PCR[17].R = SIUL_PCR17;
    #endif
    #ifdef SIUL_PCR18             /* SIU 18 */
       pSIUL->PCR[18].R = SIUL_PCR18;
    #endif
    #ifdef SIUL_PCR19             /* SIU 19 */
       pSIUL->PCR[19].R = SIUL_PCR19;
    #endif
    #ifdef SIUL_PCR20             /* SIU 20 */
       pSIUL->PCR[20].R = SIUL_PCR20;
    #endif
    #ifdef SIUL_PCR21             /* SIU 21 */
       pSIUL->PCR[21].R = SIUL_PCR21;
    #endif
    #ifdef SIUL_PCR22             /* SIU 22 */
       pSIUL->PCR[22].R = SIUL_PCR22;
    #endif
    #ifdef SIUL_PCR23             /* SIU 23 */
       pSIUL->PCR[23].R = SIUL_PCR23;
    #endif
    #ifdef SIUL_PCR24             /* SIU 24 */
       pSIUL->PCR[24].R = SIUL_PCR24;
    #endif
    #ifdef SIUL_PCR25             /* SIU 25 */
       pSIUL->PCR[25].R = SIUL_PCR25;
    #endif
    #ifdef SIUL_PCR26             /* SIU 26 */
       pSIUL->PCR[26].R = SIUL_PCR26;
    #endif
    #ifdef SIUL_PCR27             /* SIU 27 */
       pSIUL->PCR[27].R = SIUL_PCR27;
    #endif
    #ifdef SIUL_PCR28             /* SIU 28 */
       pSIUL->PCR[28].R = SIUL_PCR28;
    #endif
    #ifdef SIUL_PCR29             /* SIU 29 */
       pSIUL->PCR[29].R = SIUL_PCR29;
    #endif
    #ifdef SIUL_PCR30             /* SIU 30 */
       pSIUL->PCR[30].R = SIUL_PCR30;
    #endif
    #ifdef SIUL_PCR31             /* SIU 31 */
       pSIUL->PCR[31].R = SIUL_PCR31;
    #endif
    #ifdef SIUL_PCR32             /* SIU 32 */
       pSIUL->PCR[32].R = SIUL_PCR32;
    #endif
    #ifdef SIUL_PCR33             /* SIU 33 */
       pSIUL->PCR[33].R = SIUL_PCR33;
    #endif
    #ifdef SIUL_PCR34             /* SIU 34 */
       pSIUL->PCR[34].R = SIUL_PCR34;
    #endif
    #ifdef SIUL_PCR35             /* SIU 35 */
       pSIUL->PCR[35].R = SIUL_PCR35;
    #endif
    #ifdef SIUL_PCR36             /* SIU 36 */
       pSIUL->PCR[36].R = SIUL_PCR36;
    #endif
    #ifdef SIUL_PCR37             /* SIU 37 */
       pSIUL->PCR[37].R = SIUL_PCR37;
    #endif
    #ifdef SIUL_PCR38             /* SIU 38 */
       pSIUL->PCR[38].R = SIUL_PCR38;
    #endif
    #ifdef SIUL_PCR39             /* SIU 39 */
       pSIUL->PCR[39].R = SIUL_PCR39;
    #endif
    #ifdef SIUL_PCR40             /* SIU 40 */
       pSIUL->PCR[40].R = SIUL_PCR40;
    #endif
    #ifdef SIUL_PCR41             /* SIU 41 */
       pSIUL->PCR[41].R = SIUL_PCR41;
    #endif
    #ifdef SIUL_PCR42             /* SIU 42 */
       pSIUL->PCR[42].R = SIUL_PCR42;
    #endif
    #ifdef SIUL_PCR43             /* SIU 43 */
       pSIUL->PCR[43].R = SIUL_PCR43;
    #endif
    #ifdef SIUL_PCR44             /* SIU 44 */
       pSIUL->PCR[44].R = SIUL_PCR44;
    #endif
    #ifdef SIUL_PCR45             /* SIU 45 */
       pSIUL->PCR[45].R = SIUL_PCR45;
    #endif
    #ifdef SIUL_PCR46             /* SIU 46 */
       pSIUL->PCR[46].R = SIUL_PCR46;
    #endif
    #ifdef SIUL_PCR47             /* SIU 47 */
       pSIUL->PCR[47].R = SIUL_PCR47;
    #endif
    #ifdef SIUL_PCR48             /* SIU 48 */
       pSIUL->PCR[48].R = SIUL_PCR48;
    #endif
    #ifdef SIUL_PCR49             /* SIU 49 */
       pSIUL->PCR[49].R = SIUL_PCR49;
    #endif
    #ifdef SIUL_PCR50             /* SIU 50 */
       pSIUL->PCR[50].R = SIUL_PCR50;
    #endif
    #ifdef SIUL_PCR51             /* SIU 51 */
       pSIUL->PCR[51].R = SIUL_PCR51;
    #endif
    #ifdef SIUL_PCR52             /* SIU 52 */
       pSIUL->PCR[52].R = SIUL_PCR52;
    #endif
    #ifdef SIUL_PCR53             /* SIU 53 */
       pSIUL->PCR[53].R = SIUL_PCR53;
    #endif
    #ifdef SIUL_PCR54             /* SIU 54 */
       pSIUL->PCR[54].R = SIUL_PCR54;
    #endif
    #ifdef SIUL_PCR55             /* SIU 55 */
       pSIUL->PCR[55].R = SIUL_PCR55;
    #endif
    #ifdef SIUL_PCR56             /* SIU 56 */
       pSIUL->PCR[56].R = SIUL_PCR56;
    #endif
    #ifdef SIUL_PCR57             /* SIU 57 */
       pSIUL->PCR[57].R = SIUL_PCR57;
    #endif
    #ifdef SIUL_PCR58             /* SIU 58 */
       pSIUL->PCR[58].R = SIUL_PCR58;
    #endif
    #ifdef SIUL_PCR59             /* SIU 59 */
       pSIUL->PCR[59].R = SIUL_PCR59;
    #endif
    #ifdef SIUL_PCR60             /* SIU 60 */
       pSIUL->PCR[60].R = SIUL_PCR60;
    #endif
    #ifdef SIUL_PCR61             /* SIU 61 */
       pSIUL->PCR[61].R = SIUL_PCR61;
    #endif
    #ifdef SIUL_PCR62             /* SIU 62 */
       pSIUL->PCR[62].R = SIUL_PCR62;
    #endif
    #ifdef SIUL_PCR63             /* SIU 63 */
       pSIUL->PCR[63].R = SIUL_PCR63;
    #endif
    #ifdef SIUL_PCR64             /* SIU 64 */
       pSIUL->PCR[64].R = SIUL_PCR64;
    #endif
    #ifdef SIUL_PCR65             /* SIU 65 */
       pSIUL->PCR[65].R = SIUL_PCR65;
    #endif
    #ifdef SIUL_PCR66             /* SIU 66 */
       pSIUL->PCR[66].R = SIUL_PCR66;
    #endif
    #ifdef SIUL_PCR67             /* SIU 67 */
       pSIUL->PCR[67].R = SIUL_PCR67;
    #endif
    #ifdef SIUL_PCR68             /* SIU 68 */
       pSIUL->PCR[68].R = SIUL_PCR68;
    #endif
    #ifdef SIUL_PCR69             /* SIU 69 */
       pSIUL->PCR[69].R = SIUL_PCR69;
    #endif
    #ifdef SIUL_PCR70             /* SIU 70 */
       pSIUL->PCR[70].R = SIUL_PCR70;
    #endif
    #ifdef SIUL_PCR71             /* SIU 71 */
       pSIUL->PCR[71].R = SIUL_PCR71;
    #endif
    #ifdef SIUL_PCR72             /* SIU 72 */
       pSIUL->PCR[72].R = SIUL_PCR72;
    #endif
    #ifdef SIUL_PCR73             /* SIU 73 */
       pSIUL->PCR[73].R = SIUL_PCR73;
    #endif
    #ifdef SIUL_PCR74             /* SIU 74 */
       pSIUL->PCR[74].R = SIUL_PCR74;
    #endif
    #ifdef SIUL_PCR75             /* SIU 75 */
       pSIUL->PCR[75].R = SIUL_PCR75;
    #endif
    #ifdef SIUL_PCR76             /* SIU 76 */
       pSIUL->PCR[76].R = SIUL_PCR76;
    #endif
    #ifdef SIUL_PCR77             /* SIU 77 */
       pSIUL->PCR[77].R = SIUL_PCR77;
    #endif
    #ifdef SIUL_PCR78             /* SIU 78 */
       pSIUL->PCR[78].R = SIUL_PCR78;
    #endif
    #ifdef SIUL_PCR79             /* SIU 79 */
       pSIUL->PCR[79].R = SIUL_PCR79;
    #endif
    #ifdef SIUL_PCR80             /* SIU 80 */
       pSIUL->PCR[80].R = SIUL_PCR80;
    #endif
    #ifdef SIUL_PCR81             /* SIU 81 */
       pSIUL->PCR[81].R = SIUL_PCR81;
    #endif
    #ifdef SIUL_PCR82             /* SIU 82 */
       pSIUL->PCR[82].R = SIUL_PCR82;
    #endif
    #ifdef SIUL_PCR83             /* SIU 83 */
       pSIUL->PCR[83].R = SIUL_PCR83;
    #endif
    #ifdef SIUL_PCR84             /* SIU 84 */
       pSIUL->PCR[84].R = SIUL_PCR84;
    #endif
    #ifdef SIUL_PCR85             /* SIU 85 */
       pSIUL->PCR[85].R = SIUL_PCR85;
    #endif
    #ifdef SIUL_PCR86             /* SIU 86 */
       pSIUL->PCR[86].R = SIUL_PCR86;
    #endif
    #ifdef SIUL_PCR87             /* SIU 87 */
       pSIUL->PCR[87].R = SIUL_PCR87;
    #endif
    #ifdef SIUL_PCR88             /* SIU 88 */
       pSIUL->PCR[88].R = SIUL_PCR88;
    #endif
    #ifdef SIUL_PCR89             /* SIU 89 */
       pSIUL->PCR[89].R = SIUL_PCR89;
    #endif
    #ifdef SIUL_PCR90             /* SIU 90 */
       pSIUL->PCR[90].R = SIUL_PCR90;
    #endif
    #ifdef SIUL_PCR91             /* SIU 91 */
       pSIUL->PCR[91].R = SIUL_PCR91;
    #endif
    #ifdef SIUL_PCR92             /* SIU 92 */
       pSIUL->PCR[92].R = SIUL_PCR92;
    #endif
    #ifdef SIUL_PCR93             /* SIU 93 */
       pSIUL->PCR[93].R = SIUL_PCR93;
    #endif
    #ifdef SIUL_PCR94             /* SIU 94 */
       pSIUL->PCR[94].R = SIUL_PCR94;
    #endif
    #ifdef SIUL_PCR95             /* SIU 95 */
       pSIUL->PCR[95].R = SIUL_PCR95;
    #endif
    #ifdef SIUL_PCR96             /* SIU 96 */
       pSIUL->PCR[96].R = SIUL_PCR96;
    #endif
    #ifdef SIUL_PCR97             /* SIU 97 */
       pSIUL->PCR[97].R = SIUL_PCR97;
    #endif
    #ifdef SIUL_PCR98             /* SIU 98 */
       pSIUL->PCR[98].R = SIUL_PCR98;
    #endif
    #ifdef SIUL_PCR99             /* SIU 99 */
       pSIUL->PCR[99].R = SIUL_PCR99;
    #endif
    #ifdef SIUL_PCR100            /* SIU 100 */
       pSIUL->PCR[100].R = SIUL_PCR100;
    #endif
    #ifdef SIUL_PCR101            /* SIU 101 */
       pSIUL->PCR[101].R = SIUL_PCR101;
    #endif
    #ifdef SIUL_PCR102            /* SIU 102 */
       pSIUL->PCR[102].R = SIUL_PCR102;
    #endif
    #ifdef SIUL_PCR103            /* SIU 103 */
       pSIUL->PCR[103].R = SIUL_PCR103;
    #endif
    #ifdef SIUL_PCR104            /* SIU 104 */
       pSIUL->PCR[104].R = SIUL_PCR104;
    #endif
    #ifdef SIUL_PCR105            /* SIU 105 */
       pSIUL->PCR[105].R = SIUL_PCR105;
    #endif
    #ifdef SIUL_PCR106            /* SIU 106 */
       pSIUL->PCR[106].R = SIUL_PCR106;
    #endif
    #ifdef SIUL_PCR107            /* SIU 107 */
       pSIUL->PCR[107].R = SIUL_PCR107;
    #endif
    #ifdef SIUL_PCR108            /* SIU 108 */
       pSIUL->PCR[108].R = SIUL_PCR108;
    #endif
    #ifdef SIUL_PCR109            /* SIU 109 */
       pSIUL->PCR[109].R = SIUL_PCR109;
    #endif
    #ifdef SIUL_PCR110            /* SIU 110 */
       pSIUL->PCR[110].R = SIUL_PCR110;
    #endif
    #ifdef SIUL_PCR111            /* SIU 111 */
       pSIUL->PCR[111].R = SIUL_PCR111;
    #endif
    #ifdef SIUL_PCR112            /* SIU 112 */
       pSIUL->PCR[112].R = SIUL_PCR112;
    #endif
    #ifdef SIUL_PCR113            /* SIU 103 */
       pSIUL->PCR[113].R = SIUL_PCR113;
    #endif
    #ifdef SIUL_PCR114            /* SIU 114 */
       pSIUL->PCR[114].R = SIUL_PCR114;
    #endif
    #ifdef SIUL_PCR115            /* SIU 115 */
       pSIUL->PCR[115].R = SIUL_PCR115;
    #endif
    #ifdef SIUL_PCR116            /* SIU 116 */
       pSIUL->PCR[116].R = SIUL_PCR116;
    #endif
    #ifdef SIUL_PCR117            /* SIU 117 */
       pSIUL->PCR[117].R = SIUL_PCR117;
    #endif
    #ifdef SIUL_PCR118            /* SIU 118 */
       pSIUL->PCR[118].R = SIUL_PCR118;
    #endif
    #ifdef SIUL_PCR119            /* SIU 119 */
       pSIUL->PCR[119].R = SIUL_PCR119;
    #endif
    #ifdef SIUL_PCR120            /* SIU 120 */
       pSIUL->PCR[120].R = SIUL_PCR120;
    #endif
    #ifdef SIUL_PCR121            /* SIU 121 */
       pSIUL->PCR[121].R = SIUL_PCR121;
    #endif
    #ifdef SIUL_PCR122            /* SIU 122 */
       pSIUL->PCR[122].R = SIUL_PCR122;
    #endif
    #ifdef SIUL_PCR123            /* SIU 123 */
       pSIUL->PCR[123].R = SIUL_PCR123;
    #endif
    #ifdef SIUL_PCR124            /* SIU 124 */
       pSIUL->PCR[124].R = SIUL_PCR124;
    #endif
    #ifdef SIUL_PCR125            /* SIU 125 */
       pSIUL->PCR[125].R = SIUL_PCR125;
    #endif
    #ifdef SIUL_PCR126            /* SIU 126 */
       pSIUL->PCR[126].R = SIUL_PCR126;
    #endif
    #ifdef SIUL_PCR127            /* SIU 127 */
       pSIUL->PCR[127].R = SIUL_PCR127;
    #endif
    #ifdef SIUL_PCR128            /* SIU 128 */
       pSIUL->PCR[128].R = SIUL_PCR128;
    #endif
    #ifdef SIUL_PCR129            /* SIU 129 */
       pSIUL->PCR[129].R = SIUL_PCR129;
    #endif
    #ifdef SIUL_PCR130            /* SIU 130 */
       pSIUL->PCR[130].R = SIUL_PCR130;
    #endif
    #ifdef SIUL_PCR131            /* SIU 131 */
       pSIUL->PCR[131].R = SIUL_PCR131;
    #endif

    /*-------------------------------------------------------------------------
     * SIU PSMI registers
    --------------------------------------------------------------------------*/
    #ifdef SIUL_PSMI0            /* PSMI 0 */
       pSIUL->PSMI[0].R = SIUL_PSMI0;
    #endif
    #ifdef SIUL_PSMI1            /* PSMI 1 */
       pSIUL->PSMI[1].R = SIUL_PSMI1;
    #endif
    #ifdef SIUL_PSMI2            /* PSMI 2 */
       pSIUL->PSMI[2].R = SIUL_PSMI2;
    #endif
    #ifdef SIUL_PSMI3            /* PSMI 3 */
       pSIUL->PSMI[3].R = SIUL_PSMI3;
    #endif
    #ifdef SIUL_PSMI4            /* PSMI 4 */
       pSIUL->PSMI[4].R = SIUL_PSMI4;
    #endif
    #ifdef SIUL_PSMI5            /* PSMI 5 */
       pSIUL->PSMI[5].R = SIUL_PSMI5;
    #endif
    #ifdef SIUL_PSMI6            /* PSMI 6 */
       pSIUL->PSMI[6].R = SIUL_PSMI6;
    #endif
    #ifdef SIUL_PSMI7            /* PSMI 7 */
       pSIUL->PSMI[7].R = SIUL_PSMI7;
    #endif
    #ifdef SIUL_PSMI8            /* PSMI 8 */
       pSIUL->PSMI[8].R = SIUL_PSMI8;
    #endif
    #ifdef SIUL_PSMI9            /* PSMI 9 */
       pSIUL->PSMI[9].R = SIUL_PSMI9;
    #endif
    #ifdef SIUL_PSMI10           /* PSMI 10 */
       pSIUL->PSMI[10].R = SIUL_PSMI10;
    #endif
    #ifdef SIUL_PSMI11           /* PSMI 11 */
       pSIUL->PSMI[11].R = SIUL_PSMI11;
    #endif
    #ifdef SIUL_PSMI12           /* PSMI 12 */
       pSIUL->PSMI[12].R = SIUL_PSMI12;
    #endif
    #ifdef SIUL_PSMI13           /* PSMI 13 */
       pSIUL->PSMI[13].R = SIUL_PSMI13;
    #endif
    #ifdef SIUL_PSMI14           /* PSMI 14 */
       pSIUL->PSMI[14].R = SIUL_PSMI14;
    #endif
    #ifdef SIUL_PSMI15           /* PSMI 15 */
       pSIUL->PSMI[15].R = SIUL_PSMI15;
    #endif
    #ifdef SIUL_PSMI16           /* PSMI 16 */
       pSIUL->PSMI[16].R = SIUL_PSMI16;
    #endif
    #ifdef SIUL_PSMI17           /* PSMI 17 */
       pSIUL->PSMI[17].R = SIUL_PSMI17;
    #endif
    #ifdef SIUL_PSMI18           /* PSMI 18 */
       pSIUL->PSMI[18].R = SIUL_PSMI18;
    #endif
    #ifdef SIUL_PSMI19           /* PSMI 19 */
       pSIUL->PSMI[19].R = SIUL_PSMI19;
    #endif
    #ifdef SIUL_PSMI20           /* PSMI 20 */
       pSIUL->PSMI[20].R = SIUL_PSMI20;
    #endif
    #ifdef SIUL_PSMI21           /* PSMI 21 */
       pSIUL->PSMI[21].R = SIUL_PSMI21;
    #endif
    #ifdef SIUL_PSMI22           /* PSMI 22 */
       pSIUL->PSMI[22].R = SIUL_PSMI22;
    #endif
    #ifdef SIUL_PSMI23           /* PSMI 23 */
       pSIUL->PSMI[23].R = SIUL_PSMI23;
    #endif
    #ifdef SIUL_PSMI24           /* PSMI 24 */
       pSIUL->PSMI[24].R = SIUL_PSMI24;
    #endif
    #ifdef SIUL_PSMI25           /* PSMI 25 */
       pSIUL->PSMI[25].R = SIUL_PSMI25;
    #endif
    #ifdef SIUL_PSMI26           /* PSMI 26 */
       pSIUL->PSMI[26].R = SIUL_PSMI26;
    #endif
    #ifdef SIUL_PSMI27           /* PSMI 27 */
       pSIUL->PSMI[27].R = SIUL_PSMI27;
    #endif
    #ifdef SIUL_PSMI28           /* PSMI 28 */
       pSIUL->PSMI[28].R = SIUL_PSMI28;
    #endif
    #ifdef SIUL_PSMI29           /* PSMI 29 */
       pSIUL->PSMI[29].R = SIUL_PSMI29;
    #endif
    #ifdef SIUL_PSMI30           /* PSMI 30 */
       pSIUL->PSMI[30].R = SIUL_PSMI30;
    #endif
    #ifdef SIUL_PSMI31           /* PSMI 31 */
       pSIUL->PSMI[31].R = SIUL_PSMI31;
    #endif
    #ifdef SIUL_PSMI32           /* PSMI 32 */
       pSIUL->PSMI[32].R = SIUL_PSMI32;
    #endif
    #ifdef SIUL_PSMI33           /* PSMI 33 */
       pSIUL->PSMI[33].R = SIUL_PSMI32;
    #endif
    #ifdef SIUL_PSMI34           /* PSMI 34 */
       pSIUL->PSMI[34].R = SIUL_PSMI32;
    #endif
    #ifdef SIUL_PSMI35           /* PSMI 35 */
       pSIUL->PSMI[35].R = SIUL_PSMI32;
    #endif
    #ifdef SIUL_PSMI36           /* PSMI 36 */
       pSIUL->PSMI[36].R = SIUL_PSMI32;
    #endif
    #ifdef SIUL_PSMI37           /* PSMI 37 */
       pSIUL->PSMI[37].R = SIUL_PSMI32;
    #endif
    #ifdef SIUL_PSMI38           /* PSMI 38 */
       pSIUL->PSMI[38].R = SIUL_PSMI32;
    #endif
    #ifdef SIUL_PSMI39           /* PSMI 39 */
       pSIUL->PSMI[39].R = SIUL_PSMI32;
    #endif
    #ifdef SIUL_PSMI40           /* PSMI 40 */
       pSIUL->PSMI[40].R = SIUL_PSMI32;
    #endif
    #ifdef SIUL_PSMI41           /* PSMI 41 */
       pSIUL->PSMI[41].R = SIUL_PSMI32;
    #endif
    #ifdef SIUL_PSMI42           /* PSMI 42 */
       pSIUL->PSMI[42].R = SIUL_PSMI32;
    #endif

   /*-------------------------------------------------------------------------
    * SIU IFMC register
   --------------------------------------------------------------------------*/
    #ifdef SIUL_IFMC0            /* IFMC 0 */
       pSIUL->IFMC[0].R = SIUL_IFMC0;
    #endif
    #ifdef SIUL_IFMC1            /* IFMC 1 */
       pSIUL->IFMC[1].R = SIUL_IFMC1;
    #endif
    #ifdef SIUL_IFMC2            /* IFMC 2 */
       pSIUL->IFMC[2].R = SIUL_IFMC2;
    #endif
    #ifdef SIUL_IFMC3            /* IFMC 3 */
       pSIUL->IFMC[3].R = SIUL_IFMC3;
    #endif
    #ifdef SIUL_IFMC4            /* IFMC 4 */
       pSIUL->IFMC[4].R = SIUL_IFMC4;
    #endif
    #ifdef SIUL_IFMC5            /* IFMC 5 */
       pSIUL->IFMC[5].R = SIUL_IFMC5;
    #endif
    #ifdef SIUL_IFMC6            /* IFMC 6 */
       pSIUL->IFMC[6].R = SIUL_IFMC6;
    #endif
    #ifdef SIUL_IFMC7            /* IFMC 7 */
       pSIUL->IFMC[7].R = SIUL_IFMC7;
    #endif
    #ifdef SIUL_IFMC8            /* IFMC 8 */
       pSIUL->IFMC[8].R = SIUL_IFMC8;
    #endif
    #ifdef SIUL_IFMC9            /* IFMC 9 */
       pSIUL->IFMC[9].R = SIUL_IFMC9;
    #endif
    #ifdef SIUL_IFMC10           /* IFMC 10 */
       pSIUL->IFMC[10].R = SIUL_IFMC10;
    #endif
    #ifdef SIUL_IFMC11           /* IFMC 11 */
       pSIUL->IFMC[11].R = SIUL_IFMC11;
    #endif
    #ifdef SIUL_IFMC12           /* IFMC 12 */
       pSIUL->IFMC[12].R = SIUL_IFMC12;
    #endif
    #ifdef SIUL_IFMC13           /* IFMC 13 */
       pSIUL->IFMC[13].R = SIUL_IFMC13;
    #endif
    #ifdef SIUL_IFMC14           /* IFMC 14 */
       pSIUL->IFMC[14].R = SIUL_IFMC14;
    #endif
    #ifdef SIUL_IFMC15           /* IFMC 15 */
       pSIUL->IFMC[15].R = SIUL_IFMC15;
    #endif
    #ifdef SIUL_IFMC16           /* IFMC 16 */
       pSIUL->IFMC[16].R = SIUL_IFMC16;
    #endif
    #ifdef SIUL_IFMC17           /* IFMC 17 */
       pSIUL->IFMC[17].R = SIUL_IFMC17;
    #endif
    #ifdef SIUL_IFMC18           /* IFMC 18 */
       pSIUL->IFMC[18].R = SIUL_IFMC18;
    #endif
    #ifdef SIUL_IFMC19           /* IFMC 19 */
       pSIUL->IFMC[19].R = SIUL_IFMC19;
    #endif
    #ifdef SIUL_IFMC20           /* IFMC 20 */
       pSIUL->IFMC[20].R = SIUL_IFMC20;
    #endif
    #ifdef SIUL_IFMC21           /* IFMC 21 */
       pSIUL->IFMC[21].R = SIUL_IFMC21;
    #endif
    #ifdef SIUL_IFMC22           /* IFMC 22 */
       pSIUL->IFMC[22].R = SIUL_IFMC22;
    #endif
    #ifdef SIUL_IFMC23           /* IFMC 23 */
       pSIUL->IFMC[23].R = SIUL_IFMC23;
    #endif
    #ifdef SIUL_IFMC24           /* IFMC 24 */
       pSIUL->IFMC[24].R = SIUL_IFMC24;
    #endif
    #ifdef SIUL_IFMC25           /* IFMC 25 */
       pSIUL->IFMC[25].R = SIUL_IFMC25;
    #endif
    #ifdef SIUL_IFMC26           /* IFMC 26 */
       pSIUL->IFMC[26].R = SIUL_IFMC26;
    #endif
    #ifdef SIUL_IFMC27           /* IFMC 27 */
       pSIUL->IFMC[27].R = SIUL_IFMC27;
    #endif
    #ifdef SIUL_IFMC28           /* IFMC 28 */
       pSIUL->IFMC[28].R = SIUL_IFMC28;
    #endif
    #ifdef SIUL_IFMC29           /* IFMC 29 */
       pSIUL->IFMC[29].R = SIUL_IFMC29;
    #endif
    #ifdef SIUL_IFMC30           /* IFMC 30 */
       pSIUL->IFMC[30].R = SIUL_IFMC30;
    #endif
    #ifdef SIUL_IFMC31           /* IFMC 31 */
       pSIUL->IFMC[31].R = SIUL_IFMC31;
    #endif

   /*-------------------------------------------------------------------------
    * SIU IRER register
   --------------------------------------------------------------------------*/
    #ifdef SIUL_IRER             /* IRER */
       pSIUL->IRER.R = SIUL_IRER;
    #endif

   /*-------------------------------------------------------------------------
    * SIU IREER register
   --------------------------------------------------------------------------*/
    #ifdef SIUL_IREER             /* IREER */
       pSIUL->IREER.R = SIUL_IREER;
    #endif

   /*-------------------------------------------------------------------------
    * SIU IFEER register
   --------------------------------------------------------------------------*/
    #ifdef SIUL_IFEER             /* IFEER */
       pSIUL->IFEER.R = SIUL_IREER;
    #endif

   /*-------------------------------------------------------------------------
    * SIU IFCPR register
   --------------------------------------------------------------------------*/
    #ifdef SIUL_IFCPR             /* IFCPR */
       pSIUL->IFCPR.R = SIUL_IFCPR;
    #endif

   /*-------------------------------------------------------------------------
    * SIU IFER register
   --------------------------------------------------------------------------*/
    #ifdef SIUL_IFER             /* IFER */
       pSIUL->IFER.R = SIUL_IFER;
    #endif
}
