/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!
*/

#include "MPC5643L.h"
#include "fccu.h"


/* ============================================================================
 * === DEFINES & MACROS & TYPEDEFS & ENUMS & STRUCTS
 * ==========================================================================*/

#define FCCU_OPS_IDLE		(uint8_t) 0
#define FCCU_OPS_INPR		(uint8_t) 1
#define FCCU_OPS_ABORT		(uint8_t) 2
#define FCCU_OPS_SUCCESS	(uint8_t) 3

#define FCCU_OPR_NOOP		(uint32_t) 0
#define FCCU_OPR_OP1		(uint32_t) 1
#define FCCU_OPR_OP2		(uint32_t) 2
#define FCCU_OPR_OP3		(uint32_t) 3
#define FCCU_OPR_OP9		(uint32_t) 9
#define FCCU_OPR_OP10		(uint32_t) 10
#define FCCU_OPR_OP15		(uint32_t) 15

#define FCCU_CTRLK_OP1		(uint32_t) 0x913756AF
#define FCCU_CTRLK_OP2		(uint32_t) 0x825A132B
#define FCCU_CTRLK_OP16		(uint32_t) 0x7ACB32F0
#define FCCU_CTRLK_OP31		(uint32_t) 0x29AF8752

#define FCCU_CFK			(uint32_t) 0x618B7A50
#define FCCU_NCFK			(uint32_t) 0xAB3498FE

#define ME_DRUN_MODE		(uint32_t) 3


/* ============================================================================
 * === VARIABLES
 * ==========================================================================*/

FCCU_tag fccu_regs;
uint16_t reset_flags_fes;
uint16_t reset_flags_des;
uint32_t me_gs;

/* ============================================================================
 * === ISR FUNCTIONS
 * ==========================================================================*/


/* ============================================================================
 * === MODULE FUNCTIONS
 * ==========================================================================*/

static void FccuReadRegs_Status(void);
static void FccuClearStatusRegs(void);
static void FccuReadClearResetFlags(void);


static void FccuReadRegs_Status(void)
{
	/* CF Status : set OP9, wait for completion, read status */
	FCCU.CTRL.R = FCCU_OPR_OP9;
	while (FCCU.CTRL.B.OPS != FCCU_OPS_SUCCESS)
		;
	fccu_regs.CFS_CFG0.R = FCCU.CFS_CFG0.R;
	fccu_regs.CFS_CFG1.R = FCCU.CFS_CFG1.R;
	fccu_regs.CFS_CFG2.R = FCCU.CFS_CFG2.R;
	fccu_regs.CFS_CFG3.R = FCCU.CFS_CFG3.R;

	/*fccu_regs.CFS[0].R = FCCU.CFS[0].R;
	fccu_regs.CFS[1].R = FCCU.CFS[1].R;
	fccu_regs.CFS[2].R = FCCU.CFS[2].R;
	fccu_regs.CFS[3].R = FCCU.CFS[3].R;*/

	/* NCF Status :	OP10, wait for completion, read */
	FCCU.CTRL.R = FCCU_OPR_OP10;
	while (FCCU.CTRL.B.OPS != FCCU_OPS_SUCCESS)
		;
	/*fccu_regs.NCFS[0].R = FCCU.NCFS[0].R;
	fccu_regs.NCFS[1].R = FCCU.NCFS[1].R;
	fccu_regs.NCFS[2].R = FCCU.NCFS[2].R;
	fccu_regs.NCFS[3].R = FCCU.NCFS[3].R;*/

	fccu_regs.NCFS_CFG0.R = FCCU.NCFS_CFG0.R;
	fccu_regs.NCFS_CFG1.R = FCCU.NCFS_CFG1.R;
	fccu_regs.NCFS_CFG2.R = FCCU.NCFS_CFG2.R;
	fccu_regs.NCFS_CFG3.R = FCCU.NCFS_CFG3.R;

	/* Status : OP3, wait for completion, read */
	FCCU.CTRL.R = FCCU_OPR_OP3;
	while (FCCU.CTRL.B.OPS != FCCU_OPS_SUCCESS)
		;
	fccu_regs.STAT.R = FCCU.STAT.R;
	
	/* IRQ Status */
	fccu_regs.IRQ_STAT.R = FCCU.IRQ_STAT.R;	
}

static void FccuClearStatusRegs(void)
{
	uint32_t i;
	uint32_t value;
	
	/* CFS Clear : key, clear flags, wait for completion, re-read */
	for (i=0; i < 4; ++i)
	{
		/*value = FCCU.CFS[i].R;
		FCCU.CFK.R = FCCU_CFK;
		FCCU.CFS[i].R = value;
		while (FCCU.CTRL.B.OPS != FCCU_OPS_SUCCESS)
			;*/

			value = FCCU.CFS_CFG[i].R;
			FCCU.CFK.R = FCCU_CFK;
			FCCU.CFS_CFG[i].R = value;
			while (FCCU.CTRL.B.OPS != FCCU_OPS_SUCCESS)
				;
	}
	

	/* CFS Clear : key, clear flags, wait for completion, re-read */
	for (i=0; i < 4; ++i)
	{
		/*value = FCCU.NCFS[i].R;
		FCCU.NCFK.R = FCCU_NCFK;
		FCCU.NCFS[i].R = value;
		while (FCCU.CTRL.B.OPS != FCCU_OPS_SUCCESS)
			;*/
		value = FCCU.NCFS_CFG[i].R;
		FCCU.NCFK.R = FCCU_NCFK;
		FCCU.NCFS_CFG[i].R = value;
		while (FCCU.CTRL.B.OPS != FCCU_OPS_SUCCESS)
			;
	}
	
}

static void FccuReadClearResetFlags(void)
{
	/* capture flags */
	reset_flags_fes = RGM.FES.R;
	reset_flags_des = RGM.DES.R;
	
	/* clear flags */
	RGM.FES.R = 0xFFFF;
	RGM.DES.R = 0xFFFF;
	
	/* save ME state */
	me_gs = ME.GS.R;
}



/* ============================================================================
 * === INTERFACE FUNCTIONS
 * ==========================================================================*/

void fccu_Capture(void)
{
	/* clear OPS at first */
	FCCU.CTRL.R = FCCU_OPR_OP15;
	while (FCCU.CTRL.B.OPS != FCCU_OPS_IDLE)
		;


	FccuReadRegs_Status();
	FccuClearStatusRegs();
	FccuReadClearResetFlags();
}


void fccu_Init(void)
{
	/* clear OPS at first */
	FCCU.CTRL.R = FCCU_OPR_OP15;
	while (FCCU.CTRL.B.OPS != FCCU_OPS_IDLE)
		;
	
	/* switch to config state */
	FCCU.CTRLK.R = FCCU_CTRLK_OP1;
	FCCU.CTRL.R = FCCU_OPR_OP1;
	while (FCCU.CTRL.B.OPS != FCCU_OPS_SUCCESS)
		;
	
	/* switch to normal state */
	FCCU.CTRLK.R = FCCU_CTRLK_OP2;
	FCCU.CTRL.R = FCCU_OPR_OP2;
	while (FCCU.CTRL.B.OPS != FCCU_OPS_SUCCESS)
		;
	
	/* resolve SAFE mode in ME if needed */
	if (ME.GS.B.S_CURRENT_MODE != ME_DRUN_MODE)
	{
	    ME.MCTL.R = (ME_DRUN_MODE << 28 | 0x00005AF0);        /* Mode & Key */
	    ME.MCTL.R = (ME_DRUN_MODE << 28 | 0x0000A50F);        /* Mode & Key */
	    /* Wait for mode entry to complete */
	    while(ME.GS.R & 0x08000000)
	    	;   
	    /* Check DRUN mode has been entered */
	    while(ME.GS.B.S_CURRENT_MODE != ME_DRUN_MODE)
	    	;
		
	}
	
}
