/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!
*
* @file     sys.c
*
* @author   r63172
* 
* @version  1.0.1.0
* 
* @date     Nov-15-2010
* 
* @brief    System initialization functions. Magic Carpet initialization.
*           Interrupt initialization.
*
*******************************************************************************
*
* Detailed Description of the file.
*
*******************************************************************************/

/*******************************************************************************
* External objects
*******************************************************************************/
#include "MPC5643L_qs.h"
#include "sys.h"

/***************************************************************************//*!
@brief          Leopard Magic Carpet module initialization

@param[in,out]  void
@param[in]      void

@return         void

@details        The function setup Leopard Magic Carpet, which includes clock
                generation module (CGM), mode entry (ME), reset generation
                module (RGM), power control unit (PCU).

@warning        
******************************************************************************/
void mc_mode_init(void)
{   
    volatile tU32      temp,timer;

    //   Disable Software Watchdog (SWT)
    SWT.SR.R                        = 0xc520;
    SWT.SR.R                        = 0xd928;
    SWT.CR.R                        = 0x8000010A;

    #ifdef DP
    SWT1.SR.R                       = 0xc520;
    SWT1.SR.R                       = 0xd928;
    SWT1.CR.R                       = 0x8000010A;
    #endif

    /*====================================================
     External clock (Clockout) configuration
     ====================================================*/
    CGM.OCDS_SC.B.SELCTL            = OCDSSC_CLKOUT_SRC_SYSPLL; // system clock source
    CGM.OCDS_SC.B.SELDIV            = OCDSSC_CLKOUT_DIVBY_4;    // system clock division
    CGM.OC_EN.B.EN                  = CLKOUT_ENABLE;            // output clock enabled
    
    /*====================================================
     Auxiliary Clock 0
     - motor control clock MC_PLL_CLK   DIV0    DE0
     - SWG clock                        DIV1    DE1
     ====================================================*/
    CGM.AC0_SC.B.SELCTL             = AC0SC_CLKSRC_SECPLL;      // Aux0 clock source select
    CGM.AC0_DC0_3.B.DIV0            = 0;                        // Aux0 clock divider   0 = 1:1;  1 = 1:2;  2 = 1:3 ... 15 = 1:16
    CGM.AC0_DC0_3.B.DE0             = AC0DC_DIVIDER_ENABLE;     // Aux0 clock divider enable

    CGM.AC0_DC0_3.B.DIV1            = 0;                        // Aux0 clock divider   0 = 1:1;  1 = 1:2;  2 = 1:3 ... 15 = 1:16
    CGM.AC0_DC0_3.B.DE1             = AC0DC_DIVIDER_ENABLE;     // Aux0 clock divider enable

    /*====================================================
     Auxiliary Clock 1 (FlexRay clock ) configuration
     ====================================================*/
    CGM.AC1_SC.B.SELCTL              = AC1SC_CLKSRC_SECPLL;
    CGM.AC1_DC0_3.B.DIV0             = 0;                        // Aux1 clock divider   0 = 1:1;  1 = 1:2;  2 = 1:3 ... 15 = 1:16
    CGM.AC1_DC0_3.B.DE0              = AC1DC_DIVIDER_ENABLE;

    /*====================================================
     Auxiliary Clock 2 (FlexCan clock) configuration
     ====================================================*/
    CGM.AC2_SC.B.SELCTL              = AC2SC_CLKSRC_INT;
    CGM.AC1_DC0_3.B.DIV0             = 0;                        // Aux2 clock divider   0 = 1:1;  1 = 1:2;  2 = 1:3 ... 15 = 1:16
    CGM.AC2_DC0_3.B.DE0              = AC2DC_DIVIDER_ENABLE;

    /*====================================================
     Auxiliary Clock 3 Clock source for FMPLL0
     ====================================================*/
    CGM.AC3_SC.B.SELCTL              = 1;                       // 4-40MHz XSC

    /*====================================================
     Auxiliary Clock 4 Clock source for FMPLL1
     ====================================================*/
    CGM.AC4_SC.B.SELCTL              = 1;                       // 4-40MHz XSC

    // Clear all reset flags to avoid staying in SAFE mode
    RGM.FES.R                       = 0xFFFF;

    /*====================================================
     Modes Configurations
     ====================================================*/
    // enable all modes
    ME.MEN.B.STOP0                  = ME_MODE_STOP0_ENABLED;
    ME.MEN.B.HALT0                  = ME_MODE_HALT0_ENABLED;
    ME.MEN.B.RUN3                   = ME_MODE_RUN3_ENABLED;
    ME.MEN.B.RUN2                   = ME_MODE_RUN2_ENABLED;
    ME.MEN.B.RUN1                   = ME_MODE_RUN1_ENABLED;
    ME.MEN.B.RUN0                   = ME_MODE_RUN0_ENABLED;
    ME.MEN.B.DRUN                   = ME_MODE_DRUN_ENABLED;
    ME.MEN.B.SAFE                   = ME_MODE_SAFE_ENABLED;
    ME.MEN.B.RESET_FUNC             = ME_MODE_RESET_ENABLED;

    
    // DRUN mode configuration
    ME.DRUN.B.FLAON                 = DRUN_DFLASH_NORMAL_MODE;
    ME.DRUN.B.PLL0ON                = DRUN_SYSPLL_OFF;          // PLL0 disabled
    ME.DRUN.B.PLL1ON                = DRUN_SECPLL_OFF;          // PLL1 disabled
    ME.DRUN.B.XOSCON                = DRUN_XOSC_ON;             // Switch on external osc.
    ME.DRUN.B.IRCOSCON              = DRUN_INTOSC_ON;           // Switch on internal osc.
    //ME.DRUN.B.SYSCLK                = SYSCLK_SRC_OSC;           // select internal osc for system clock
    ME.DRUN.B.SYSCLK                = SYSCLK_SRC_INT;           // select internal osc for system clock

    CGM.CMU_0_CSR.B.RCDIV           = 3;
    // to avoid CMU reset in case of Fmosc<Frcosc	
    CGM.CMU_0_LFREFR_A.B.LFREF_A    = 0x1;
    CGM.CMU_0_HFREFR_A.B.HFREF_A    = 0xFFE;

    CGM.CMU_1_CSR.B.RCDIV           = 3;
    // to avoid CMU reset in case of Fmosc<Frcosc
    CGM.CMU_1_LFREFR_A.B.LFREF_A    = 0x1;
    CGM.CMU_1_HFREFR_A.B.HFREF_A    = 0xFFE;

    // Re-enter in DRUN mode to update the configuration
    ME.MCTL.R                       = 0x30005AF0;   // DRUN Mode & Key
    ME.MCTL.R                       = 0x3000A50F;   // DRUN Mode & Key

    //ME_GS Wait for external osc to stabilize.
    //while(ME.GS.B.S_XOSC==0);
    while(ME.GS.B.S_IRCOSC==0);

    temp = ME.GS.B.S_MTRANS;

    temp = ME.GS.B.S_CURRENT_MODE;

    //waiting for end of transaction
    //timer = 1000;
    //while(ME.GS.B.S_MTRANS == 1 || timer>0) {asm("nop");timer -=1;}
    while(ME.GS.B.S_MTRANS == 1);

    //ME_GS Check DRUN mode has successfully been entered
    while(ME.GS.B.S_CURRENT_MODE != 3 );

#if 0
    //PLL0 80 MHz primary PLL   XTAL-8MHZ
    CGM.FMPLL[0].CR.B.IDF           = 0;
    CGM.FMPLL[0].CR.B.NDIV          = 40;
    CGM.FMPLL[0].CR.B.ODF           = 1;
#endif
#if 1
    //PLL0 120 MHz primary PLL   XTAL-8MHZ
    CGM.FMPLL[0].CR.B.IDF           = 0;
    CGM.FMPLL[0].CR.B.NDIV          = 60;
    CGM.FMPLL[0].CR.B.ODF           = 1;
#endif
#if 0
    //PLL0 60 MHz primary PLL   XTAL-8MHZ
    CGM.FMPLL[0].CR.B.IDF           = 0;
    CGM.FMPLL[0].CR.B.NDIV          = 60;
    CGM.FMPLL[0].CR.B.ODF           = 2;
#endif
#if 0
    //PLL0 80 MHz primary PLL   XTAL-40MHZ
    CGM.FMPLL[0].CR.B.IDF           = 3;
    CGM.FMPLL[0].CR.B.NDIV          = 32;
    CGM.FMPLL[0].CR.B.ODF           = 1;
#endif

#if 0
    //PLL0 120 MHz secondary PLL    XTAL-40MHZ
    CGM.FMPLL[0].CR.B.IDF           = 2;
    CGM.FMPLL[0].CR.B.NDIV          = 24;
    CGM.FMPLL[0].CR.B.ODF           = 1;
#endif

#if 0
    //PLL1 120 MHz secondary PLL    XTAL-40MHZ
    CGM.FMPLL[1].CR.B.IDF           = 2;
    CGM.FMPLL[1].CR.B.NDIV          = 24;
    CGM.FMPLL[1].CR.B.ODF           = 1;
#endif

#if 1
    //PLL1 120 MHz secondary PLL    XTAL-8MHZ
    CGM.FMPLL[1].CR.B.IDF           = 0;
    CGM.FMPLL[1].CR.B.NDIV          = 60;
    CGM.FMPLL[1].CR.B.ODF           = 1;
#endif

    ME.DRUN.B.PLL0ON                = 0x1;          // PLL0 enabled
    ME.DRUN.B.PLL1ON                = 0x1;          // PLL1 enabled
    ME.DRUN.B.SYSCLK                = PLL0;         // select SYS PLL

    // Enable Periphs in all running modes
    ME.RUNPC[0].R                   = 0x000000FE;

    // Enable Periphs in low power modes
    ME.LPPC[0].R                    = 0x00000500;
    
    // Re-enter in DRUN mode to update the configuration	
    ME.MCTL.R                       = 0x30005AF0;   // DRUN Mode & Key
    ME.MCTL.R                       = 0x3000A50F;   // DRUN Mode & Key

    // ME_GS Wait for FPLL_0 to stabilize.   
    while(ME.GS.B.S_PLL0==0);

    // ME_GS Wait for FPLL_1 to stabilize.
    while(ME.GS.B.S_PLL1==0);

    // waiting for end of transaction
    while (ME.GS.B.S_MTRANS == 1);

    //ME_GS Check DRUN mode has successfully been entered
    while(ME.GS.B.S_CURRENT_MODE != 3 );

    // wait for PLL to lock - will not lock before DRUN re-entry 
    while(CGM.FMPLL[0].CR.B.S_LOCK==0);

    // wait for PLL to lock - will not lock before DRUN re-entry 
    while(CGM.FMPLL[1].CR.B.S_LOCK==0);

 //ME_GS Poll Global status register to get current system clock
 //fail if system clock is not pll
 //0000 16MHz internal RC oscillator
 //0001 divided 16MHz internal RC oscillator
 //0010 4MHz crystal oscillator
 //0011 divided 4MHz crystal oscillator
 //0100 system PLL
 //1111 system clock is disabled
    while(ME.GS.B.S_SYSCLK != 0x4){};//ME_GS fail here
}


void sys_init(void)
{
    // Initialize Magic Carpet: clock, CPU mode, reset states etc.
    mc_mode_init();


}
/*****************************************************************************/
