/******************************************************************************
*
* Freescale Semiconductor Inc.
* (c) Copyright 2008 Freescale Semiconductor, Inc.
* ALL RIGHTS RESERVED.
*
***************************************************************************//*!
*
* @file      state_machine.c
*
* @author    b15651
* 
* @version   1.0.1.0
* 
* @date      Jul-13-2012
* 
* @brief     Header file for StateMachineFrame "c" project
*
*******************************************************************************
*
* Detailed Description of the file. If not used, remove the separator above.
*
******************************************************************************/

/******************************************************************************
* Includes
******************************************************************************/
#include "state_machine.h"

/******************************************************************************
| External declarations
-----------------------------------------------------------------------------*/

/******************************************************************************
| Defines and macros            (scope: module-local)
-----------------------------------------------------------------------------*/

/******************************************************************************
| Typedefs and structures       (scope: module-local)
-----------------------------------------------------------------------------*/

/******************************************************************************
| Global variable definitions   (scope: module-exported)
-----------------------------------------------------------------------------*/

/******************************************************************************
| Global variable definitions   (scope: module-local)
-----------------------------------------------------------------------------*/

/******************************************************************************
| Function prototypes           (scope: module-local)
-----------------------------------------------------------------------------*/


/******************************************************************************
| Function implementations      (scope: module-local)
-----------------------------------------------------------------------------*/

/******************************************************************************
| Function implementations      (scope: module-exported)
-----------------------------------------------------------------------------*/
extern void stateFault(pmsmDrive_t *ptr);
extern void stateInit(pmsmDrive_t *ptr);
extern void stateReady(pmsmDrive_t *ptr);
extern void stateCalib(pmsmDrive_t *ptr);
extern void stateAlign(pmsmDrive_t *ptr);
extern void stateRun(pmsmDrive_t *ptr);

extern PFCN_VOID_PARAM_PMSM state_table[12][6]={
    /* Actual state ->         'Init'           'Fault'         'Ready'         'Calib'         'Align'         'Run'*/
    /* e_fault          */ { stateFault,     stateFault,     stateFault,     stateFault,     stateFault,     stateFault},
    /* e_fault_clear    */ { stateFault,     stateInit,      stateFault,     stateFault,     stateFault,     stateFault},
    /* e_init          	*/ { stateInit,      stateFault,     stateInit,     stateFault,     stateFault,     stateFault},
    /* e_init_done      */ { stateReady,     stateFault,     stateFault,     stateFault,     stateFault,     stateFault},
    /* e_ready          */ { stateFault,     stateFault,     stateReady,     stateFault,     stateFault,     stateFault},
    /* e_app_on         */ { stateFault,     stateFault,     stateCalib,     stateFault,     stateFault,     stateFault},
    /* e_calib          */ { stateFault,     stateFault,     stateFault,     stateCalib,     stateFault,     stateFault},
    /* e_calib_done     */ { stateFault,     stateFault,     stateFault,     stateAlign,     stateFault,     stateFault},
    /* e_align          */ { stateFault,     stateFault,     stateFault,     stateFault,     stateAlign,     stateFault},
    /* e_align_done     */ { stateFault,     stateFault,     stateFault,     stateFault,     stateRun,       stateFault},
    /* e_run            */ { stateFault,     stateFault,     stateFault,     stateFault,     stateFault,     stateRun},
    /* e_app_off        */ { stateFault,     stateFault,     stateReady,     stateInit,      stateInit,      stateInit}
};

/* LED application control*/

/***************************************************************************//*!
*
* @brief   LED OFF state
*
* @param   pointer to structure of pmsmDrive_t type
* 		   base address of selected SUIL PAD
*
* @return  none
*
******************************************************************************/
void stateLedOFF(pmsmDrive_t *ptr, tS32 SUIL_PAD_ADDR)
{
	ioctl(SIUL_BASE,SIUL_CLEAR_PAD, SUIL_PAD_ADDR);
}

/***************************************************************************//*!
*
* @brief   LED ON state
*
* @param   pointer to structure of pmsmDrive_t type
* 		   base address of selected SUIL PAD
*
* @return  none
*
******************************************************************************/
void stateLedON(pmsmDrive_t *ptr, tS32 SUIL_PAD_ADDR)
{
	ioctl(SIUL_BASE,SIUL_SET_PAD, SUIL_PAD_ADDR);
}

/***************************************************************************//*!
*
* @brief   LED FLASHING state
*
* @param    pointer to structure of pmsmDrive_t type,
* 			base address of selected SUIL PAD
*
* @return  none
*
******************************************************************************/
void stateLedFLASHING_SLOW(pmsmDrive_t *ptr, tS32 SUIL_PAD_ADDR)
{
	ptr->cntrState.ledCounter += 1;

	if((ptr->cntrState.ledCounter)>((ptr->cntrState.ledFlashing)<<1))
	{
	ioctl(SIUL_BASE,SIUL_TOGGLE_PAD, SUIL_PAD_ADDR);
	ptr->cntrState.ledCounter = 0;
	}
}

/***************************************************************************//*!
*
* @brief   LED FLASHING state
*
* @param    pointer to structure of pmsmDrive_t type,
* 			base address of selected SUIL PAD
*
* @return  none
*
******************************************************************************/
void stateLedFLASHING_FAST(pmsmDrive_t *ptr, tS32 SUIL_PAD_ADDR)
{
	ptr->cntrState.ledCounter += 1;

	if((ptr->cntrState.ledCounter)>((ptr->cntrState.ledFlashing)>>1))
	{
	ioctl(SIUL_BASE,SIUL_TOGGLE_PAD, SUIL_PAD_ADDR);
	ptr->cntrState.ledCounter = 0;
	}
}

/* Actual state ->         				'Init'			'Fault'			   'Ready'         'Calib'					'Align'	         'Run'*/
extern PFCN_VOID_LED state_LED[6] = {stateLedOFF, stateLedFLASHING_FAST, stateLedOFF, stateLedFLASHING_SLOW, stateLedFLASHING_SLOW,	stateLedON};
