/******************************************************************************
*
* Copyright 2006-2015 Freescale Semiconductor, Inc.
* Copyright 2016-2017 NXP
*
***************************************************************************//*!
*
* @file       MPC5643L_CTU_LLD.h
*
* @author     r63172
*
* @version    1.0.1.0
*
* @date       Jul-13-2012
*
* @brief      CTU low level driver module for MPC5643L.
*
*******************************************************************************
*
* This file includes initial setting and MACRO definitions of MPC5643L CTU
* peripheral module.
*
******************************************************************************/

#ifndef _MPC5643L_CTU_LLD_H_
#define _MPC5643L_CTU_LLD_H_

#ifdef __cplusplus
extern "C" {
#endif

#define CTU_BASE                                        0xFFE0C000

/******************************************************************************
* CTU ioctl commands definitions
******************************************************************************/
/***************************************************************************//*!
*
* @brief                Select input signal for trigger generator subunit
*
* @param                CTU_PWMREL_RISING
* @param                CTU_PWMREL_FALING
* @param                CTU_PWM_SUB0_OUT0_RISING
* @param                CTU_PWM_SUB0_OUT0_FALING
* @param                CTU_PWM_SUB1_OUT0_RISING
* @param                CTU_PWM_SUB1_OUT0_FALING
* @param                CTU_PWM_SUB2_OUT0_RISING
* @param                CTU_PWM_SUB2_OUT0_FALING
* @param                CTU_PWM_SUB3_OUT0_RISING
* @param                CTU_PWM_SUB3_OUT0_FALING
* @param                CTU_PWM_SUB0_OUT1_RISING
* @param                CTU_PWM_SUB0_OUT1_FALING
* @param                CTU_PWM_SUB1_OUT1_RISING
* @param                CTU_PWM_SUB1_OUT1_FALING
* @param                CTU_PWM_SUB2_OUT1_RISING
* @param                CTU_PWM_SUB2_OUT1_FALING
* @param                CTU_PWM_SUB3_OUT1_RISING
* @param                CTU_PWM_SUB3_OUT1_FALING
* @param                CTU_PWM_X0_RISING
* @param                CTU_PWM_X0_FALING
* @param                CTU_PWM_X1_RISING
* @param                CTU_PWM_X1_FALING
* @param                CTU_PWM_X2_RISING
* @param                CTU_PWM_X2_FALING
* @param                CTU_PWM_X3_RISING
* @param                CTU_PWM_X3_FALING
* @param                CTU_ETIMER0_RISING
* @param                CTU_ETIMER0_FALING
* @param                CTU_ETIMER1_RISING
* @param                CTU_ETIMER1_FALING
* @param                CTU_EXT_SIGNAL_RISING
* @param                CTU_EXT_SIGNAL_FALING
*
* @return               NULL
*
* @details              The #CTU_TGS_INPUT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TGS_INPUT, CTU_PWMREL_RISING);
* \endcode
*
******************************************************************************/
#define CTU_TGS_INPUT

/***************************************************************************//*!
*
* @brief                Set Trigger Generator Subunit (TGS) mode
*
* @param                CTU_TRIGGERED
* @param                CTU_SEQUENTIAL
*
* @return               NULL
*
* @details              The #CTU_TGS_MODE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TGS_MODE, CTU_TRIGGERED);
* \endcode
*
******************************************************************************/
#define CTU_TGS_MODE

/***************************************************************************//*!
*
* @brief                Select source signal for triggering CTU MRS
*
* @param                CTU_PWMREL
* @param                CTU_PWM_SUB0_OUT0
* @param                CTU_PWM_SUB1_OUT0
* @param                CTU_PWM_SUB2_OUT0
* @param                CTU_PWM_SUB3_OUT0
* @param                CTU_PWM_SUB0_OUT1
* @param                CTU_PWM_SUB1_OUT1
* @param                CTU_PWM_SUB2_OUT1
* @param                CTU_PWM_SUB3_OUT1
* @param                CTU_PWM_X0
* @param                CTU_PWM_X1
* @param                CTU_PWM_X2
* @param                CTU_PWM_X3
* @param                CTU_ETIMER0
* @param                CTU_ETIMER1
* @param                CTU_EXT_SIGNAL
*
* @return               NULL
*
* @details              The #CTU_SEQUENTIAL_MRS_SOURCE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SEQUENTIAL_MRS_SOURCE, CTU_PWMREL);
* \endcode
*
******************************************************************************/
#define CTU_SEQUENTIAL_MRS_SOURCE

/***************************************************************************//*!
*
* @brief                Set CTU clock prescaler
*
* @param                CTU_BYPASSED
* @param                CTU_CLK_DIVBY_2
* @param                CTU_CLK_DIVBY_3
* @param                CTU_CLK_DIVBY_4
*
* @return               NULL
*
* @details              The #CTU_CLOCK_PRESCALER ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_CLOCK_PRESCALER, CTU_BYPASSED);
* \endcode
*
******************************************************************************/
#define CTU_CLOCK_PRESCALER

/***************************************************************************//*!
*
* @brief                Enable toggle mode for external output
*
* @param                CTU_DISABLE
* @param                CTU_ENABLE
*
* @return               NULL
*
* @details              The #CTU_EXT_TRIGGER_TOGGLE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_EXT_TRIGGER_TOGGLE, CTU_DISABLE);
* \endcode
*
******************************************************************************/
#define CTU_EXT_TRIGGER_TOGGLE

/***************************************************************************//*!
*
* @brief                Set CTU trigger T0 compare value
*
* @param                16bit value
*
* @return               NULL
*
* @details              The #CTU_TRG0_COMP_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG0_COMP_VALUE, 16bit value);
* \endcode
*
******************************************************************************/
#define CTU_TRG0_COMP_VALUE

/***************************************************************************//*!
*
* @brief                Set CTU trigger T1 compare value
*
* @param                16bit value
*
* @return               NULL
*
* @details              The #CTU_TRG1_COMP_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG1_COMP_VALUE, 16bit value);
* \endcode
*
******************************************************************************/
#define CTU_TRG1_COMP_VALUE

/***************************************************************************//*!
*
* @brief                Set CTU trigger T2 compare value
*
* @param                16bit value
*
* @return               NULL
*
* @details              The #CTU_TRG2_COMP_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG2_COMP_VALUE, 16bit value);
* \endcode
*
******************************************************************************/
#define CTU_TRG2_COMP_VALUE

/***************************************************************************//*!
*
* @brief                Set CTU trigger T3 compare value
*
* @param                16bit value
*
* @return               NULL
*
* @details              The #CTU_TRG3_COMP_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG3_COMP_VALUE, 16bit value);
* \endcode
*
******************************************************************************/
#define CTU_TRG3_COMP_VALUE

/***************************************************************************//*!
*
* @brief                Set CTU trigger T4 compare value
*
* @param                16bit value
*
* @return               NULL
*
* @details              The #CTU_TRG4_COMP_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG4_COMP_VALUE, 16bit value);
* \endcode
*
******************************************************************************/
#define CTU_TRG4_COMP_VALUE

/***************************************************************************//*!
*
* @brief                Set CTU trigger T5 compare value
*
* @param                16bit value
*
* @return               NULL
*
* @details              The #CTU_TRG5_COMP_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG5_COMP_VALUE, 16bit value);
* \endcode
*
******************************************************************************/
#define CTU_TRG5_COMP_VALUE

/***************************************************************************//*!
*
* @brief                Set CTU trigger T6 compare value
*
* @param                16bit value
*
* @return               NULL
*
* @details              The #CTU_TRG6_COMP_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG6_COMP_VALUE, 16bit value);
* \endcode
*
******************************************************************************/
#define CTU_TRG6_COMP_VALUE

/***************************************************************************//*!
*
* @brief                Set CTU trigger T7 compare value
*
* @param                16bit value
*
* @return               NULL
*
* @details              The #CTU_TRG7_COMP_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG7_COMP_VALUE, 16bit value);
* \endcode
*
******************************************************************************/
#define CTU_TRG7_COMP_VALUE

/***************************************************************************//*!
*
* @brief                Set CTU counter reload value
*
* @param                16bit value
*
* @return               NULL
*
* @details              The #CTU_TGS_REL_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TGS_REL_VALUE, 16bit value);
* \endcode
*
******************************************************************************/
#define CTU_TGS_REL_VALUE

/***************************************************************************//*!
*
* @brief                Set CTU counter compare value
*
* @param                16bit value
*
* @return               NULL
*
* @details              The #CTU_TGS_COMP_VALUE ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TGS_COMP_VALUE, 16bit value);
* \endcode
*
******************************************************************************/
#define CTU_TGS_COMP_VALUE

/***************************************************************************//*!
*
* @brief                Set trigger T0 first command address offset
*
* @param                CTU_ADCCMD_0
* @param                CTU_ADCCMD_1
* @param                CTU_ADCCMD_2
* @param                CTU_ADCCMD_3
* @param                CTU_ADCCMD_4
* @param                CTU_ADCCMD_5
* @param                CTU_ADCCMD_6
* @param                CTU_ADCCMD_7
* @param                CTU_ADCCMD_8
* @param                CTU_ADCCMD_9
* @param                CTU_ADCCMD_10
* @param                CTU_ADCCMD_11
* @param                CTU_ADCCMD_12
* @param                CTU_ADCCMD_13
* @param                CTU_ADCCMD_14
* @param                CTU_ADCCMD_15
* @param                CTU_ADCCMD_16
* @param                CTU_ADCCMD_17
* @param                CTU_ADCCMD_18
* @param                CTU_ADCCMD_19
* @param                CTU_ADCCMD_20
* @param                CTU_ADCCMD_21
* @param                CTU_ADCCMD_22
* @param                CTU_ADCCMD_23
*
* @return               NULL
*
* @details              The #CTU_TRG0_FIRST_ADCCMD ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG0_FIRST_ADCCMD, CTU_ADCCMD_0);
* \endcode
*
******************************************************************************/
#define CTU_TRG0_FIRST_ADCCMD

/***************************************************************************//*!
*
* @brief                Set trigger T1 first command address offset
*
* @param                CTU_ADCCMD_0
* @param                CTU_ADCCMD_1
* @param                CTU_ADCCMD_2
* @param                CTU_ADCCMD_3
* @param                CTU_ADCCMD_4
* @param                CTU_ADCCMD_5
* @param                CTU_ADCCMD_6
* @param                CTU_ADCCMD_7
* @param                CTU_ADCCMD_8
* @param                CTU_ADCCMD_9
* @param                CTU_ADCCMD_10
* @param                CTU_ADCCMD_11
* @param                CTU_ADCCMD_12
* @param                CTU_ADCCMD_13
* @param                CTU_ADCCMD_14
* @param                CTU_ADCCMD_15
* @param                CTU_ADCCMD_16
* @param                CTU_ADCCMD_17
* @param                CTU_ADCCMD_18
* @param                CTU_ADCCMD_19
* @param                CTU_ADCCMD_20
* @param                CTU_ADCCMD_21
* @param                CTU_ADCCMD_22
* @param                CTU_ADCCMD_23
*
* @return               NULL
*
* @details              The #CTU_TRG1_FIRST_ADCCMD ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG1_FIRST_ADCCMD, CTU_ADCCMD_0);
* \endcode
*
******************************************************************************/
#define CTU_TRG1_FIRST_ADCCMD

/***************************************************************************//*!
*
* @brief                Set trigger T2 first command address offset
*
* @param                CTU_ADCCMD_0
* @param                CTU_ADCCMD_1
* @param                CTU_ADCCMD_2
* @param                CTU_ADCCMD_3
* @param                CTU_ADCCMD_4
* @param                CTU_ADCCMD_5
* @param                CTU_ADCCMD_6
* @param                CTU_ADCCMD_7
* @param                CTU_ADCCMD_8
* @param                CTU_ADCCMD_9
* @param                CTU_ADCCMD_10
* @param                CTU_ADCCMD_11
* @param                CTU_ADCCMD_12
* @param                CTU_ADCCMD_13
* @param                CTU_ADCCMD_14
* @param                CTU_ADCCMD_15
* @param                CTU_ADCCMD_16
* @param                CTU_ADCCMD_17
* @param                CTU_ADCCMD_18
* @param                CTU_ADCCMD_19
* @param                CTU_ADCCMD_20
* @param                CTU_ADCCMD_21
* @param                CTU_ADCCMD_22
* @param                CTU_ADCCMD_23
*
* @return               NULL
*
* @details              The #CTU_TRG2_FIRST_ADCCMD ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG2_FIRST_ADCCMD, CTU_ADCCMD_0);
* \endcode
*
******************************************************************************/
#define CTU_TRG2_FIRST_ADCCMD

/***************************************************************************//*!
*
* @brief                Set trigger T3 first command address offset
*
* @param                CTU_ADCCMD_0
* @param                CTU_ADCCMD_1
* @param                CTU_ADCCMD_2
* @param                CTU_ADCCMD_3
* @param                CTU_ADCCMD_4
* @param                CTU_ADCCMD_5
* @param                CTU_ADCCMD_6
* @param                CTU_ADCCMD_7
* @param                CTU_ADCCMD_8
* @param                CTU_ADCCMD_9
* @param                CTU_ADCCMD_10
* @param                CTU_ADCCMD_11
* @param                CTU_ADCCMD_12
* @param                CTU_ADCCMD_13
* @param                CTU_ADCCMD_14
* @param                CTU_ADCCMD_15
* @param                CTU_ADCCMD_16
* @param                CTU_ADCCMD_17
* @param                CTU_ADCCMD_18
* @param                CTU_ADCCMD_19
* @param                CTU_ADCCMD_20
* @param                CTU_ADCCMD_21
* @param                CTU_ADCCMD_22
* @param                CTU_ADCCMD_23
*
* @return               NULL
*
* @details              The #CTU_TRG3_FIRST_ADCCMD ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG3_FIRST_ADCCMD, CTU_ADCCMD_0);
* \endcode
*
******************************************************************************/
#define CTU_TRG3_FIRST_ADCCMD

/***************************************************************************//*!
*
* @brief                Set trigger T4 first command address offset
*
* @param                CTU_ADCCMD_0
* @param                CTU_ADCCMD_1
* @param                CTU_ADCCMD_2
* @param                CTU_ADCCMD_3
* @param                CTU_ADCCMD_4
* @param                CTU_ADCCMD_5
* @param                CTU_ADCCMD_6
* @param                CTU_ADCCMD_7
* @param                CTU_ADCCMD_8
* @param                CTU_ADCCMD_9
* @param                CTU_ADCCMD_10
* @param                CTU_ADCCMD_11
* @param                CTU_ADCCMD_12
* @param                CTU_ADCCMD_13
* @param                CTU_ADCCMD_14
* @param                CTU_ADCCMD_15
* @param                CTU_ADCCMD_16
* @param                CTU_ADCCMD_17
* @param                CTU_ADCCMD_18
* @param                CTU_ADCCMD_19
* @param                CTU_ADCCMD_20
* @param                CTU_ADCCMD_21
* @param                CTU_ADCCMD_22
* @param                CTU_ADCCMD_23
*
* @return               NULL
*
* @details              The #CTU_TRG4_FIRST_ADCCMD ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG4_FIRST_ADCCMD, CTU_ADCCMD_0);
* \endcode
*
******************************************************************************/
#define CTU_TRG4_FIRST_ADCCMD

/***************************************************************************//*!
*
* @brief                Set trigger T5 first command address offset
*
* @param                CTU_ADCCMD_0
* @param                CTU_ADCCMD_1
* @param                CTU_ADCCMD_2
* @param                CTU_ADCCMD_3
* @param                CTU_ADCCMD_4
* @param                CTU_ADCCMD_5
* @param                CTU_ADCCMD_6
* @param                CTU_ADCCMD_7
* @param                CTU_ADCCMD_8
* @param                CTU_ADCCMD_9
* @param                CTU_ADCCMD_10
* @param                CTU_ADCCMD_11
* @param                CTU_ADCCMD_12
* @param                CTU_ADCCMD_13
* @param                CTU_ADCCMD_14
* @param                CTU_ADCCMD_15
* @param                CTU_ADCCMD_16
* @param                CTU_ADCCMD_17
* @param                CTU_ADCCMD_18
* @param                CTU_ADCCMD_19
* @param                CTU_ADCCMD_20
* @param                CTU_ADCCMD_21
* @param                CTU_ADCCMD_22
* @param                CTU_ADCCMD_23
*
* @return               NULL
*
* @details              The #CTU_TRG5_FIRST_ADCCMD ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG5_FIRST_ADCCMD, CTU_ADCCMD_0);
* \endcode
*
******************************************************************************/
#define CTU_TRG5_FIRST_ADCCMD

/***************************************************************************//*!
*
* @brief                Set trigger T6 first command address offset
*
* @param                CTU_ADCCMD_0
* @param                CTU_ADCCMD_1
* @param                CTU_ADCCMD_2
* @param                CTU_ADCCMD_3
* @param                CTU_ADCCMD_4
* @param                CTU_ADCCMD_5
* @param                CTU_ADCCMD_6
* @param                CTU_ADCCMD_7
* @param                CTU_ADCCMD_8
* @param                CTU_ADCCMD_9
* @param                CTU_ADCCMD_10
* @param                CTU_ADCCMD_11
* @param                CTU_ADCCMD_12
* @param                CTU_ADCCMD_13
* @param                CTU_ADCCMD_14
* @param                CTU_ADCCMD_15
* @param                CTU_ADCCMD_16
* @param                CTU_ADCCMD_17
* @param                CTU_ADCCMD_18
* @param                CTU_ADCCMD_19
* @param                CTU_ADCCMD_20
* @param                CTU_ADCCMD_21
* @param                CTU_ADCCMD_22
* @param                CTU_ADCCMD_23
*
* @return               NULL
*
* @details              The #CTU_TRG6_FIRST_ADCCMD ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG6_FIRST_ADCCMD, CTU_ADCCMD_0);
* \endcode
*
******************************************************************************/
#define CTU_TRG6_FIRST_ADCCMD

/***************************************************************************//*!
*
* @brief                Set trigger T7 first command address offset
*
* @param                CTU_ADCCMD_0
* @param                CTU_ADCCMD_1
* @param                CTU_ADCCMD_2
* @param                CTU_ADCCMD_3
* @param                CTU_ADCCMD_4
* @param                CTU_ADCCMD_5
* @param                CTU_ADCCMD_6
* @param                CTU_ADCCMD_7
* @param                CTU_ADCCMD_8
* @param                CTU_ADCCMD_9
* @param                CTU_ADCCMD_10
* @param                CTU_ADCCMD_11
* @param                CTU_ADCCMD_12
* @param                CTU_ADCCMD_13
* @param                CTU_ADCCMD_14
* @param                CTU_ADCCMD_15
* @param                CTU_ADCCMD_16
* @param                CTU_ADCCMD_17
* @param                CTU_ADCCMD_18
* @param                CTU_ADCCMD_19
* @param                CTU_ADCCMD_20
* @param                CTU_ADCCMD_21
* @param                CTU_ADCCMD_22
* @param                CTU_ADCCMD_23
*
* @return               NULL
*
* @details              The #CTU_TRG7_FIRST_ADCCMD ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG7_FIRST_ADCCMD, CTU_ADCCMD_0);
* \endcode
*
******************************************************************************/
#define CTU_TRG7_FIRST_ADCCMD

/***************************************************************************//*!
*
* @brief                Trigger 0 control
*
* @param                CTU_TRG_ENABLE
* @param                CTU_EXT_OUT_ENABLE
* @param                CTU_ETIMER0_OUT_ENABLE
* @param                CTU_ETIMER1_OUT_ENABLE
* @param                CTU_ETIMER2_OUT_ENABLE
* @param                CTU_ADC_OUT_ENABLE
*
* @return               NULL
*
* @details              The #CTU_TRG0_CONTROL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG0_CONTROL, CTU_TRG_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_TRG0_CONTROL

/***************************************************************************//*!
*
* @brief                Trigger 1 control
*
* @param                CTU_TRG_ENABLE
* @param                CTU_EXT_OUT_ENABLE
* @param                CTU_ETIMER0_OUT_ENABLE
* @param                CTU_ETIMER1_OUT_ENABLE
* @param                CTU_ETIMER2_OUT_ENABLE
* @param                CTU_ADC_OUT_ENABLE
*
* @return               NULL
*
* @details              The #CTU_TRG1_CONTROL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG1_CONTROL, CTU_TRG_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_TRG1_CONTROL

/***************************************************************************//*!
*
* @brief                Trigger 2 control
*
* @param                CTU_TRG_ENABLE
* @param                CTU_EXT_OUT_ENABLE
* @param                CTU_ETIMER0_OUT_ENABLE
* @param                CTU_ETIMER1_OUT_ENABLE
* @param                CTU_ETIMER2_OUT_ENABLE
* @param                CTU_ADC_OUT_ENABLE
*
* @return               NULL
*
* @details              The #CTU_TRG2_CONTROL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG2_CONTROL, CTU_TRG_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_TRG2_CONTROL

/***************************************************************************//*!
*
* @brief                Trigger 3 control
*
* @param                CTU_TRG_ENABLE
* @param                CTU_EXT_OUT_ENABLE
* @param                CTU_ETIMER0_OUT_ENABLE
* @param                CTU_ETIMER1_OUT_ENABLE
* @param                CTU_ETIMER2_OUT_ENABLE
* @param                CTU_ADC_OUT_ENABLE
*
* @return               NULL
*
* @details              The #CTU_TRG3_CONTROL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG3_CONTROL, CTU_TRG_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_TRG3_CONTROL

/***************************************************************************//*!
*
* @brief                Trigger 4 control
*
* @param                CTU_TRG_ENABLE
* @param                CTU_EXT_OUT_ENABLE
* @param                CTU_ETIMER0_OUT_ENABLE
* @param                CTU_ETIMER1_OUT_ENABLE
* @param                CTU_ETIMER2_OUT_ENABLE
* @param                CTU_ADC_OUT_ENABLE
*
* @return               NULL
*
* @details              The #CTU_TRG4_CONTROL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG4_CONTROL, CTU_TRG_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_TRG4_CONTROL

/***************************************************************************//*!
*
* @brief                Trigger 5 control
*
* @param                CTU_TRG_ENABLE
* @param                CTU_EXT_OUT_ENABLE
* @param                CTU_ETIMER0_OUT_ENABLE
* @param                CTU_ETIMER1_OUT_ENABLE
* @param                CTU_ETIMER2_OUT_ENABLE
* @param                CTU_ADC_OUT_ENABLE
*
* @return               NULL
*
* @details              The #CTU_TRG5_CONTROL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG5_CONTROL, CTU_TRG_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_TRG5_CONTROL

/***************************************************************************//*!
*
* @brief                Trigger 6 control
*
* @param                CTU_TRG_ENABLE
* @param                CTU_EXT_OUT_ENABLE
* @param                CTU_ETIMER0_OUT_ENABLE
* @param                CTU_ETIMER1_OUT_ENABLE
* @param                CTU_ETIMER2_OUT_ENABLE
* @param                CTU_ADC_OUT_ENABLE
*
* @return               NULL
*
* @details              The #CTU_TRG6_CONTROL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG6_CONTROL, CTU_TRG_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_TRG6_CONTROL

/***************************************************************************//*!
*
* @brief                Trigger 7 control
*
* @param                CTU_TRG_ENABLE
* @param                CTU_EXT_OUT_ENABLE
* @param                CTU_ETIMER0_OUT_ENABLE
* @param                CTU_ETIMER1_OUT_ENABLE
* @param                CTU_ETIMER2_OUT_ENABLE
* @param                CTU_ADC_OUT_ENABLE
*
* @return               NULL
*
* @details              The #CTU_TRG7_CONTROL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_TRG7_CONTROL, CTU_TRG_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_TRG7_CONTROL

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_0 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_0, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_0

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_0 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_0, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_0

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_1, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_1

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_1, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_1

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_2, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_2

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_2, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_2

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_3 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_3, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_3

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_3 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_3, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_3

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_4 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_4, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_4

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_4 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_4, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_4

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_5 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_5, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_5

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_5 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_5, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_5

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_6 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_6, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_6

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_6 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_6, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_6

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_7 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_7, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_7

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_7 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_7, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_7

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_8 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_8, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_8

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_8 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_8, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_8

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_9 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_9, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_9

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_9 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_9, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_9

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_10 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_10, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_10

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_10 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_10, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_10

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_11 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_11, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_11

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_11 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_11, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_11

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_12 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_12, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_12

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_12 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_12, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_12

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_13 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_13, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_13

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_13 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_13, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_13

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_14 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_14, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_14

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_14 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_14, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_14

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_15 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_15, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_15

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_15 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_15, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_15

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_16 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_16, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_16

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_16 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_16, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_16

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_17 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_17, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_17

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_17 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_17, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_17

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_18 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_18, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_18

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_18 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_18, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_18

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_19 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_19, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_19

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_19 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_19, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_19

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_20 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_20, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_20

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_20 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_20, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_20

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_21 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_21, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_21

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_21 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_21, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_21

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_22 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_22, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_22

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_22 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_22, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_22

/***************************************************************************//*!
*
* @brief                CTU ADC command control for dual  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADCCMD_ADC0_CH0
* @param                CTU_ADCCMD_ADC0_CH1
* @param                CTU_ADCCMD_ADC0_CH2
* @param                CTU_ADCCMD_ADC0_CH3
* @param                CTU_ADCCMD_ADC0_CH4
* @param                CTU_ADCCMD_ADC0_CH5
* @param                CTU_ADCCMD_ADC0_CH6
* @param                CTU_ADCCMD_ADC0_CH7
* @param                CTU_ADCCMD_ADC0_CH8
* @param                CTU_ADCCMD_ADC0_CH9
* @param                CTU_ADCCMD_ADC0_CH10
* @param                CTU_ADCCMD_ADC0_CH11
* @param                CTU_ADCCMD_ADC0_CH12
* @param                CTU_ADCCMD_ADC0_CH13
* @param                CTU_ADCCMD_ADC0_CH14
* @param                CTU_ADCCMD_ADC0_CH15
* @param                CTU_ADCCMD_ADC1_CH0
* @param                CTU_ADCCMD_ADC1_CH1
* @param                CTU_ADCCMD_ADC1_CH2
* @param                CTU_ADCCMD_ADC1_CH3
* @param                CTU_ADCCMD_ADC1_CH4
* @param                CTU_ADCCMD_ADC1_CH5
* @param                CTU_ADCCMD_ADC1_CH6
* @param                CTU_ADCCMD_ADC1_CH7
* @param                CTU_ADCCMD_ADC1_CH8
* @param                CTU_ADCCMD_ADC1_CH9
* @param                CTU_ADCCMD_ADC1_CH10
* @param                CTU_ADCCMD_ADC1_CH11
* @param                CTU_ADCCMD_ADC1_CH12
* @param                CTU_ADCCMD_ADC1_CH13
* @param                CTU_ADCCMD_ADC1_CH14
* @param                CTU_ADCCMD_ADC1_CH15
*
* @return               NULL
*
* @details              The #CTU_DCONV_ADCCMD_23 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DCONV_ADCCMD_23, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_DCONV_ADCCMD_23

/***************************************************************************//*!
*
* @brief                CTU ADC command control for single  conversion mode
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_FIFO_0
* @param                CTU_ADCCMD_FIFO_1
* @param                CTU_ADCCMD_FIFO_2
* @param                CTU_ADCCMD_FIFO_3
* @param                CTU_ADC0
* @param                CTU_ADC1
* @param                CTU_ADCCMD_CH0
* @param                CTU_ADCCMD_CH1
* @param                CTU_ADCCMD_CH2
* @param                CTU_ADCCMD_CH3
* @param                CTU_ADCCMD_CH4
* @param                CTU_ADCCMD_CH5
* @param                CTU_ADCCMD_CH6
* @param                CTU_ADCCMD_CH7
* @param                CTU_ADCCMD_CH8
* @param                CTU_ADCCMD_CH9
* @param                CTU_ADCCMD_CH10
* @param                CTU_ADCCMD_CH11
* @param                CTU_ADCCMD_CH12
* @param                CTU_ADCCMD_CH13
* @param                CTU_ADCCMD_CH14
* @param                CTU_ADCCMD_CH15
*
* @return               NULL
*
* @details              The #CTU_SCONV_ADCCMD_23 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SCONV_ADCCMD_23, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SCONV_ADCCMD_23

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_0 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_0, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_0

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_1, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_1

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_2, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_2

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_3 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_3, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_3

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_4 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_4, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_4

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_5 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_5, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_5

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_6 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_6, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_6

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_7 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_7, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_7

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_8 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_8, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_8

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_9 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_9, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_9

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_10 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_10, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_10

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_11 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_11, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_11

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_12 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_12, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_12

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_13 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_13, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_13

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_14 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_14, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_14

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_15 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_15, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_15

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_16 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_16, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_16

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_17 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_17, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_17

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_18 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_18, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_18

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_19 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_19, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_19

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_20 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_20, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_20

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_21 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_21, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_21

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_22 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_LLD,CTU_SELFTEST_ADCCMD_22, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_22

/***************************************************************************//*!
*
* @brief                CTU ADC command for ADC self-testing
*
* @param                CTU_ADCCMD_INT_ENABLE
* @param                CTU_ADCCMD_FIRST
* @param                CTU_ADCCMD_SELFTEST_ENABLE
* @param                CTU_ADCCMD_SELFTEST_DCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_SCONV_MODE
* @param                CTU_ADCCMD_SELFTEST_ADC0
* @param                CTU_ADCCMD_SELFTEST_ADC1
* @param                CTU_ADCCMD_SELFTEST_S_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_RC_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_C_ALGORITHM
* @param                CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM
*
* @return               NULL
*
* @details              The #CTU_SELFTEST_ADCCMD_23 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SELFTEST_ADCCMD_23, CTU_ADCCMD_INT_ENABLE);
* \endcode
*
******************************************************************************/
#define CTU_SELFTEST_ADCCMD_23

/***************************************************************************//*!
*
* @brief                Read CTU error flag status
*
* @param                NULL
*
* @return               This command returns status of CTU error flag register.
*
* @details              The #CTU_READ_ERROR_FLAGS ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(CTU_BASE,CTU_READ_ERROR_FLAGS, NULL);
* \endcode
*
******************************************************************************/
#define CTU_READ_ERROR_FLAGS

/***************************************************************************//*!
*
* @brief                Clear CTU error flag
*
* @param                CTU_MRS_RELOAD_ERROR
* @param                CTU_TRG_OVERRUN_ERROR
* @param                CTU_INVALID_COMMAND_ERROR
* @param                CTU_MRS_OVERRUN
* @param                CTU_TGS_OVERRUN_SEQ
* @param                CTU_ADC_ERROR
* @param                CTU_ETIMER0_ERROR
* @param                CTU_ETIMER1_ERROR
* @param                CTU_ETIMER2_ERROR
* @param                CTU_EXT_TRG_ERROR
* @param                CTU_ALL_ERRORS
*
* @return               NULL
*
* @details              The #CTU_CLEAR_ERROR_FLAGS ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_CLEAR_ERROR_FLAGS, CTU_MRS_RELOAD_ERROR);
* \endcode
*
******************************************************************************/
#define CTU_CLEAR_ERROR_FLAGS

/***************************************************************************//*!
*
* @brief                Read CTU interrupt flag status
*
* @param                NULL
*
* @return               This command returns status of CTU interrupt flag register.
*
* @details              The #CTU_READ_INT_FLAGS ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU16 u16RetVal;
* u16RetVal = ioctl(CTU_BASE,CTU_READ_INT_FLAGS, NULL);
* \endcode
*
******************************************************************************/
#define CTU_READ_INT_FLAGS

/***************************************************************************//*!
*
* @brief                Clear CTU interrupt flag
*
* @param                CTU_MRS_INTFLG
* @param                CTU_TRG0_INTFLG
* @param                CTU_TRG1_INTFLG
* @param                CTU_TRG2_INTFLG
* @param                CTU_TRG3_INTFLG
* @param                CTU_TRG4_INTFLG
* @param                CTU_TRG5_INTFLG
* @param                CTU_TRG6_INTFLG
* @param                CTU_TRG7_INTFLG
* @param                CTU_ADC_INTFLG
* @param                CTU_ALL_INTFLG
*
* @return               NULL
*
* @details              The #CTU_CLEAR_INT_FLAGS ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_CLEAR_INT_FLAGS, CTU_MRS_INTFLG);
* \endcode
*
******************************************************************************/
#define CTU_CLEAR_INT_FLAGS

/***************************************************************************//*!
*
* @brief                Enable CTU interrupts
*
* @param                CTU_ERROR_INTEN
* @param                CTU_MRS_INTEN
* @param                CTU_TRG0_INTEN
* @param                CTU_TRG1_INTEN
* @param                CTU_TRG2_INTEN
* @param                CTU_TRG3_INTEN
* @param                CTU_TRG4_INTEN
* @param                CTU_TRG5_INTEN
* @param                CTU_TRG6_INTEN
* @param                CTU_TRG7_INTEN
*
* @return               NULL
*
* @details              The #CTU_ENABLE_INT ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_ENABLE_INT, CTU_ERROR_INTEN);
* \endcode
*
******************************************************************************/
#define CTU_ENABLE_INT

/***************************************************************************//*!
*
* @brief                Enable CTU DMA requests
*
* @param                CTU_MRS_DMAEN
* @param                CTU_DMADONE
*
* @return               NULL
*
* @details              The #CTU_ENABLE_DMA ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_ENABLE_DMA, CTU_MRS_DMAEN);
* \endcode
*
******************************************************************************/
#define CTU_ENABLE_DMA

/***************************************************************************//*!
*
* @brief                CTU control
*
* @param                CTU_TGSISR_RELOAD_EN
* @param                CTU_GENERAL_RELOAD_EN
* @param                CTU_GENERATE_SW_MRS
* @param                CTU_CLEAR_GENERAL_RELOAD_FLAG
* @param                CTU_DIGITAL_FILTER_EN
* @param                CTU_OUTPUT_DISABLE
* @param                CTU_RESET_ADC_STATEMACHINE
* @param                CTU_GENERATE_SW_TRG0
* @param                CTU_GENERATE_SW_TRG1
* @param                CTU_GENERATE_SW_TRG2
* @param                CTU_GENERATE_SW_TRG3
* @param                CTU_GENERATE_SW_TRG4
* @param                CTU_GENERATE_SW_TRG5
* @param                CTU_GENERATE_SW_TRG6
* @param                CTU_GENERATE_SW_TRG7
*
* @return               NULL
*
* @details              The #CTU_CONTROL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_CONTROL, CTU_TGSISR_RELOAD_EN);
* \endcode
*
******************************************************************************/
#define CTU_CONTROL

/***************************************************************************//*!
*
* @brief                CTU configure digital filter on external signal
*
* @param                8bit value
*
* @return               NULL
*
* @details              The #CTU_DIGITAL_FILTER_VAL ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_DIGITAL_FILTER_VAL, 8bit value);
* \endcode
*
******************************************************************************/
#define CTU_DIGITAL_FILTER_VAL

/***************************************************************************//*!
*
* @brief                CTU FIFO DMA control
*
* @param                CTU_DMA_FIFO_0
* @param                CTU_DMA_FIFO_1
* @param                CTU_DMA_FIFO_2
* @param                CTU_DMA_FIFO_3
*
* @return               NULL
*
* @details              The #CTU_ENABLE_FIFO_DMA ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_ENABLE_FIFO_DMA, CTU_DMA_FIFO_0);
* \endcode
*
******************************************************************************/
#define CTU_ENABLE_FIFO_DMA

/***************************************************************************//*!
*
* @brief                CTU FIFO control for FIFO 0
*
* @param                CTU_FIFO_FULL_INT_EN
* @param                CTU_FIFO_EMPTY_INT_EN
* @param                CTU_FIFO_THRESHOLD_INT_EN
* @param                CTU_FIFO_OVERRUN_INT_EN
*
* @return               NULL
*
* @details              The #CTU_ENABLE_INT_FIFO_0 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_ENABLE_INT_FIFO_0, CTU_FIFO_FULL_INT_EN);
* \endcode
*
******************************************************************************/
#define CTU_ENABLE_INT_FIFO_0

/***************************************************************************//*!
*
* @brief                CTU FIFO control for FIFO 1
*
* @param                CTU_FIFO_FULL_INT_EN
* @param                CTU_FIFO_EMPTY_INT_EN
* @param                CTU_FIFO_THRESHOLD_INT_EN
* @param                CTU_FIFO_OVERRUN_INT_EN
*
* @return               NULL
*
* @details              The #CTU_ENABLE_INT_FIFO_1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_ENABLE_INT_FIFO_1, CTU_FIFO_FULL_INT_EN);
* \endcode
*
******************************************************************************/
#define CTU_ENABLE_INT_FIFO_1

/***************************************************************************//*!
*
* @brief                CTU FIFO control for FIFO 2
*
* @param                CTU_FIFO_FULL_INT_EN
* @param                CTU_FIFO_EMPTY_INT_EN
* @param                CTU_FIFO_THRESHOLD_INT_EN
* @param                CTU_FIFO_OVERRUN_INT_EN
*
* @return               NULL
*
* @details              The #CTU_ENABLE_INT_FIFO_2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_ENABLE_INT_FIFO_2, CTU_FIFO_FULL_INT_EN);
* \endcode
*
******************************************************************************/
#define CTU_ENABLE_INT_FIFO_2

/***************************************************************************//*!
*
* @brief                CTU FIFO control for FIFO 3
*
* @param                CTU_FIFO_FULL_INT_EN
* @param                CTU_FIFO_EMPTY_INT_EN
* @param                CTU_FIFO_THRESHOLD_INT_EN
* @param                CTU_FIFO_OVERRUN_INT_EN
*
* @return               NULL
*
* @details              The #CTU_ENABLE_INT_FIFO_3 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_ENABLE_INT_FIFO_3, CTU_FIFO_FULL_INT_EN);
* \endcode
*
******************************************************************************/
#define CTU_ENABLE_INT_FIFO_3

/***************************************************************************//*!
*
* @brief                Set FIFO 0 threshold value
*
* @param                8bit value
*
* @return               NULL
*
* @details              The #CTU_SET_THRESHOLD_FIFO_0 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SET_THRESHOLD_FIFO_0, 8bit value);
* \endcode
*
******************************************************************************/
#define CTU_SET_THRESHOLD_FIFO_0

/***************************************************************************//*!
*
* @brief                Get FIFO 0 threshold value
*
* @param                NULL
*
* @return               Returns actual value of threshold for FIFO 0
*
* @details              The #CTU_GET_THRESHOLD_FIFO_0 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU32 u32RetVal;
* u32RetVal = ioctl(CTU_BASE,CTU_GET_THRESHOLD_FIFO_0, NULL);
* \endcode
*
******************************************************************************/
#define CTU_GET_THRESHOLD_FIFO_0

/***************************************************************************//*!
*
* @brief                Set FIFO 1 threshold value
*
* @param                8bit value
*
* @return               NULL
*
* @details              The #CTU_SET_THRESHOLD_FIFO_1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SET_THRESHOLD_FIFO_1, 8bit value);
* \endcode
*
******************************************************************************/
#define CTU_SET_THRESHOLD_FIFO_1

/***************************************************************************//*!
*
* @brief                Get FIFO 1 threshold value
*
* @param                NULL
*
* @return               Returns actual value of threshold for FIFO 1
*
* @details              The #CTU_GET_THRESHOLD_FIFO_1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU32 u32RetVal;
* u32RetVal = ioctl(CTU_BASE,CTU_GET_THRESHOLD_FIFO_1, NULL);
* \endcode
*
******************************************************************************/
#define CTU_GET_THRESHOLD_FIFO_1

/***************************************************************************//*!
*
* @brief                Set FIFO 2 threshold value
*
* @param                8bit value
*
* @return               NULL
*
* @details              The #CTU_SET_THRESHOLD_FIFO_2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SET_THRESHOLD_FIFO_2, 8bit value);
* \endcode
*
******************************************************************************/
#define CTU_SET_THRESHOLD_FIFO_2

/***************************************************************************//*!
*
* @brief                Get FIFO 2 threshold value
*
* @param                NULL
*
* @return               Returns actual value of threshold for FIFO 2
*
* @details              The #CTU_GET_THRESHOLD_FIFO_2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU32 u32RetVal;
* u32RetVal = ioctl(CTU_BASE,CTU_GET_THRESHOLD_FIFO_2, NULL);
* \endcode
*
******************************************************************************/
#define CTU_GET_THRESHOLD_FIFO_2

/***************************************************************************//*!
*
* @brief                Set FIFO 3 threshold value
*
* @param                8bit value
*
* @return               NULL
*
* @details              The #CTU_SET_THRESHOLD_FIFO_3 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_SET_THRESHOLD_FIFO_3, 8bit value);
* \endcode
*
******************************************************************************/
#define CTU_SET_THRESHOLD_FIFO_3

/***************************************************************************//*!
*
* @brief                Get FIFO 3 threshold value
*
* @param                NULL
*
* @return               Returns actual value of threshold for FIFO 3
*
* @details              The #CTU_GET_THRESHOLD_FIFO_3 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU32 u32RetVal;
* u32RetVal = ioctl(CTU_BASE,CTU_GET_THRESHOLD_FIFO_3, NULL);
* \endcode
*
******************************************************************************/
#define CTU_GET_THRESHOLD_FIFO_3

/***************************************************************************//*!
*
* @brief                Read CTU FIFO interrupt flag status
*
* @param                NULL
*
* @return               This command returns status of CTU FIFO interrupt flag register.
*
* @details              The #CTU_READ_FIFO_INT_FLAGS ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU32 u32RetVal;
* u32RetVal = ioctl(CTU_BASE,CTU_READ_FIFO_INT_FLAGS, NULL);
* \endcode
*
******************************************************************************/
#define CTU_READ_FIFO_INT_FLAGS

/***************************************************************************//*!
*
* @brief                Clear CTU FIFO interrupt flags
*
* @param                CTU_FIFO_0_OVERRUN
* @param                CTU_FIFO_1_OVERRUN
* @param                CTU_FIFO_2_OVERRUN
* @param                CTU_FIFO_3_OVERRUN
* @param                CTU_FIFO_ALL
*
* @return               NULL
*
* @details              The #CTU_CLEAR_FIFO_INT_FLAGS ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* ioctl(CTU_BASE,CTU_CLEAR_FIFO_INT_FLAGS, CTU_FIFO_0_OVERRUN);
* \endcode
*
******************************************************************************/
#define CTU_CLEAR_FIFO_INT_FLAGS

/***************************************************************************//*!
*
* @brief                Read complete FIFO 0 register with right aligned conversion data
*
* @param                NULL
*
* @return               Returns whole content of FIFO 0 register with right aligned conversion data.
*
* @details              The #CTU_READ_RFIFO_0 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU32 u32RetVal;
* u32RetVal = ioctl(CTU_LLD,CTU_READ_RFIFO_0, NULL);
* \endcode
*
******************************************************************************/
#define CTU_READ_RFIFO_0

/***************************************************************************//*!
*
* @brief                Read complete FIFO 1 register with right aligned conversion data
*
* @param                NULL
*
* @return               Returns whole content of FIFO 1 register with right aligned conversion data.
*
* @details              The #CTU_READ_RFIFO_1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU32 u32RetVal;
* u32RetVal = ioctl(CTU_LLD,CTU_READ_RFIFO_1, NULL);
* \endcode
*
******************************************************************************/
#define CTU_READ_RFIFO_1

/***************************************************************************//*!
*
* @brief                Read complete FIFO 2 register with right aligned conversion data
*
* @param                NULL
*
* @return               Returns whole content of FIFO 2 register with right aligned conversion data.
*
* @details              The #CTU_READ_RFIFO_2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU32 u32RetVal;
* u32RetVal = ioctl(CTU_LLD,CTU_READ_RFIFO_2, NULL);
* \endcode
*
******************************************************************************/
#define CTU_READ_RFIFO_2

/***************************************************************************//*!
*
* @brief                Read complete FIFO 3 register with right aligned conversion data
*
* @param                NULL
*
* @return               Returns whole content of FIFO 3 register with right aligned conversion data.
*
* @details              The #CTU_READ_RFIFO_3 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU32 u32RetVal;
* u32RetVal = ioctl(CTU_LLD,CTU_READ_RFIFO_3, NULL);
* \endcode
*
******************************************************************************/
#define CTU_READ_RFIFO_3

/***************************************************************************//*!
*
* @brief                Read complete FIFO 0 register with left aligned conversion data
*
* @param                NULL
*
* @return               Returns whole content of FIFO 0 register with left aligned conversion data.
*
* @details              The #CTU_READ_LFIFO_0 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU32 u32RetVal;
* u32RetVal = ioctl(CTU_LLD,CTU_READ_LFIFO_0, NULL);
* \endcode
*
******************************************************************************/
#define CTU_READ_LFIFO_0

/***************************************************************************//*!
*
* @brief                Read complete FIFO 1 register with left aligned conversion data
*
* @param                NULL
*
* @return               Returns whole content of FIFO 1 register with left aligned conversion data.
*
* @details              The #CTU_READ_LFIFO_1 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU32 u32RetVal;
* u32RetVal = ioctl(CTU_LLD,CTU_READ_LFIFO_1, NULL);
* \endcode
*
******************************************************************************/
#define CTU_READ_LFIFO_1

/***************************************************************************//*!
*
* @brief                Read complete FIFO 2 register with left aligned conversion data
*
* @param                NULL
*
* @return               Returns whole content of FIFO 2 register with left aligned conversion data.
*
* @details              The #CTU_READ_LFIFO_2 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU32 u32RetVal;
* u32RetVal = ioctl(CTU_LLD,CTU_READ_LFIFO_2, NULL);
* \endcode
*
******************************************************************************/
#define CTU_READ_LFIFO_2

/***************************************************************************//*!
*
* @brief                Read complete FIFO 3 register with left aligned conversion data
*
* @param                NULL
*
* @return               Returns whole content of FIFO 3 register with left aligned conversion data.
*
* @details              The #CTU_READ_LFIFO_3 ioctl command TBD
*
* @par Code Example:
*
* \code
* // 
* volatile tU32 u32RetVal;
* u32RetVal = ioctl(CTU_LLD,CTU_READ_LFIFO_3, NULL);
* \endcode
*
******************************************************************************/
#define CTU_READ_LFIFO_3


/******************************************************************************
* CTU bitfield masks definition
******************************************************************************/

#define CTU_TGS_M_MASK                                  0x0001
#define CTU_MRS_SM_MASK                                 0x003E
#define CTU_PRES_MASK                                   0x00C0
#define CTU_ET_TM_MASK                                  0x0100
#define CTU_T0_INDEX_MASK                               0x0000001F
#define CTU_T1_INDEX_MASK                               0x00001F00
#define CTU_T2_INDEX_MASK                               0x001F0000
#define CTU_T3_INDEX_MASK                               0x1F000000
#define CTU_T4_INDEX_MASK                               0x0000001F
#define CTU_T5_INDEX_MASK                               0x00001F00
#define CTU_T6_INDEX_MASK                               0x001F0000
#define CTU_T7_INDEX_MASK                               0x1F000000
#define CTU_T0_MASK                                     0x0000007F
#define CTU_T1_MASK                                     0x00007F00
#define CTU_T2_MASK                                     0x007F0000
#define CTU_T3_MASK                                     0x7F000000
#define CTU_T4_MASK                                     0x0000007F
#define CTU_T5_MASK                                     0x00007F00
#define CTU_T6_MASK                                     0x007F0000
#define CTU_T7_MASK                                     0x7F000000
#define CTU_CTUEFRV_MASK                                0x0FFF
#define CTU_CTUIFRV_MASK                                0x0FFF
#define CTU_CTUIRINT_MASK                               0XFF03
#define CTU_CTUIRDMA_MASK                               0x000C
#define CTU_CTUDFV_MASK                                 0x00FF
#define CTU_FDCRV_MASK                                  0x000F
#define CTU_FCR_0_MASK                                  0x000F
#define CTU_FCR_1_MASK                                  0x00F0
#define CTU_FCR_2_MASK                                  0x0F00
#define CTU_FCR_3_MASK                                  0xF000
#define CTU_FTH_0_MASK                                  0x000000FF
#define CTU_FTH_1_MASK                                  0x0000FF00
#define CTU_FTH_2_MASK                                  0x00FF0000
#define CTU_FTH_3_MASK                                  0xFF000000
#define CTU_FSTV_MASK                                   0x0000FFFF
#define CTU_FIFO_MASK                                   0x001FFFFF

/******************************************************************************
* CTU register offset definition
******************************************************************************/

#define CTU_TGSISR_OFFSET                               0x0
#define CTU_TGSCR_OFFSET                                0x4
#define CTU_T0CR_OFFSET                                 0x6
#define CTU_T1CR_OFFSET                                 0x8
#define CTU_T2CR_OFFSET                                 0xA
#define CTU_T3CR_OFFSET                                 0xC
#define CTU_T4CR_OFFSET                                 0xE
#define CTU_T5CR_OFFSET                                 0x10
#define CTU_T6CR_OFFSET                                 0x12
#define CTU_T7CR_OFFSET                                 0x14
#define CTU_TGSCRR_OFFSET                               0x18
#define CTU_TGSCCR_OFFSET                               0x16
#define CTU_CLCR1_OFFSET                                0x1C
#define CTU_CLCR2_OFFSET                                0x20
#define CTU_THCR1_T0_OFFSET                             0x24
#define CTU_THCR1_T1_OFFSET                             0x24
#define CTU_THCR1_T2_OFFSET                             0x24
#define CTU_THCR1_T3_OFFSET                             0x24
#define CTU_THCR1_T4_OFFSET                             0x28
#define CTU_THCR1_T5_OFFSET                             0x28
#define CTU_THCR1_T6_OFFSET                             0x28
#define CTU_THCR1_T7_OFFSET                             0x28
#define CTU_CLR_0_OFFSET                                0x2c
#define CTU_CLR_1_OFFSET                                0x2e
#define CTU_CLR_2_OFFSET                                0x30
#define CTU_CLR_3_OFFSET                                0x32
#define CTU_CLR_4_OFFSET                                0x34
#define CTU_CLR_5_OFFSET                                0x36
#define CTU_CLR_6_OFFSET                                0x38
#define CTU_CLR_7_OFFSET                                0x3a
#define CTU_CLR_8_OFFSET                                0x3c
#define CTU_CLR_9_OFFSET                                0x3e
#define CTU_CLR_10_OFFSET                               0x40
#define CTU_CLR_11_OFFSET                               0x42
#define CTU_CLR_12_OFFSET                               0x44
#define CTU_CLR_13_OFFSET                               0x46
#define CTU_CLR_14_OFFSET                               0x48
#define CTU_CLR_15_OFFSET                               0x4a
#define CTU_CLR_16_OFFSET                               0x4c
#define CTU_CLR_17_OFFSET                               0x4e
#define CTU_CLR_18_OFFSET                               0x50
#define CTU_CLR_19_OFFSET                               0x52
#define CTU_CLR_20_OFFSET                               0x54
#define CTU_CLR_21_OFFSET                               0x56
#define CTU_CLR_22_OFFSET                               0x58
#define CTU_CLR_23_OFFSET                               0x5a
#define CTU_CTUEFR_OFFSET                               0xc0
#define CTU_CTUIFR_OFFSET                               0xc2
#define CTU_CTUIR_OFFSET                                0xc4
#define CTU_CTUCR_OFFSET                                0xc8
#define CTU_CTUDF_OFFSET                                0xCA
#define CTU_FDCR_OFFSET                                 0x6C
#define CTU_FCR_OFFSET                                  0x70
#define CTU_FTH_OFFSET                                  0x74
#define CTU_FST_OFFSET                                  0x7C
#define CTU_FR0_OFFSET                                  0x80
#define CTU_FR1_OFFSET                                  0x84
#define CTU_FR2_OFFSET                                  0x88
#define CTU_FR3_OFFSET                                  0x8c
#define CTU_FL0_OFFSET                                  0xa0
#define CTU_FL1_OFFSET                                  0xa4
#define CTU_FL2_OFFSET                                  0xa8
#define CTU_FL3_OFFSET                                  0xac

/******************************************************************************
* CTU MACRO and ioctl parameters definition
******************************************************************************/

#define CTU_PWMREL_RISING                               1
#define CTU_PWMREL_FALING                               2
#define CTU_PWM_SUB0_OUT0_RISING                        4
#define CTU_PWM_SUB0_OUT0_FALING                        8
#define CTU_PWM_SUB1_OUT0_RISING                        10
#define CTU_PWM_SUB1_OUT0_FALING                        20
#define CTU_PWM_SUB2_OUT0_RISING                        40
#define CTU_PWM_SUB2_OUT0_FALING                        80
#define CTU_PWM_SUB3_OUT0_RISING                        100
#define CTU_PWM_SUB3_OUT0_FALING                        200
#define CTU_PWM_SUB0_OUT1_RISING                        400
#define CTU_PWM_SUB0_OUT1_FALING                        800
#define CTU_PWM_SUB1_OUT1_RISING                        1000
#define CTU_PWM_SUB1_OUT1_FALING                        2000
#define CTU_PWM_SUB2_OUT1_RISING                        4000
#define CTU_PWM_SUB2_OUT1_FALING                        8000
#define CTU_PWM_SUB3_OUT1_RISING                        10000
#define CTU_PWM_SUB3_OUT1_FALING                        20000
#define CTU_PWM_X0_RISING                               40000
#define CTU_PWM_X0_FALING                               80000
#define CTU_PWM_X1_RISING                               100000
#define CTU_PWM_X1_FALING                               200000
#define CTU_PWM_X2_RISING                               400000
#define CTU_PWM_X2_FALING                               800000
#define CTU_PWM_X3_RISING                               1000000
#define CTU_PWM_X3_FALING                               2000000
#define CTU_ETIMER0_RISING                              4000000
#define CTU_ETIMER0_FALING                              8000000
#define CTU_ETIMER1_RISING                              10000000
#define CTU_ETIMER1_FALING                              20000000
#define CTU_EXT_SIGNAL_RISING                           40000000
#define CTU_EXT_SIGNAL_FALING                           80000000
#define CTU_TRIGGERED                                   0x0
#define CTU_SEQUENTIAL                                  0x1
#define CTU_PWMREL                                      0x0
#define CTU_PWM_SUB0_OUT0                               0x1
#define CTU_PWM_SUB1_OUT0                               0x2
#define CTU_PWM_SUB2_OUT0                               0x3
#define CTU_PWM_SUB3_OUT0                               0x4
#define CTU_PWM_SUB0_OUT1                               0x5
#define CTU_PWM_SUB1_OUT1                               0x6
#define CTU_PWM_SUB2_OUT1                               0x7
#define CTU_PWM_SUB3_OUT1                               0x8
#define CTU_PWM_X0                                      0x9
#define CTU_PWM_X1                                      0xA
#define CTU_PWM_X2                                      0xB
#define CTU_PWM_X3                                      0xC
#define CTU_ETIMER0                                     0xD
#define CTU_ETIMER1                                     0xE
#define CTU_EXT_SIGNAL                                  0xF
#define CTU_BYPASSED                                    0x0
#define CTU_CLK_DIVBY_2                                 0x1
#define CTU_CLK_DIVBY_3                                 0x2
#define CTU_CLK_DIVBY_4                                 0x3
#define CTU_DISABLE                                     0x0
#define CTU_ENABLE                                      0x1
#define CTU_ADCCMD_0                                    0x0
#define CTU_ADCCMD_1                                    0x1
#define CTU_ADCCMD_2                                    0x2
#define CTU_ADCCMD_3                                    0x3
#define CTU_ADCCMD_4                                    0x4
#define CTU_ADCCMD_5                                    0x5
#define CTU_ADCCMD_6                                    0x6
#define CTU_ADCCMD_7                                    0x7
#define CTU_ADCCMD_8                                    0x8
#define CTU_ADCCMD_9                                    0x9
#define CTU_ADCCMD_10                                   0xA
#define CTU_ADCCMD_11                                   0xB
#define CTU_ADCCMD_12                                   0xC
#define CTU_ADCCMD_13                                   0xD
#define CTU_ADCCMD_14                                   0xE
#define CTU_ADCCMD_15                                   0xF
#define CTU_ADCCMD_16                                   0x10
#define CTU_ADCCMD_17                                   0x11
#define CTU_ADCCMD_18                                   0x12
#define CTU_ADCCMD_19                                   0x13
#define CTU_ADCCMD_20                                   0x14
#define CTU_ADCCMD_21                                   0x15
#define CTU_ADCCMD_22                                   0x16
#define CTU_ADCCMD_23                                   0x17
#define CTU_TRG_ENABLE                                  0x40
#define CTU_EXT_OUT_ENABLE                              0x20
#define CTU_ETIMER0_OUT_ENABLE                          0x2
#define CTU_ETIMER1_OUT_ENABLE                          0x4
#define CTU_ETIMER2_OUT_ENABLE                          0x8
#define CTU_ADC_OUT_ENABLE                              0x1
#define CTU_ADCCMD_INT_ENABLE                           0x8000
#define CTU_ADCCMD_FIRST                                0x4000
#define CTU_ADCCMD_FIFO_0                               0x0400
#define CTU_ADCCMD_FIFO_1                               0x0800
#define CTU_ADCCMD_FIFO_2                               0x0C00
#define CTU_ADCCMD_FIFO_3                               0x1C00
#define CTU_ADCCMD_ADC0_CH0                             0
#define CTU_ADCCMD_ADC0_CH1                             1
#define CTU_ADCCMD_ADC0_CH2                             2
#define CTU_ADCCMD_ADC0_CH3                             3
#define CTU_ADCCMD_ADC0_CH4                             4
#define CTU_ADCCMD_ADC0_CH5                             5
#define CTU_ADCCMD_ADC0_CH6                             6
#define CTU_ADCCMD_ADC0_CH7                             7
#define CTU_ADCCMD_ADC0_CH8                             8
#define CTU_ADCCMD_ADC0_CH9                             9
#define CTU_ADCCMD_ADC0_CH10                            0xA
#define CTU_ADCCMD_ADC0_CH11                            0xB
#define CTU_ADCCMD_ADC0_CH12                            0xC
#define CTU_ADCCMD_ADC0_CH13                            0xD
#define CTU_ADCCMD_ADC0_CH14                            0xE
#define CTU_ADCCMD_ADC0_CH15                            0xF
#define CTU_ADCCMD_ADC1_CH0                             0
#define CTU_ADCCMD_ADC1_CH1                             0x20
#define CTU_ADCCMD_ADC1_CH2                             0x40
#define CTU_ADCCMD_ADC1_CH3                             0x60
#define CTU_ADCCMD_ADC1_CH4                             0x80
#define CTU_ADCCMD_ADC1_CH5                             0xA0
#define CTU_ADCCMD_ADC1_CH6                             0xC0
#define CTU_ADCCMD_ADC1_CH7                             0xE0
#define CTU_ADCCMD_ADC1_CH8                             0x100
#define CTU_ADCCMD_ADC1_CH9                             0x120
#define CTU_ADCCMD_ADC1_CH10                            0x140
#define CTU_ADCCMD_ADC1_CH11                            0x160
#define CTU_ADCCMD_ADC1_CH12                            0x180
#define CTU_ADCCMD_ADC1_CH13                            0x1A0
#define CTU_ADCCMD_ADC1_CH14                            0x1C0
#define CTU_ADCCMD_ADC1_CH15                            0x1E0
#define CTU_ADC0                                        0
#define CTU_ADC1                                        0x20
#define CTU_ADCCMD_CH0                                  0
#define CTU_ADCCMD_CH1                                  1
#define CTU_ADCCMD_CH2                                  2
#define CTU_ADCCMD_CH3                                  3
#define CTU_ADCCMD_CH4                                  4
#define CTU_ADCCMD_CH5                                  5
#define CTU_ADCCMD_CH6                                  6
#define CTU_ADCCMD_CH7                                  7
#define CTU_ADCCMD_CH8                                  8
#define CTU_ADCCMD_CH9                                  9
#define CTU_ADCCMD_CH10                                 0xA
#define CTU_ADCCMD_CH11                                 0xB
#define CTU_ADCCMD_CH12                                 0xC
#define CTU_ADCCMD_CH13                                 0xD
#define CTU_ADCCMD_CH14                                 0xE
#define CTU_ADCCMD_CH15                                 0xF
#define CTU_ADCCMD_SELFTEST_ENABLE                      0x0200
#define CTU_ADCCMD_SELFTEST_DCONV_MODE                  0x1000
#define CTU_ADCCMD_SELFTEST_SCONV_MODE                  0
#define CTU_ADCCMD_SELFTEST_ADC0                        0
#define CTU_ADCCMD_SELFTEST_ADC1                        0x0800
#define CTU_ADCCMD_SELFTEST_S_ALGORITHM                 0
#define CTU_ADCCMD_SELFTEST_RC_ALGORITHM                0x0080
#define CTU_ADCCMD_SELFTEST_C_ALGORITHM                 0x0100
#define CTU_ADCCMD_SELFTEST_S_RC_C_ALGORITHM            0x0180
#define CTU_MRS_RELOAD_ERROR                            0x0001
#define CTU_TRG_OVERRUN_ERROR                           0x0002
#define CTU_INVALID_COMMAND_ERROR                       0x0004
#define CTU_MRS_OVERRUN                                 0x0008
#define CTU_TGS_OVERRUN_SEQ                             0x0010
#define CTU_ADC_ERROR                                   0x0020
#define CTU_ETIMER0_ERROR                               0x0040
#define CTU_ETIMER1_ERROR                               0x0080
#define CTU_ETIMER2_ERROR                               0x0100
#define CTU_EXT_TRG_ERROR                               0x0800
#define CTU_ALL_ERRORS                                  0x0FFF
#define CTU_MRS_INTFLG                                  0x0001
#define CTU_TRG0_INTFLG                                 0x0002
#define CTU_TRG1_INTFLG                                 0x0004
#define CTU_TRG2_INTFLG                                 0x0008
#define CTU_TRG3_INTFLG                                 0x0010
#define CTU_TRG4_INTFLG                                 0x0020
#define CTU_TRG5_INTFLG                                 0x0040
#define CTU_TRG6_INTFLG                                 0x0080
#define CTU_TRG7_INTFLG                                 0x0100
#define CTU_ADC_INTFLG                                  0x0200
#define CTU_ALL_INTFLG                                  0x0FFF
#define CTU_ERROR_INTEN                                 0x0001
#define CTU_MRS_INTEN                                   0X0002
#define CTU_TRG0_INTEN                                  0X0100
#define CTU_TRG1_INTEN                                  0x0200
#define CTU_TRG2_INTEN                                  0X0400
#define CTU_TRG3_INTEN                                  0x0800
#define CTU_TRG4_INTEN                                  0x1000
#define CTU_TRG5_INTEN                                  0X2000
#define CTU_TRG6_INTEN                                  0x4000
#define CTU_TRG7_INTEN                                  0x8000
#define CTU_MRS_DMAEN                                   0x0004
#define CTU_DMADONE                                     0x0008
#define CTU_TGSISR_RELOAD_EN                            0x0001
#define CTU_GENERAL_RELOAD_EN                           0x0002
#define CTU_GENERATE_SW_MRS                             0x0004
#define CTU_CLEAR_GENERAL_RELOAD_FLAG                   0x0010
#define CTU_DIGITAL_FILTER_EN                           0x0020
#define CTU_OUTPUT_DISABLE                              0x0040
#define CTU_RESET_ADC_STATEMACHINE                      0x0080
#define CTU_GENERATE_SW_TRG0                            0x0100
#define CTU_GENERATE_SW_TRG1                            0x0200
#define CTU_GENERATE_SW_TRG2                            0x0400
#define CTU_GENERATE_SW_TRG3                            0x0800
#define CTU_GENERATE_SW_TRG4                            0x1000
#define CTU_GENERATE_SW_TRG5                            0X2000
#define CTU_GENERATE_SW_TRG6                            0x4000
#define CTU_GENERATE_SW_TRG7                            0x8000
#define CTU_DMA_FIFO_0                                  1
#define CTU_DMA_FIFO_1                                  2
#define CTU_DMA_FIFO_2                                  4
#define CTU_DMA_FIFO_3                                  8
#define CTU_FIFO_FULL_INT_EN                            1
#define CTU_FIFO_EMPTY_INT_EN                           2
#define CTU_FIFO_THRESHOLD_INT_EN                       4
#define CTU_FIFO_OVERRUN_INT_EN                         8
#define CTU_FIFO_0_OVERRUN                              0x00000008
#define CTU_FIFO_1_OVERRUN                              0x00000080
#define CTU_FIFO_2_OVERRUN                              0x00000800
#define CTU_FIFO_3_OVERRUN                              0x00008000
#define CTU_FIFO_ALL                                    0x00008888

/******************************************************************************
* CTU ioctl commands implementation
******************************************************************************/

#define ioctlCTU_TGS_INPUT(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_TGSISR_OFFSET)) = (param)

#define ioctlCTU_TGS_MODE(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_TGSCR_OFFSET)) = (*((volatile tU16 *)(ctuAddr + CTU_TGSCR_OFFSET)) & (~CTU_TGS_M_MASK)) | (param)

#define ioctlCTU_SEQUENTIAL_MRS_SOURCE(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_TGSCR_OFFSET)) = (*((volatile tU16 *)(ctuAddr + CTU_TGSCR_OFFSET)) & (~CTU_MRS_SM_MASK)) | (param<<1)

#define ioctlCTU_CLOCK_PRESCALER(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_TGSCR_OFFSET)) = (*((volatile tU16 *)(ctuAddr + CTU_TGSCR_OFFSET)) & (~CTU_PRES_MASK)) | (param<<6)

#define ioctlCTU_EXT_TRIGGER_TOGGLE(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_TGSCR_OFFSET)) = (*((volatile tU16 *)(ctuAddr + CTU_TGSCR_OFFSET)) & (~CTU_ET_TM_MASK)) | (param<<8)

#define ioctlCTU_TRG0_COMP_VALUE(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_T0CR_OFFSET)) = (param)

#define ioctlCTU_TRG1_COMP_VALUE(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_T1CR_OFFSET)) = (param)

#define ioctlCTU_TRG2_COMP_VALUE(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_T2CR_OFFSET)) = (param)

#define ioctlCTU_TRG3_COMP_VALUE(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_T3CR_OFFSET)) = (param)

#define ioctlCTU_TRG4_COMP_VALUE(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_T4CR_OFFSET)) = (param)

#define ioctlCTU_TRG5_COMP_VALUE(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_T5CR_OFFSET)) = (param)

#define ioctlCTU_TRG6_COMP_VALUE(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_T6CR_OFFSET)) = (param)

#define ioctlCTU_TRG7_COMP_VALUE(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_T7CR_OFFSET)) = (param)

#define ioctlCTU_TGS_REL_VALUE(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_TGSCRR_OFFSET)) = (param)

#define ioctlCTU_TGS_COMP_VALUE(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_TGSCCR_OFFSET)) = (param)

#define ioctlCTU_TRG0_FIRST_ADCCMD(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_CLCR1_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_CLCR1_OFFSET)) & (~CTU_T0_INDEX_MASK)) | (param)

#define ioctlCTU_TRG1_FIRST_ADCCMD(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_CLCR1_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_CLCR1_OFFSET)) & (~CTU_T1_INDEX_MASK)) | (param<<8)

#define ioctlCTU_TRG2_FIRST_ADCCMD(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_CLCR1_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_CLCR1_OFFSET)) & (~CTU_T2_INDEX_MASK)) | (param<<16)

#define ioctlCTU_TRG3_FIRST_ADCCMD(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_CLCR1_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_CLCR1_OFFSET)) & (~CTU_T3_INDEX_MASK)) | (param<<24)

#define ioctlCTU_TRG4_FIRST_ADCCMD(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_CLCR2_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_CLCR2_OFFSET)) & (~CTU_T4_INDEX_MASK)) | (param)

#define ioctlCTU_TRG5_FIRST_ADCCMD(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_CLCR2_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_CLCR2_OFFSET)) & (~CTU_T5_INDEX_MASK)) | (param<<8)

#define ioctlCTU_TRG6_FIRST_ADCCMD(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_CLCR2_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_CLCR2_OFFSET)) & (~CTU_T6_INDEX_MASK)) | (param<<16)

#define ioctlCTU_TRG7_FIRST_ADCCMD(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_CLCR2_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_CLCR2_OFFSET)) & (~CTU_T7_INDEX_MASK)) | (param<<24)

#define ioctlCTU_TRG0_CONTROL(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_THCR1_T0_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_THCR1_T0_OFFSET)) & (~CTU_T0_MASK)) | (param)

#define ioctlCTU_TRG1_CONTROL(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_THCR1_T1_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_THCR1_T1_OFFSET)) & (~CTU_T1_MASK)) | (param<<8)

#define ioctlCTU_TRG2_CONTROL(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_THCR1_T2_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_THCR1_T2_OFFSET)) & (~CTU_T2_MASK)) | (param<<16)

#define ioctlCTU_TRG3_CONTROL(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_THCR1_T3_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_THCR1_T3_OFFSET)) & (~CTU_T3_MASK)) | (param<<24)

#define ioctlCTU_TRG4_CONTROL(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_THCR1_T4_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_THCR1_T4_OFFSET)) & (~CTU_T4_MASK)) | (param)

#define ioctlCTU_TRG5_CONTROL(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_THCR1_T5_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_THCR1_T5_OFFSET)) & (~CTU_T5_MASK)) | (param<<8)

#define ioctlCTU_TRG6_CONTROL(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_THCR1_T6_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_THCR1_T6_OFFSET)) & (~CTU_T6_MASK)) | (param<<16)

#define ioctlCTU_TRG7_CONTROL(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_THCR1_T7_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_THCR1_T7_OFFSET)) & (~CTU_T7_MASK)) | (param<<24)

#define ioctlCTU_DCONV_ADCCMD_0(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_0_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_0(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_0_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_1(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_1_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_1(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_1_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_2(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_2_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_2(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_2_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_3(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_3_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_3(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_3_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_4(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_4_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_4(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_4_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_5(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_5_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_5(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_5_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_6(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_6_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_6(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_6_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_7(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_7_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_7(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_7_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_8(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_8_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_8(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_8_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_9(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_9_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_9(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_9_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_10(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_10_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_10(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_10_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_11(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_11_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_11(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_11_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_12(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_12_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_12(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_12_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_13(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_13_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_13(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_13_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_14(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_14_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_14(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_14_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_15(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_15_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_15(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_15_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_16(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_16_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_16(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_16_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_17(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_17_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_17(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_17_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_18(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_18_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_18(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_18_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_19(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_19_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_19(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_19_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_20(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_20_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_20(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_20_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_21(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_21_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_21(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_21_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_22(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_22_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_22(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_22_OFFSET)) = (param)

#define ioctlCTU_DCONV_ADCCMD_23(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_23_OFFSET)) = (param)

#define ioctlCTU_SCONV_ADCCMD_23(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_23_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_0(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_0_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_1(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_1_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_2(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_2_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_3(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_3_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_4(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_4_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_5(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_5_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_6(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_6_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_7(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_7_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_8(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_8_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_9(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_9_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_10(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_10_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_11(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_11_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_12(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_12_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_13(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_13_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_14(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_14_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_15(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_15_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_16(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_16_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_17(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_17_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_18(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_18_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_19(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_19_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_20(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_20_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_21(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_21_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_22(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_22_OFFSET)) = (param)

#define ioctlCTU_SELFTEST_ADCCMD_23(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CLR_23_OFFSET)) = (param)

#define ioctlCTU_READ_ERROR_FLAGS(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CTUEFR_OFFSET)) & (CTU_CTUEFRV_MASK)

#define ioctlCTU_CLEAR_ERROR_FLAGS(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CTUEFR_OFFSET)) = (*((volatile tU16 *)(ctuAddr + CTU_CTUEFR_OFFSET)) & (~CTU_CTUEFRV_MASK)) | (param)

#define ioctlCTU_READ_INT_FLAGS(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CTUIFR_OFFSET)) & (CTU_CTUIFRV_MASK)

#define ioctlCTU_CLEAR_INT_FLAGS(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CTUIFR_OFFSET)) = (*((volatile tU16 *)(ctuAddr + CTU_CTUIFR_OFFSET)) & (~CTU_CTUIFRV_MASK)) | (param)

#define ioctlCTU_ENABLE_INT(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CTUIR_OFFSET)) = (*((volatile tU16 *)(ctuAddr + CTU_CTUIR_OFFSET)) & (~CTU_CTUIRINT_MASK)) | (param)

#define ioctlCTU_ENABLE_DMA(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CTUIR_OFFSET)) = (*((volatile tU16 *)(ctuAddr + CTU_CTUIR_OFFSET)) & (~CTU_CTUIRDMA_MASK)) | (param<<2)

#define ioctlCTU_CONTROL(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CTUCR_OFFSET)) = (param)

#define ioctlCTU_DIGITAL_FILTER_VAL(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_CTUDF_OFFSET)) = (*((volatile tU16 *)(ctuAddr + CTU_CTUDF_OFFSET)) & (~CTU_CTUDFV_MASK)) | (param)

#define ioctlCTU_ENABLE_FIFO_DMA(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_FDCR_OFFSET)) = (*((volatile tU16 *)(ctuAddr + CTU_FDCR_OFFSET)) & (~CTU_FDCRV_MASK)) | (param)

#define ioctlCTU_ENABLE_INT_FIFO_0(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_FCR_OFFSET)) = (*((volatile tU16 *)(ctuAddr + CTU_FCR_OFFSET)) & (~CTU_FCR_0_MASK)) | (param)

#define ioctlCTU_ENABLE_INT_FIFO_1(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_FCR_OFFSET)) = (*((volatile tU16 *)(ctuAddr + CTU_FCR_OFFSET)) & (~CTU_FCR_1_MASK)) | (param<<4)

#define ioctlCTU_ENABLE_INT_FIFO_2(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_FCR_OFFSET)) = (*((volatile tU16 *)(ctuAddr + CTU_FCR_OFFSET)) & (~CTU_FCR_2_MASK)) | (param<<8)

#define ioctlCTU_ENABLE_INT_FIFO_3(ctuAddr,param) \
        *((volatile tU16 *)(ctuAddr + CTU_FCR_OFFSET)) = (*((volatile tU16 *)(ctuAddr + CTU_FCR_OFFSET)) & (~CTU_FCR_3_MASK)) | (param<<12)

#define ioctlCTU_SET_THRESHOLD_FIFO_0(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FTH_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_FTH_OFFSET)) & (~CTU_FTH_0_MASK)) | (param)

#define ioctlCTU_GET_THRESHOLD_FIFO_0(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FTH_OFFSET)) & (CTU_FTH_0_MASK)

#define ioctlCTU_SET_THRESHOLD_FIFO_1(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FTH_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_FTH_OFFSET)) & (~CTU_FTH_1_MASK)) | (param<<8)

#define ioctlCTU_GET_THRESHOLD_FIFO_1(ctuAddr,param) \
        (*((volatile tU32 *)(ctuAddr + CTU_FTH_OFFSET)) & (CTU_FTH_1_MASK)) >>8

#define ioctlCTU_SET_THRESHOLD_FIFO_2(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FTH_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_FTH_OFFSET)) & (~CTU_FTH_2_MASK)) | (param<<16)

#define ioctlCTU_GET_THRESHOLD_FIFO_2(ctuAddr,param) \
        (*((volatile tU32 *)(ctuAddr + CTU_FTH_OFFSET)) & (CTU_FTH_2_MASK)) >>16

#define ioctlCTU_SET_THRESHOLD_FIFO_3(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FTH_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_FTH_OFFSET)) & (~CTU_FTH_3_MASK)) | (param<<24)

#define ioctlCTU_GET_THRESHOLD_FIFO_3(ctuAddr,param) \
        (*((volatile tU32 *)(ctuAddr + CTU_FTH_OFFSET)) & (CTU_FTH_3_MASK)) >>24

#define ioctlCTU_READ_FIFO_INT_FLAGS(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FST_OFFSET)) & (CTU_FSTV_MASK)

#define ioctlCTU_CLEAR_FIFO_INT_FLAGS(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FST_OFFSET)) = (*((volatile tU32 *)(ctuAddr + CTU_FST_OFFSET)) & (~CTU_FSTV_MASK)) | (param)

#define ioctlCTU_READ_RFIFO_0(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FR0_OFFSET)) & (CTU_FIFO_MASK)

#define ioctlCTU_READ_RFIFO_1(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FR1_OFFSET)) & (CTU_FIFO_MASK)

#define ioctlCTU_READ_RFIFO_2(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FR2_OFFSET)) & (CTU_FIFO_MASK)

#define ioctlCTU_READ_RFIFO_3(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FR3_OFFSET)) & (CTU_FIFO_MASK)

#define ioctlCTU_READ_LFIFO_0(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FL0_OFFSET)) & (CTU_FIFO_MASK)

#define ioctlCTU_READ_LFIFO_1(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FL1_OFFSET)) & (CTU_FIFO_MASK)

#define ioctlCTU_READ_LFIFO_2(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FL2_OFFSET)) & (CTU_FIFO_MASK)

#define ioctlCTU_READ_LFIFO_3(ctuAddr,param) \
        *((volatile tU32 *)(ctuAddr + CTU_FL3_OFFSET)) & (CTU_FIFO_MASK)

#ifdef __cplusplus
}
#endif

#endif /* _MPC5643L_CTU_LLD_H_ */
